Python: package fltk

fltk | index /home/held/source/pyfltk/test/fltk/__init__.py

`pyFltk, the Python bindings to the FLTK GUI toolkit.
This is an easy to use and light-weight GUI toolkit
offering basic capabilities for the creation of
graphical user interfaces.`

Package Contents
`` |  |
_fltk |  |  |

Classes
`` |  | __builtin__.object FL_CHART_ENTRY Fl Fl_End Fl_File_Chooser Fl_File_Icon Fl_Help_Block Fl_Help_Dialog Fl_Help_Link Fl_Help_Target Fl_Image Fl_Bitmap Fl_XBM_Image Fl_Pixmap Fl_GIF_Image Fl_XPM_Image Fl_RGB_Image Fl_BMP_Image Fl_JPEG_Image Fl_PNG_Image Fl_PNM_Image Fl_Shared_Image Fl_Tiled_Image Fl_Label Fl_Menu_Item Fl_Multi_Label Fl_Preferences Fl_Text_Buffer Fl_Text_Selection Fl_Tooltip Fl_Widget Fl_Box Fl_Button Fl_Light_Button Fl_Check_Button Fl_Radio_Light_Button Fl_Round_Button Fl_Radio_Round_Button Fl_Radio_Button Fl_Repeat_Button Fl_Return_Button Fl_Toggle_Button Fl_Chart Fl_Clock_Output Fl_Clock Fl_Round_Clock Fl_FormsBitmap Fl_FormsPixmap Fl_Free Fl_Group Fl_Browser_ Fl_Browser Fl_File_Browser Fl_Hold_Browser Fl_Multi_Browser Fl_Select_Browser Fl_Check_Browser Fl_Color_Chooser Fl_Help_View Fl_Input_Choice Fl_Pack Fl_Scroll Fl_Spinner Fl_Table Fl_Table_Row Fl_Tabs Fl_Text_Display Fl_Text_Editor Fl_Tile Fl_Window Fl_Double_Window Fl_Overlay_Window Fl_Gl_Window Fl_Single_Window Fl_Menu_Window Fl_Wizard ListSelect Fl_Input_ Fl_Input Fl_File_Input Fl_Float_Input Fl_Int_Input Fl_Multiline_Input Fl_Output Fl_Multiline_Output Fl_Secret_Input Fl_Menu_ Fl_Choice Fl_Menu_Bar Fl_Menu_Button Fl_Positioner Fl_Progress Fl_Timer Fl_Valuator Fl_Adjuster Fl_Counter Fl_Simple_Counter Fl_Dial Fl_Fill_Dial Fl_Line_Dial Fl_Roller Fl_Slider Fl_Fill_Slider Fl_Hor_Fill_Slider Fl_Hor_Nice_Slider Fl_Hor_Slider Fl_Nice_Slider Fl_Scrollbar Fl_Value_Slider Fl_Hor_Value_Slider Fl_Value_Input Flcc_Value_Input Fl_Value_Output Flcc_HueBox Flcc_ValueBox Style_Table_Entry
class FL_CHART_ENTRY(__builtin__.object)
`` | `Proxy of C++ FL_CHART_ENTRY class`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> FL_CHART_ENTRY` __repr__ = _swig_repr(self) Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_FL_CHART_ENTRY> `delete_FL_CHART_ENTRY(FL_CHART_ENTRY self)`
class Fl(__builtin__.object)
`` | `The Fl class is the FLTK global (static) class containing state information and global methods for the current application.`
| Methods defined here: __del__ lambda self __init__(self, *args, **kwargs) __repr__ = _swig_repr(self) Static methods defined here: add_awake_handler_(*args) `add_awake_handler_(Fl_Awake_Handler arg0, void arg1) -> int` add_check = Fl_add_check(...) add_fd = Fl_add_fd(...) add_handler = Fl_add_handler(...) add_idle = Fl_add_idle(func, data=None) add_timeout = Fl_add_timeout(...) arg(*args) `arg(int arg0, char arg1, int arg2) -> int` args(*args) `args(int arg0, char arg1, int arg2, int arg3 = None) -> int args(int arg0, char arg1)` awake(*args) `awake(Fl_Awake_Handler cb, void message = None) -> int awake(void message = None)` background(*args) `background(uchar arg0, uchar arg1, uchar arg2)` background2(*args) `background2(uchar arg0, uchar arg1, uchar arg2)` belowmouse(*args) `belowmouse() -> Fl_Widget belowmouse(Fl_Widget arg0)` box_dh(*args) `box_dh(Fl_Boxtype arg0) -> int` box_dw(*args) `box_dw(Fl_Boxtype arg0) -> int` box_dx(*args) `box_dx(Fl_Boxtype arg0) -> int` box_dy(*args) `box_dy(Fl_Boxtype arg0) -> int` check(*args) `check() -> int` clear_widget_pointer(*args) `clear_widget_pointer(Fl_Widget w)` compose(*args) `compose(int _del) -> int` compose_reset(*args) `compose_reset()` copy(*args) `copy(char stuff, int len, int clipboard = 0)` damage(*args) `damage(int d) damage() -> int` default_atclose(*args) `default_atclose(Fl_Window arg0, void arg1)` delete_widget(*args) `delete_widget(Fl_Widget w)` display(*args) `display(char arg0)` dnd(*args) `dnd() -> int` dnd_text_ops(*args) `dnd_text_ops(int v) dnd_text_ops() -> int` do_widget_deletion(*args) `do_widget_deletion()` draw_box_active(*args) `draw_box_active() -> int` event(*args) `event() -> int` event_alt(*args) `event_alt() -> int` event_button(*args) `event_button() -> int` event_button1(*args) `event_button1() -> int` event_button2(*args) `event_button2() -> int` event_button3(*args) `event_button3() -> int` event_buttons(*args) `event_buttons() -> int` event_clicks(*args) `event_clicks() -> int event_clicks(int i)` event_ctrl(*args) `event_ctrl() -> int` event_dx(*args) `event_dx() -> int` event_dy(*args) `event_dy() -> int` event_inside(*args) `event_inside(int arg0, int arg1, int arg2, int arg3) -> int event_inside(Fl_Widget arg0) -> int` event_is_click(*args) `event_is_click() -> int event_is_click(int i)` event_key(*args) `event_key() -> int event_key(int arg0) -> int` event_length(*args) `event_length() -> int` event_original_key(*args) `event_original_key() -> int` event_shift(*args) `event_shift() -> int` event_state(*args) `event_state() -> int event_state(int i) -> int` event_text(*args) `event_text() -> char` event_x(*args) `event_x() -> int` event_x_root(*args) `event_x_root() -> int` event_y(*args) `event_y() -> int` event_y_root(*args) `event_y_root() -> int` first_window(*args) `first_window() -> Fl_Window first_window(Fl_Window arg0)` flush(*args) `flush()` focus(*args) `focus() -> Fl_Widget focus(Fl_Widget arg0)` foreground(*args) `foreground(uchar arg0, uchar arg1, uchar arg2)` free_color(*args) `free_color(Fl_Color arg0, int overlay = 0)` get_awake_handler_(*args) `get_awake_handler_(Fl_Awake_Handler arg0, void arg1) -> int` get_boxtype(*args) `get_boxtype(Fl_Boxtype arg0) -> Fl_Box_Draw_F` get_color(*args) `get_color(Fl_Color arg0)` get_font(*args) `get_font(Fl_Font arg0) -> char` get_font_name(*args) `get_font_name(Fl_Font arg0, int attributes = None) -> char` get_font_sizes(*args) `get_font_sizes(Fl_Font arg0, int sizep) -> int` get_key(*args) `get_key(int arg0) -> int` get_mouse(*args) `get_mouse(int arg0, int arg1)` get_system_colors(*args) `get_system_colors()` grab(*args) `grab() -> Fl_Window grab(Fl_Window arg0)` h(*args) `h() -> int` handle(*args) `handle(int arg0, Fl_Window arg1) -> int` has_idle(*args) `has_idle(void cb, void arg1 = None) -> int` has_timeout(*args) `has_timeout(Fl_Timeout_Handler arg0, void arg1 = None) -> int` lock(*args) `lock()` modal(*args) `modal() -> Fl_Window` mt_run = Fl_mt_run(window) next_window(*args) `next_window(Fl_Window arg0) -> Fl_Window` own_colormap(*args) `own_colormap()` paste(*args) `paste(Fl_Widget receiver, int clipboard) paste(Fl_Widget receiver)` pushed(*args) `pushed() -> Fl_Widget pushed(Fl_Widget arg0)` readqueue(*args) `readqueue() -> Fl_Widget` ready(*args) `ready() -> int` redraw(*args) `redraw()` release(*args) `release()` release_widget_pointer(*args) `release_widget_pointer(Fl_Widget w)` reload_scheme(*args) `reload_scheme() -> int` remove_check = Fl_remove_check(...) remove_fd = Fl_remove_fd(...) remove_handler = Fl_remove_handler(...) remove_idle = Fl_remove_idle(func, data=None) remove_timeout = Fl_remove_timeout(...) repeat_timeout = Fl_repeat_timeout(...) run(*args) `run() -> int` scheme(*args) `scheme(char arg0) -> int scheme() -> char` screen_count(*args) `screen_count() -> int` screen_xywh(*args) `screen_xywh(int X, int Y, int W, int H) screen_xywh(int X, int Y, int W, int H, int mx, int my) screen_xywh(int X, int Y, int W, int H, int n)` scrollbar_size(*args) `scrollbar_size() -> int scrollbar_size(int W)` selection(*args) `selection(Fl_Widget owner, char arg1, int len)` selection_owner(*args) `selection_owner() -> Fl_Widget selection_owner(Fl_Widget arg0)` set_abort(*args) `set_abort(void f)` set_atclose(*args) `set_atclose(void f)` set_boxtype(*args) `set_boxtype(Fl_Boxtype arg0, Fl_Box_Draw_F arg1, uchar arg2, uchar arg3, uchar arg4, uchar arg5) set_boxtype(Fl_Boxtype arg0, Fl_Boxtype _from)` set_color(*args) `set_color(Fl_Color arg0, uchar arg1, uchar arg2, uchar arg3) set_color(Fl_Color arg0, unsigned int arg1)` set_font(*args) `set_font(Fl_Font arg0, char arg1) set_font(Fl_Font arg0, Fl_Font arg1)` set_fonts(*args) `set_fonts(char arg0 = None) -> Fl_Font` set_labeltype(*args) `set_labeltype(Fl_Labeltype arg0, Fl_Label_Draw_F arg1, Fl_Label_Measure_F arg2)` test_shortcut(*args) `test_shortcut(int arg0) -> int` thread_message(*args) `thread_message()` unlock(*args) `unlock()` version(*args) `version() -> double` visible_focus(*args) `visible_focus(int v) visible_focus() -> int` visual(*args) `visual(int arg0) -> int` w(*args) `w() -> int` wait(*args) `wait() -> int wait(double time) -> double` watch_widget_pointer(*args) `watch_widget_pointer(Fl_Widget w)` x(*args) `x() -> int` y(*args) `y() -> int` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl> `delete_Fl(Fl self)`
class Fl_Adjuster(Fl_Valuator)
`` | `The Fl_Adjuster widget has proven to be very useful for values that need a was stolen from Prisms, and large dynamic range. When you press a button and drag to the right the value increases. When you drag to the left it decreases. The largest button adjusts by 100 * step(), the next by 10 * step() and that smallest button by step(). Clicking on the buttons increments by 10 times the amount dragging by a pixel does. Shift + click decrements by 10 times the amount.`
| Method resolution order: Fl_Adjuster Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Adjuster` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` soft(self, *args) `soft(self, int s) soft(self) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Adjuster> `delete_Fl_Adjuster(Fl_Adjuster self)` Methods inherited from Fl_Valuator: bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_BMP_Image(Fl_RGB_Image)
`` | `The Fl_BMP_Image class supports loading, caching, and drawing of Windows Bitmap (BMP) image files.`
| Method resolution order: Fl_BMP_Image Fl_RGB_Image Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, char filename) -> Fl_BMP_Image` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_BMP_Image> `delete_Fl_BMP_Image(Fl_BMP_Image self)` Methods inherited from Fl_RGB_Image: color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` uncache(self, *args) `uncache(self)` Methods inherited from Fl_Image: count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Bitmap(Fl_Image)
`` | `The Fl_Bitmap class supports caching and drawing of mono-color (bitmap) images. Images are drawn using the current color.`
| Method resolution order: Fl_Bitmap Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, uchar bits, int W, int H) -> Fl_Bitmap` __repr__ = _swig_repr(self) copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` uncache(self, *args) `uncache(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Bitmap> `delete_Fl_Bitmap(Fl_Bitmap self)` Methods inherited from Fl_Image: color_average(self, *args) `color_average(self, Fl_Color c, float i)` count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` desaturate(self, *args) `desaturate(self)` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Box(Fl_Widget)
`` | `This widget simply draws its box, and possibly it's label. Putting it before some other widgets and making it big enough to surround them will let you draw a frame around them.`
| Method resolution order: Fl_Box Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Box __init__(self, Fl_Boxtype b, int X, int Y, int W, int H, char l) -> Fl_Box` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Box> `delete_Fl_Box(Fl_Box self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Browser(Fl_Browser_)
`` | `The Fl_Browser widget displays a scrolling list of text lines, and manages all the storage for the text. This is not a text editor or spreadsheet! But it is useful for showing a vertical list of named objects to the user. Each line in the browser is identified by number. The numbers start at one (this is so that zero can be reserved for 'no line' in the selective browsers). Unless otherwise noted, the methods do not check to see if the passed line number is in range and legal. It must always be greater than zero and <= size(). Each line contains a null-terminated string of text and a data pointer. The text string is displayed, the pointer can be used by the callbacks to reference the object the text describes. The base class does nothing when the user clicks on it. The subclasses Fl_Select_Browser, Fl_Hold_Browser, and Fl_Multi_Browser react to user clicks to select lines in the browser and do callbacks. The base class called Fl_Browser_ provides the scrolling and selection mechanisms of this and all the subclasses, but the dimensions and appearance of each item are determined by the subclass. You can use Fl_Browser_ to display information other than text, or text that is dynamically produced from your own data structures. If you find that loading the browser is a lot of work or is inefficient, you may want to make a subclass of Fl_Browser_.`
| Method resolution order: Fl_Browser Fl_Browser_ Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Browser` __repr__ = _swig_repr(self) add(self, *args) `add(self, char text, PyObject data = None)` bottomline(self, *args) `bottomline(self, int l)` clear(self, *args) `clear(self)` column_char(self, *args) `column_char(self) -> char column_char(self, char c)` column_widths(self, *args) `column_widths(self) -> int column_widths(self, PyObject widths)` data(self, *args) `data(self, int index, PyObject data = None) -> PyObject` display(self, *args) `display(self, int arg0, int arg1 = 1)` displayed(self, *args) `displayed(self, int n) -> int` draw(self, *args) `draw(self)` format_char(self, *args) `format_char(self) -> char format_char(self, char c)` full_height(self, *args) `full_height(self) -> int` full_width(self, *args) `full_width(self) -> int` get_data(self, *args) `get_data(self, int index) -> PyObject` hide(self, *args) `hide(self, int n) hide(self)` incr_height(self, *args) `incr_height(self) -> int` insert(self, *args) `insert(self, int index, char text, PyObject data = None)` item_draw(self, *args) `item_draw(self, void arg0, int arg1, int arg2, int arg3, int arg4)` item_first(self, *args) `item_first(self) -> void` item_height(self, *args) `item_height(self, void arg0) -> int` item_next(self, *args) `item_next(self, void arg0) -> void` item_prev(self, *args) `item_prev(self, void arg0) -> void` item_quick_height(self, *args) `item_quick_height(self, void arg0) -> int` item_select(self, *args) `item_select(self, void arg0, int arg1)` item_selected(self, *args) `item_selected(self, void arg0) -> int` item_width(self, *args) `item_width(self, void arg0) -> int` lineposition(self, *args) `lineposition(self, int arg0, Fl_Line_Position arg1)` load(self, *args) `load(self, char filename) -> int` make_visible(self, *args) `make_visible(self, int n)` middleline(self, *args) `middleline(self, int l)` move(self, *args) `move(self, int to, int _from)` remove(self, *args) `remove(self, int arg0)` replace(self, *args) `replace(self, int a, char b)` select(self, *args) `select(self, int arg0, int arg1 = 1) -> int` selected(self, *args) `selected(self, int arg0) -> int` show(self, *args) `show(self, int n) show(self)` size(self, *args) `size(self) -> int size(self, int W, int H)` swap(self, *args) `swap(self, int a, int b)` text(self, *args) `text(self, int arg0) -> char text(self, int arg0, char arg1)` topline(self, *args) `topline(self) -> int topline(self, int l)` value(self, *args) `value(self) -> int value(self, int v)` visible(self, *args) `visible(self, int n) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: BOTTOM = 1 MIDDLE = 2 TOP = 0 __swig_destroy__ = <built-in function delete_Fl_Browser> `delete_Fl_Browser(Fl_Browser self)` Methods inherited from Fl_Browser_: deselect(self, *args) `deselect(self, int docallbacks = 0) -> int` getHScrollbar(self, *args) `getHScrollbar(self) -> Fl_Scrollbar` getScrollbar(self, *args) `getScrollbar(self) -> Fl_Scrollbar` handle(self, *args) `handle(self, int arg0) -> int` has_scrollbar(self, *args) `has_scrollbar(self) -> uchar has_scrollbar(self, uchar i)` hposition(self, *args) `hposition(self) -> int hposition(self, int arg0)` position(self, *args) `position(self) -> int position(self, int arg0)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` scrollbar_left(self, *args) `scrollbar_left(self)` scrollbar_right(self, *args) `scrollbar_right(self)` select_only(self, *args) `select_only(self, void arg0, int docallbacks = 0) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Static methods inherited from Fl_Browser_: scrollbar_width(*args) `scrollbar_width(int b) scrollbar_width() -> int` Data and other attributes inherited from Fl_Browser_: ALWAYS_ON = 4 BOTH = 3 BOTH_ALWAYS = 7 HORIZONTAL = 1 HORIZONTAL_ALWAYS = 5 VERTICAL = 2 VERTICAL_ALWAYS = 6 Methods inherited from Fl_Group: add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Browser_(Fl_Group)
`` | `This is the base class for browsers. To be useful it must be subclassed and several virtual functions defined. The Forms-compatible browser and the file chooser's browser are subclassed off of this. This has been designed so that the subclass has complete control over the storage of the data, although because next() and prev() functions are used to index, it works best as a linked list or as a large block of characters in which the line breaks must be searched for. A great deal of work has been done so that the 'height' of a data object does not need to be determined until it is drawn. This is useful if actually figuring out the size of an object requires accessing image data or doing stat() on a file or doing some other slow operation.`
| Method resolution order: Fl_Browser_ Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Browser_` __repr__ = _swig_repr(self) deselect(self, *args) `deselect(self, int docallbacks = 0) -> int` display(self, *args) `display(self, void arg0)` draw(self, *args) `draw(self)` full_height(self, *args) `full_height(self) -> int` full_width(self, *args) `full_width(self) -> int` getHScrollbar(self, *args) `getHScrollbar(self) -> Fl_Scrollbar` getScrollbar(self, *args) `getScrollbar(self) -> Fl_Scrollbar` handle(self, *args) `handle(self, int arg0) -> int` has_scrollbar(self, *args) `has_scrollbar(self) -> uchar has_scrollbar(self, uchar i)` hposition(self, *args) `hposition(self) -> int hposition(self, int arg0)` incr_height(self, *args) `incr_height(self) -> int` item_draw(self, *args) `item_draw(self, void arg0, int arg1, int arg2, int arg3, int arg4)` item_first(self, *args) `item_first(self) -> void` item_height(self, *args) `item_height(self, void arg0) -> int` item_next(self, *args) `item_next(self, void arg0) -> void` item_prev(self, *args) `item_prev(self, void arg0) -> void` item_quick_height(self, *args) `item_quick_height(self, void arg0) -> int` item_select(self, *args) `item_select(self, void arg0, int arg1 = 1)` item_selected(self, *args) `item_selected(self, void arg0) -> int` item_width(self, *args) `item_width(self, void arg0) -> int` position(self, *args) `position(self) -> int position(self, int arg0)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` scrollbar_left(self, *args) `scrollbar_left(self)` scrollbar_right(self, *args) `scrollbar_right(self)` select(self, *args) `select(self, void arg0, int arg1 = 1, int docallbacks = 0) -> int` select_only(self, *args) `select_only(self, void arg0, int docallbacks = 0) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Static methods defined here: scrollbar_width(*args) `scrollbar_width(int b) scrollbar_width() -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: ALWAYS_ON = 4 BOTH = 3 BOTH_ALWAYS = 7 HORIZONTAL = 1 HORIZONTAL_ALWAYS = 5 VERTICAL = 2 VERTICAL_ALWAYS = 6 __swig_destroy__ = <built-in function delete_Fl_Browser_> `delete_Fl_Browser_(Fl_Browser_ self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Button(Fl_Widget)
`` | `Buttons generate callbacks when they are clicked by the user. You control exactly when and how by changing the values for type() and when(). Buttons can also generate callbacks in response to FL_SHORTCUT events. The button can either have an explicit shortcut() value or a letter shortcut can be indicated in the label() with an '&' character before it. For the label shortcut it does not matter if Alt is held down, but if you have an input field in the same window, the user will have to hold down the Alt key so that the input field does not eat the event first as an FL_KEYBOARD event.`
| Method resolution order: Fl_Button Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Button` __repr__ = _swig_repr(self) clear(self, *args) `clear(self) -> int` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` set(self, *args) `set(self) -> int` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s) shortcut(self, char s)` value(self, *args) `value(self, int arg0) -> int value(self) -> char` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Button> `delete_Fl_Button(Fl_Button self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Chart(Fl_Widget)
`` | `This widget displays simple charts and is provided for Forms compatibility.`
| Method resolution order: Fl_Chart Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Chart` __repr__ = _swig_repr(self) add(self, *args) `add(self, double arg0, char arg1 = None, unsigned int arg2 = 0)` autosize(self, *args) `autosize(self) -> uchar autosize(self, uchar n)` bounds(self, *args) `bounds(self, double a, double b) bounds(self, double a, double b)` clear(self, *args) `clear(self)` draw(self, *args) `draw(self)` insert(self, *args) `insert(self, int arg0, double arg1, char arg2 = None, unsigned int arg3 = 0)` maxsize(self, *args) `maxsize(self) -> int maxsize(self, int arg0)` replace(self, *args) `replace(self, int arg0, double arg1, char arg2 = None, unsigned int arg3 = 0)` size(self, *args) `size(self) -> int size(self, int W, int H)` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Chart> `delete_Fl_Chart(Fl_Chart self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Check_Browser(Fl_Browser_)
`` | `The Fl_Check_Browser widget displays a scrolling list of text lines that may be selected and/or checked by the user.`
| Method resolution order: Fl_Check_Browser Fl_Browser_ Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Check_Browser` __repr__ = _swig_repr(self) add(self, *args) `add(self, char s) -> int add(self, char s, int b) -> int` check_all(self, *args) `check_all(self)` check_none(self, *args) `check_none(self)` checked(self, *args) `checked(self, int item) -> int checked(self, int item, int b)` clear(self, *args) `clear(self)` draw(self, *args) `draw(self)` full_height(self, *args) `full_height(self) -> int` full_width(self, *args) `full_width(self) -> int` handle(self, *args) `handle(self, int arg0) -> int` incr_height(self, *args) `incr_height(self) -> int` item_draw(self, *args) `item_draw(self, void arg0, int arg1, int arg2, int arg3, int arg4)` item_first(self, *args) `item_first(self) -> void` item_height(self, *args) `item_height(self, void arg0) -> int` item_next(self, *args) `item_next(self, void arg0) -> void` item_prev(self, *args) `item_prev(self, void arg0) -> void` item_quick_height(self, *args) `item_quick_height(self, void arg0) -> int` item_select(self, *args) `item_select(self, void arg0, int arg1 = 1)` item_selected(self, *args) `item_selected(self, void arg0) -> int` item_width(self, *args) `item_width(self, void arg0) -> int` nchecked(self, *args) `nchecked(self) -> int` nitems(self, *args) `nitems(self) -> int` remove(self, *args) `remove(self, int item) -> int` set_checked(self, *args) `set_checked(self, int item)` text(self, *args) `text(self, int item) -> char` value(self, *args) `value(self) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Check_Browser> `delete_Fl_Check_Browser(Fl_Check_Browser self)` Methods inherited from Fl_Browser_: deselect(self, *args) `deselect(self, int docallbacks = 0) -> int` display(self, *args) `display(self, void arg0)` getHScrollbar(self, *args) `getHScrollbar(self) -> Fl_Scrollbar` getScrollbar(self, *args) `getScrollbar(self) -> Fl_Scrollbar` has_scrollbar(self, *args) `has_scrollbar(self) -> uchar has_scrollbar(self, uchar i)` hposition(self, *args) `hposition(self) -> int hposition(self, int arg0)` position(self, *args) `position(self) -> int position(self, int arg0)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` scrollbar_left(self, *args) `scrollbar_left(self)` scrollbar_right(self, *args) `scrollbar_right(self)` select(self, *args) `select(self, void arg0, int arg1 = 1, int docallbacks = 0) -> int` select_only(self, *args) `select_only(self, void arg0, int docallbacks = 0) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Static methods inherited from Fl_Browser_: scrollbar_width(*args) `scrollbar_width(int b) scrollbar_width() -> int` Data and other attributes inherited from Fl_Browser_: ALWAYS_ON = 4 BOTH = 3 BOTH_ALWAYS = 7 HORIZONTAL = 1 HORIZONTAL_ALWAYS = 5 VERTICAL = 2 VERTICAL_ALWAYS = 6 Methods inherited from Fl_Group: add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Check_Button(Fl_Light_Button)
`` | `Buttons generate callbacks when they are clicked by the user. You control exactly when and how by changing the values for type() and when(). The Fl_Check_Button subclass display the 'on' state by turning on a light, rather than drawing pushed in. The shape of the 'light' is initially set to FL_DIAMOND_DOWN_BOX. The color of the light when on is controlled with selection_color(), which defaults to FL_RED.`
| Method resolution order: Fl_Check_Button Fl_Light_Button Fl_Button Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Check_Button` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Check_Button> `delete_Fl_Check_Button(Fl_Check_Button self)` Methods inherited from Fl_Light_Button: handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Button: clear(self, *args) `clear(self) -> int` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` set(self, *args) `set(self) -> int` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s) shortcut(self, char s)` value(self, *args) `value(self, int arg0) -> int value(self) -> char` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Choice(Fl_Menu_)
`` | `This is a button that when pushed pops up a menu (or hierarchy of menus) defined by an array of Fl_Menu_Item objects. Motif calls this an OptionButton. The only difference between this and a Fl_Menu_Button is that the name of the most recent chosen menu item is displayed inside the box, while the label is displayed outside the box. However, since the use of this is most often to control a single variable rather than do individual callbacks, some of the Fl_Menu_Button methods are redescribed here in those terms. When the user picks an item off the menu the value() is set to that item and then the item's callback is done with the menu_button as the Fl_Widget argument. If the item does not have a callback the menu_button's callback is done instead. All three mouse buttons pop up the menu. The Forms behavior of the first two buttons to increment/decrement the choice is not implemented. This could be added with a subclass, however. The menu will also pop up in response to shortcuts indicated by putting a '&' character in the label(). See Fl_Button for a description of this. Typing the shortcut() of any of the items will do exactly the same as when you pick the item with the mouse. The '&' character in item names are only looked at when the menu is popped up, however.`
| Method resolution order: Fl_Choice Fl_Menu_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Choice` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` value(self, *args) `value(self, int i) -> int value(self) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Choice> `delete_Fl_Choice(Fl_Choice self)` Methods inherited from Fl_Menu_: add(self, *args) `add(self, char arg0, int shortcut, Fl_Callback arg2, void arg3 = None, int arg4 = 0) -> int add(self, char arg0) -> int add(self, PyObject lObj, PyObject sObj, PyObject cObj, PyObject uObj = None, PyObject fObj = None) -> int` clear(self, *args) `clear(self)` copy(self, *args) `copy(self, Fl_Menu_Item m, void user_data = None) copy(self, PyObject args, PyObject user_data = None)` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` find_item(self, *args) `find_item(self, char name) -> Fl_Menu_Item` item_pathname(self, *args) `item_pathname(self, char name, int namelen, Fl_Menu_Item finditem = None) -> int` menu(self, *args) `menu(self) -> Fl_Menu_Item menu(self, PyObject args) menu(self) -> PyObject` mode(self, *args) `mode(self, int i, int fl) mode(self, int i) -> int` mvalue(self, *args) `mvalue(self) -> Fl_Menu_Item` picked(self, *args) `picked(self, Fl_Menu_Item arg0) -> Fl_Menu_Item` remove(self, *args) `remove(self, int arg0)` replace(self, *args) `replace(self, int arg0, char arg1)` shortcut(self, *args) `shortcut(self, int i, int s)` size(self, *args) `size(self) -> int size(self, int W, int H)` test_shortcut(self, *args) `test_shortcut(self) -> Fl_Menu_Item` text(self, *args) `text(self) -> char text(self, int i) -> char` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int c)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar c)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar c)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Clock(Fl_Clock_Output)
`` | `This widget provides a round analog clock display and is provided for Forms compatibility. It installs a 1-second timeout callback using Fl.add_timeout().`
| Method resolution order: Fl_Clock Fl_Clock_Output Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Clock __init__(self, uchar t, int x, int y, int w, int h, char l) -> Fl_Clock` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Clock> `delete_Fl_Clock(Fl_Clock self)` Methods inherited from Fl_Clock_Output: hour(self, *args) `hour(self) -> int` minute(self, *args) `minute(self) -> int` second(self, *args) `second(self) -> int` value(self, *args) `value(self, ulong v) value(self, int arg0, int arg1, int arg2) value(self) -> ulong` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Clock_Output(Fl_Widget)
`` | `Proxy of C++ Fl_Clock_Output class`
| Method resolution order: Fl_Clock_Output Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Clock_Output` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` hour(self, *args) `hour(self) -> int` minute(self, *args) `minute(self) -> int` second(self, *args) `second(self) -> int` value(self, *args) `value(self, ulong v) value(self, int arg0, int arg1, int arg2) value(self) -> ulong` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Clock_Output> `delete_Fl_Clock_Output(Fl_Clock_Output self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Color_Chooser(Fl_Group)
`` | `The Fl_Color_Chooser widget provides a standard RGB color chooser. You can place any number of these into a panel of your own design. This widget contains the hue box, value slider, and rgb input fields from the above diagram (it does not have the color chips or the Cancel or OK buttons). The callback is done every time the user changes the rgb value. It is not done if they move the hue control in a way that produces the same rgb value, such as when saturation or value is zero.`
| Method resolution order: Fl_Color_Chooser Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Color_Chooser` __repr__ = _swig_repr(self) b(self, *args) `b(self) -> double` draw(self, *args) `draw(self)` g(self, *args) `g(self) -> double` hsv(self, *args) `hsv(self, double arg0, double arg1, double arg2) -> int` hue(self, *args) `hue(self) -> double` mode(self, *args) `mode(self) -> int` r(self, *args) `r(self) -> double` rgb(self, *args) `rgb(self, double arg0, double arg1, double arg2) -> int` saturation(self, *args) `saturation(self) -> double` value(self, *args) `value(self) -> double` Static methods defined here: hsv2rgb(*args) `hsv2rgb(double arg0, double arg1, double arg2, double arg3, double arg4, double arg5)` rgb2hsv(*args) `rgb2hsv(double arg0, double arg1, double arg2, double arg3, double arg4, double arg5)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Color_Chooser> `delete_Fl_Color_Chooser(Fl_Color_Chooser self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` handle(self, *args) `handle(self, int arg0) -> int` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Counter(Fl_Valuator)
`` | `The Fl_Counter widget is provided for forms compatibility. It controls a single floating point value.`
| Method resolution order: Fl_Counter Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Counter` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` lstep(self, *args) `lstep(self, double a)` step(self, *args) `step(self, double a, double b) step(self, double a)` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int s)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Counter> `delete_Fl_Counter(Fl_Counter self)` Methods inherited from Fl_Valuator: bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Dial(Fl_Valuator)
`` | `The Fl_Dial widget provides a circular dial to control a single floating point value.`
| Method resolution order: Fl_Dial Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Dial` __repr__ = _swig_repr(self) angle1(self, *args) `angle1(self) -> short angle1(self, short a)` angle2(self, *args) `angle2(self) -> short angle2(self, short a)` angles(self, *args) `angles(self, short a, short b)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Dial> `delete_Fl_Dial(Fl_Dial self)` Methods inherited from Fl_Valuator: bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Double_Window(Fl_Window)
`` | `The Fl_Double_Window class provides a double-buffered window. If possible this will use the X double buffering extension (Xdbe). If not, it will draw the window data into an off-screen pixmap, and then copy it to the on-screen window. It is highly recommended that you put the following code before the first show() of any window in your program: Fl.visual(FL_DOUBLE|FL_INDEX) This makes sure you can use Xdbe on servers where double buffering does not exist for every visual.`
| Method resolution order: Fl_Double_Window Fl_Window Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int W, int H, char l = None) -> Fl_Double_Window __init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Double_Window` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` flush(self, *args) `flush(self)` hide(self, *args) `hide(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` show(self, *args) `show(self, PyObject count = None, PyObject data = None)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Double_Window> `delete_Fl_Double_Window(Fl_Double_Window self)` Methods inherited from Fl_Window: border(self, *args) `border(self, int b) border(self) -> int` clear_border(self, *args) `clear_border(self)` copy_label(self, *args) `copy_label(self, char a)` cursor(self, *args) `cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` default_cursor(self, *args) `default_cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` free_position(self, *args) `free_position(self)` fullscreen(self, *args) `fullscreen(self)` fullscreen_off(self, *args) `fullscreen_off(self, int arg0, int arg1, int arg2, int arg3)` handle(self, *args) `handle(self, int arg0) -> int` hotspot(self, *args) `hotspot(self, int x, int y, int offscreen = 0) hotspot(self, Fl_Widget arg0, int offscreen = 0)` icon(self, *args) `icon(self) -> void icon(self, void ic)` iconize(self, *args) `iconize(self)` iconlabel(self, *args) `iconlabel(self) -> char iconlabel(self, char arg0)` label(self, *args) `label(self) -> char label(self, char arg0) label(self, char label, char iconlabel)` make_current(self, *args) `make_current(self)` modal(self, *args) `modal(self) -> int` non_modal(self, *args) `non_modal(self) -> int` override(self, *args) `override(self) -> int` set_modal(self, *args) `set_modal(self)` set_non_modal(self, *args) `set_non_modal(self)` set_override(self, *args) `set_override(self)` shown(self, *args) `shown(self) -> int` size_range(self, *args) `size_range(self, int a, int b, int c = 0, int d = 0, int e = 0, int f = 0, int g = 0)` x_root(self, *args) `x_root(self) -> int` xclass(self, *args) `xclass(self) -> char xclass(self, char c)` y_root(self, *args) `y_root(self) -> int` Static methods inherited from Fl_Window: current(*args) `current() -> Fl_Window` default_callback(*args) `default_callback(Fl_Window arg0, void v)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_End(__builtin__.object)
`` | `Proxy of C++ Fl_End class`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Fl_End` __repr__ = _swig_repr(self) Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_End> `delete_Fl_End(Fl_End self)`
class Fl_File_Browser(Fl_Browser)
`` | `The Fl_File_Browser widget displays a list of filenames, optionally with file-specific icons.`
| Method resolution order: Fl_File_Browser Fl_Browser Fl_Browser_ Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_File_Browser` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` filetype(self, *args) `filetype(self) -> int filetype(self, int t)` filter(self, *args) `filter(self, char pattern) filter(self) -> char` full_height(self, *args) `full_height(self) -> int` full_width(self, *args) `full_width(self) -> int` iconsize(self, *args) `iconsize(self) -> uchar iconsize(self, uchar s)` incr_height(self, *args) `incr_height(self) -> int` item_draw(self, *args) `item_draw(self, void arg0, int arg1, int arg2, int arg3, int arg4)` item_first(self, *args) `item_first(self) -> void` item_height(self, *args) `item_height(self, void arg0) -> int` item_next(self, *args) `item_next(self, void arg0) -> void` item_prev(self, *args) `item_prev(self, void arg0) -> void` item_quick_height(self, *args) `item_quick_height(self, void arg0) -> int` item_select(self, *args) `item_select(self, void arg0, int arg1)` item_selected(self, *args) `item_selected(self, void arg0) -> int` item_width(self, *args) `item_width(self, void arg0) -> int` load(self, *args) `load(self, PyObject dObj, PyObject sObj) -> int` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: DIRECTORIES = 1 FILES = 0 __swig_destroy__ = <built-in function delete_Fl_File_Browser> `delete_Fl_File_Browser(Fl_File_Browser self)` Methods inherited from Fl_Browser: add(self, *args) `add(self, char text, PyObject data = None)` bottomline(self, *args) `bottomline(self, int l)` clear(self, *args) `clear(self)` column_char(self, *args) `column_char(self) -> char column_char(self, char c)` column_widths(self, *args) `column_widths(self) -> int column_widths(self, PyObject widths)` data(self, *args) `data(self, int index, PyObject data = None) -> PyObject` display(self, *args) `display(self, int arg0, int arg1 = 1)` displayed(self, *args) `displayed(self, int n) -> int` format_char(self, *args) `format_char(self) -> char format_char(self, char c)` get_data(self, *args) `get_data(self, int index) -> PyObject` hide(self, *args) `hide(self, int n) hide(self)` insert(self, *args) `insert(self, int index, char text, PyObject data = None)` lineposition(self, *args) `lineposition(self, int arg0, Fl_Line_Position arg1)` make_visible(self, *args) `make_visible(self, int n)` middleline(self, *args) `middleline(self, int l)` move(self, *args) `move(self, int to, int _from)` remove(self, *args) `remove(self, int arg0)` replace(self, *args) `replace(self, int a, char b)` select(self, *args) `select(self, int arg0, int arg1 = 1) -> int` selected(self, *args) `selected(self, int arg0) -> int` show(self, *args) `show(self, int n) show(self)` size(self, *args) `size(self) -> int size(self, int W, int H)` swap(self, *args) `swap(self, int a, int b)` text(self, *args) `text(self, int arg0) -> char text(self, int arg0, char arg1)` topline(self, *args) `topline(self) -> int topline(self, int l)` value(self, *args) `value(self) -> int value(self, int v)` visible(self, *args) `visible(self, int n) -> int` Data and other attributes inherited from Fl_Browser: BOTTOM = 1 MIDDLE = 2 TOP = 0 Methods inherited from Fl_Browser_: deselect(self, *args) `deselect(self, int docallbacks = 0) -> int` getHScrollbar(self, *args) `getHScrollbar(self) -> Fl_Scrollbar` getScrollbar(self, *args) `getScrollbar(self) -> Fl_Scrollbar` handle(self, *args) `handle(self, int arg0) -> int` has_scrollbar(self, *args) `has_scrollbar(self) -> uchar has_scrollbar(self, uchar i)` hposition(self, *args) `hposition(self) -> int hposition(self, int arg0)` position(self, *args) `position(self) -> int position(self, int arg0)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` scrollbar_left(self, *args) `scrollbar_left(self)` scrollbar_right(self, *args) `scrollbar_right(self)` select_only(self, *args) `select_only(self, void arg0, int docallbacks = 0) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` Static methods inherited from Fl_Browser_: scrollbar_width(*args) `scrollbar_width(int b) scrollbar_width() -> int` Data and other attributes inherited from Fl_Browser_: ALWAYS_ON = 4 BOTH = 3 BOTH_ALWAYS = 7 HORIZONTAL = 1 HORIZONTAL_ALWAYS = 5 VERTICAL = 2 VERTICAL_ALWAYS = 6 Methods inherited from Fl_Group: add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_File_Chooser(__builtin__.object)
`` | `The Fl_File_Chooser widget displays a standard file selection dialog that supports various selection modes. The Fl_File_Chooser class also exports several static values that may be used to localize or customize the appearance of all file chooser dialogs: Member Default value add_favorites_label 'Add to Favorites' all_files_label 'All Files (*)' custom_filter_label 'Custom Filter' existing_file_label 'Please choose an existing file!' favorites_label 'Favorites' filename_label 'Filename:' filesystems_label 'My Computer' (WIN32) 'File Systems' (all others) manage_favorites_label 'Manage Favorites' new_directory_label 'New Directory?' new_directory_tooltip 'Create a new directory.' preview_label 'Preview' save_label 'Save' show_label 'Show:' sort fl_numericsort The sort member specifies the sort function that is used when loading the contents of a directory.`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self, char d, char p, int t, char title) -> Fl_File_Chooser` __repr__ = _swig_repr(self) callback = __Fl_File_ChooserCallback(self, *args) color(self, *args) `color(self, Fl_Color c) color(self) -> Fl_Color` count(self, *args) `count(self) -> int` directory(self, *args) `directory(self, char d) directory(self) -> char` filter(self, *args) `filter(self, char p) filter(self) -> char` filter_value(self, *args) `filter_value(self) -> int filter_value(self, int f)` hide(self, *args) `hide(self)` iconsize(self, *args) `iconsize(self, uchar s) iconsize(self) -> uchar` label(self, *args) `label(self, char l) label(self) -> char` ok_label(self, *args) `ok_label(self, char l) ok_label(self) -> char` preview(self, *args) `preview(self, int e) preview(self) -> int` rescan(self, *args) `rescan(self)` show(self, *args) `show(self)` shown(self, *args) `shown(self) -> int` textcolor(self, *args) `textcolor(self, Fl_Color c) textcolor(self) -> Fl_Color` textfont(self, *args) `textfont(self, uchar f) textfont(self) -> uchar` textsize(self, *args) `textsize(self, uchar s) textsize(self) -> uchar` type(self, *args) `type(self, int t) type(self) -> int` user_data(self, *args) `user_data(self) user_data(self, void d)` value(self, *args) `value(self, int f = 1) -> char value(self, char filename)` visible(self, *args) `visible(self) -> int` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: CREATE = 2 DIRECTORY = 4 MULTI = 1 SINGLE = 0 __swig_destroy__ = <built-in function delete_Fl_File_Chooser> `delete_Fl_File_Chooser(Fl_File_Chooser self)`
class Fl_File_Icon(__builtin__.object)
`` | `The Fl_File_Icon class manages icon images that can be used as labels in other widgets and as icons in the FileBrowser widget.`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self, char p, int t, int nd = 0, short d = None) -> Fl_File_Icon` __repr__ = _swig_repr(self) add(self, *args) `add(self, short d) -> short` add_color(self, *args) `add_color(self, Fl_Color c) -> short` add_vertex(self, *args) `add_vertex(self, int x, int y) -> short add_vertex(self, float x, float y) -> short` clear(self, *args) `clear(self)` draw(self, *args) `draw(self, int x, int y, int w, int h, Fl_Color ic, int active = 1)` label(self, *args) `label(self, Fl_Widget w)` load(self, *args) `load(self, char f)` load_fti(self, *args) `load_fti(self, char fti) -> int` load_image(self, *args) `load_image(self, char i) -> int` next(self, *args) `next(self) -> Fl_File_Icon` pattern(self, *args) `pattern(self) -> char` size(self, *args) `size(self) -> int` type(self, *args) `type(self) -> int` value(self, *args) `value(self) -> short` Static methods defined here: find(*args) `find(char filename, int filetype = ANY) -> Fl_File_Icon` first(*args) `first() -> Fl_File_Icon` labeltype(*args) `labeltype(Fl_Label o, int x, int y, int w, int h, Fl_Align a)` load_system_icons(*args) `load_system_icons()` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: ANY = 0 CLOSEDLINE = 3 COLOR = 1 DEVICE = 3 DIRECTORY = 5 END = 0 FIFO = 2 LINE = 2 LINK = 4 OUTLINEPOLYGON = 5 PLAIN = 1 POLYGON = 4 VERTEX = 6 __swig_destroy__ = <built-in function delete_Fl_File_Icon> `delete_Fl_File_Icon(Fl_File_Icon self)`
class Fl_File_Input(Fl_Input)
`` | `This widget displays a pathname in a text input field. A navigation bar located above the input field allows the user to navigate upward in the directory tree.`
| Method resolution order: Fl_File_Input Fl_Input Fl_Input_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char t = None) -> Fl_File_Input` __repr__ = _swig_repr(self) down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` draw(self, *args) `draw(self)` errorcolor(self, *args) `errorcolor(self) -> Fl_Color errorcolor(self, Fl_Color c)` handle(self, *args) `handle(self, int arg0) -> int` value(self, *args) `value(self, char arg0) -> int value(self, char arg0, int arg1) -> int value(self) -> char` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_File_Input> `delete_Fl_File_Input(Fl_File_Input self)` Methods inherited from Fl_Input_: copy(self, *args) `copy(self, int clipboard) -> int` copy_cuts(self, *args) `copy_cuts(self) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` cut(self, *args) `cut(self) -> int cut(self, int n) -> int cut(self, int a, int b) -> int` index(self, *args) `index(self, int i) -> char` input_type(self, *args) `input_type(self) -> int input_type(self, int t)` insert(self, *args) `insert(self, char t, int l = 0) -> int` mark(self, *args) `mark(self) -> int mark(self, int m) -> int` maximum_size(self, *args) `maximum_size(self) -> int maximum_size(self, int m)` position(self, *args) `position(self) -> int position(self, int p, int m) -> int position(self, int p) -> int` readonly(self, *args) `readonly(self) -> int readonly(self, int b)` replace(self, *args) `replace(self, int arg0, int arg1, char arg2, int arg3 = 0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` size(self, *args) `size(self) -> int size(self, int W, int H)` static_value(self, *args) `static_value(self, char arg0) -> int static_value(self, char arg0, int arg1) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` undo(self, *args) `undo(self) -> int` wrap(self, *args) `wrap(self) -> int wrap(self, int b)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Fill_Dial(Fl_Dial)
`` | `The Fl_Fill_Dial widget provides a filled, circular dial to control a single floating point value.`
| Method resolution order: Fl_Fill_Dial Fl_Dial Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Fill_Dial` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Fill_Dial> `delete_Fl_Fill_Dial(Fl_Fill_Dial self)` Methods inherited from Fl_Dial: angle1(self, *args) `angle1(self) -> short angle1(self, short a)` angle2(self, *args) `angle2(self) -> short angle2(self, short a)` angles(self, *args) `angles(self, short a, short b)` handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Valuator: bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Fill_Slider(Fl_Slider)
`` | `The Fl_Fill_Slider widget contains a sliding knob inside a box. It if often used as a scrollbar. Moving the box all the way to the top/left sets it to the minimum(), and to the bottom/right to the maximum(). The minimum() may be greater than the maximum() to reverse the slider direction.`
| Method resolution order: Fl_Fill_Slider Fl_Slider Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Fill_Slider` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Fill_Slider> `delete_Fl_Fill_Slider(Fl_Fill_Slider self)` Methods inherited from Fl_Slider: bounds(self, *args) `bounds(self, double a, double b)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` scrollvalue(self, *args) `scrollvalue(self, int windowtop, int windowsize, int first, int totalsize) -> int` slider(self, *args) `slider(self) -> Fl_Boxtype slider(self, Fl_Boxtype c)` slider_size(self, *args) `slider_size(self) -> float slider_size(self, double v)` Methods inherited from Fl_Valuator: clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Float_Input(Fl_Input)
`` | `The Fl_Float_Input class is a subclass of Fl_Input that only allows the user to type floating point numbers (sign, digits, decimal point, more digits, 'E' or 'e', sign, digits).`
| Method resolution order: Fl_Float_Input Fl_Input Fl_Input_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Float_Input` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Float_Input> `delete_Fl_Float_Input(Fl_Float_Input self)` Methods inherited from Fl_Input: draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Input_: copy(self, *args) `copy(self, int clipboard) -> int` copy_cuts(self, *args) `copy_cuts(self) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` cut(self, *args) `cut(self) -> int cut(self, int n) -> int cut(self, int a, int b) -> int` index(self, *args) `index(self, int i) -> char` input_type(self, *args) `input_type(self) -> int input_type(self, int t)` insert(self, *args) `insert(self, char t, int l = 0) -> int` mark(self, *args) `mark(self) -> int mark(self, int m) -> int` maximum_size(self, *args) `maximum_size(self) -> int maximum_size(self, int m)` position(self, *args) `position(self) -> int position(self, int p, int m) -> int position(self, int p) -> int` readonly(self, *args) `readonly(self) -> int readonly(self, int b)` replace(self, *args) `replace(self, int arg0, int arg1, char arg2, int arg3 = 0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` size(self, *args) `size(self) -> int size(self, int W, int H)` static_value(self, *args) `static_value(self, char arg0) -> int static_value(self, char arg0, int arg1) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` undo(self, *args) `undo(self) -> int` value(self, *args) `value(self, char arg0) -> int value(self, char arg0, int arg1) -> int value(self) -> char` wrap(self, *args) `wrap(self) -> int wrap(self, int b)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_FormsBitmap(Fl_Widget)
`` | `Proxy of C++ Fl_FormsBitmap class`
| Method resolution order: Fl_FormsBitmap Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, Fl_Boxtype arg0, int arg1, int arg2, int arg3, int arg4, char arg5 = None) -> Fl_FormsBitmap` __repr__ = _swig_repr(self) bitmap(self, *args) `bitmap(self, Fl_Bitmap B) bitmap(self) -> Fl_Bitmap` draw(self, *args) `draw(self)` set(self, *args) `set(self, int W, int H, uchar bits)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_FormsBitmap> `delete_Fl_FormsBitmap(Fl_FormsBitmap self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_FormsPixmap(Fl_Widget)
`` | `Proxy of C++ Fl_FormsPixmap class`
| Method resolution order: Fl_FormsPixmap Fl_Widget __builtin__.object Methods defined here: Pixmap(self, *args) `Pixmap(self, Fl_Pixmap B) Pixmap(self) -> Fl_Pixmap` __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, Fl_Boxtype arg0, int arg1, int arg2, int arg3, int arg4, char arg5 = None) -> Fl_FormsPixmap` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` set(self, *args) `set(self, char bits)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_FormsPixmap> `delete_Fl_FormsPixmap(Fl_FormsPixmap self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Free(Fl_Widget)
`` | `Emulation of the Forms 'free' widget. This emulation allows the free demo to run, and appears to be useful for porting programs written in Forms which use the free widget or make subclasses of the Forms widgets. There are five types of free, which determine when the handle function is called: FL_NORMAL_FREE 1 FL_SLEEPING_FREE 2 FL_INPUT_FREE 3 FL_CONTINUOUS_FREE 4 FL_ALL_FREE 5 An FL_INPUT_FREE accepts FL_FOCUS events. A FL_CONTINUOUS_FREE sets a timeout callback 100 times a second and provides a FL_STEP event, this has obvious detrimental effects on machine performance. FL_ALL_FREE does both. FL_SLEEPING_FREE are deactivated.`
| Method resolution order: Fl_Free Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, uchar t, int x, int y, int w, int h, char l, FL_HANDLEPTR hdl) -> Fl_Free` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Free> `delete_Fl_Free(Fl_Free self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_GIF_Image(Fl_Pixmap)
`` | `The Fl_GIF_Image class supports loading, caching, and drawing of Compuserve GIF images. The class loads the first image and supports transparency.`
| Method resolution order: Fl_GIF_Image Fl_Pixmap Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, char filename) -> Fl_GIF_Image` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_GIF_Image> `delete_Fl_GIF_Image(Fl_GIF_Image self)` Methods inherited from Fl_Pixmap: color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` uncache(self, *args) `uncache(self)` Methods inherited from Fl_Image: count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Gl_Window(Fl_Window)
`` | `The Fl_Gl_Window widget sets things up so OpenGL works, and also keeps an OpenGL 'context' for that window, so that changes to the lighting and projection may be reused between redraws. Fl_Gl_Window also flushes the OpenGL streams and swaps buffers after draw() returns. OpenGL hardware typically provides some overlay bit planes, which are very useful for drawing UI controls atop your 3D graphics. If the overlay hardware is not provided, FLTK tries to simulate the overlay, This works pretty well if your graphics are double buffered, but not very well for single-buffered.`
| Method resolution order: Fl_Gl_Window Fl_Window Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int W, int H, char l = None) -> Fl_Gl_Window __init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Gl_Window` __repr__ = _swig_repr(self) can_do(self, *args) `can_do(self, int m) -> int can_do(self, int m) -> int can_do(self) -> int` can_do_overlay(self, *args) `can_do_overlay(self) -> int` context(self, *args) `context(self) context(self, void arg0, int destroy_flag = 0)` context_valid(self, *args) `context_valid(self) -> char context_valid(self, char v)` draw(self, *args) `draw(self)` drawPixels(self, *args) `drawPixels(self, PyObject rgb_py) Writes a raw RGB string to the canvas. Arguments: - rgb - a string of width * height * 3 bytes, comprising the raw image in RGB format` flush(self, *args) `flush(self)` hide(self, *args) `hide(self)` hide_overlay(self, *args) `hide_overlay(self)` invalidate(self, *args) `invalidate(self)` make_current(self, *args) `make_current(self)` make_overlay_current(self, *args) `make_overlay_current(self)` mode(self, *args) `mode(self) -> Fl_Mode mode(self, int a) -> int mode(self, int a) -> int` ortho(self, *args) `ortho(self)` redraw_overlay(self, *args) `redraw_overlay(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` show(self, *args) `show(self, PyObject count = None, PyObject data = None)` swap_buffers(self, *args) `swap_buffers(self)` valid(self, *args) `valid(self) -> char valid(self, char v)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Gl_Window> `delete_Fl_Gl_Window(Fl_Gl_Window self)` Methods inherited from Fl_Window: border(self, *args) `border(self, int b) border(self) -> int` clear_border(self, *args) `clear_border(self)` copy_label(self, *args) `copy_label(self, char a)` cursor(self, *args) `cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` default_cursor(self, *args) `default_cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` free_position(self, *args) `free_position(self)` fullscreen(self, *args) `fullscreen(self)` fullscreen_off(self, *args) `fullscreen_off(self, int arg0, int arg1, int arg2, int arg3)` handle(self, *args) `handle(self, int arg0) -> int` hotspot(self, *args) `hotspot(self, int x, int y, int offscreen = 0) hotspot(self, Fl_Widget arg0, int offscreen = 0)` icon(self, *args) `icon(self) -> void icon(self, void ic)` iconize(self, *args) `iconize(self)` iconlabel(self, *args) `iconlabel(self) -> char iconlabel(self, char arg0)` label(self, *args) `label(self) -> char label(self, char arg0) label(self, char label, char iconlabel)` modal(self, *args) `modal(self) -> int` non_modal(self, *args) `non_modal(self) -> int` override(self, *args) `override(self) -> int` set_modal(self, *args) `set_modal(self)` set_non_modal(self, *args) `set_non_modal(self)` set_override(self, *args) `set_override(self)` shown(self, *args) `shown(self) -> int` size_range(self, *args) `size_range(self, int a, int b, int c = 0, int d = 0, int e = 0, int f = 0, int g = 0)` x_root(self, *args) `x_root(self) -> int` xclass(self, *args) `xclass(self) -> char xclass(self, char c)` y_root(self, *args) `y_root(self) -> int` Static methods inherited from Fl_Window: current(*args) `current() -> Fl_Window` default_callback(*args) `default_callback(Fl_Window arg0, void v)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Group(Fl_Widget)
`` | `The Fl_Group class is the FLTK container widget. It maintains an array of child widgets. These children can themselves be any widget including Fl_Group. The most important subclass of Fl_Group is Fl_Window, however groups can also be used to control radio buttons or to enforce resize behavior.`
| Method resolution order: Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Group` __repr__ = _swig_repr(self) add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` draw(self, *args) `draw(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` handle(self, *args) `handle(self, int arg0) -> int` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` Static methods defined here: current(*args) `current() -> Fl_Group current(Fl_Group g)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Group> `delete_Fl_Group(Fl_Group self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Help_Block(__builtin__.object)
`` | `Proxy of C++ Fl_Help_Block class`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Fl_Help_Block` __repr__ = _swig_repr(self) Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Help_Block> `delete_Fl_Help_Block(Fl_Help_Block self)`
class Fl_Help_Dialog(__builtin__.object)
`` | `The Fl_Help_Dialog widget displays a standard help dialog window using the Fl_Help_View widget.`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Fl_Help_Dialog` __repr__ = _swig_repr(self) h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` load(self, *args) `load(self, char f)` position(self, *args) `position(self, int xx, int yy)` resize(self, *args) `resize(self, int xx, int yy, int ww, int hh)` show(self, *args) `show(self) show(self, int argc, char argv)` textsize(self, *args) `textsize(self, uchar s) textsize(self) -> uchar` topline(self, *args) `topline(self, char n) topline(self, int n)` value(self, *args) `value(self, char f) value(self) -> char` visible(self, *args) `visible(self) -> int` w(self, *args) `w(self) -> int` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Help_Dialog> `delete_Fl_Help_Dialog(Fl_Help_Dialog self)`
class Fl_Help_Link(__builtin__.object)
`` | `Proxy of C++ Fl_Help_Link class`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Fl_Help_Link` __repr__ = _swig_repr(self) Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Help_Link> `delete_Fl_Help_Link(Fl_Help_Link self)`
class Fl_Help_Target(__builtin__.object)
`` | `Proxy of C++ Fl_Help_Target class`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Fl_Help_Target` __repr__ = _swig_repr(self) Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Help_Target> `delete_Fl_Help_Target(Fl_Help_Target self)`
class Fl_Help_View(Fl_Group)
`` | `The Fl_Help_View widget displays HTML text. Most HTML 2.0 elements are supported, as well as a primitive implementation of tables. GIF, JPEG, and PNG images are displayed inline.`
| Method resolution order: Fl_Help_View Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int xx, int yy, int ww, int hh, char l = None) -> Fl_Help_View` __repr__ = _swig_repr(self) clear_selection(self, *args) `clear_selection(self)` directory(self, *args) `directory(self) -> char` draw(self, *args) `draw(self)` filename(self, *args) `filename(self) -> char` find(self, *args) `find(self, char s, int p = 0) -> int` leftline(self, *args) `leftline(self, int arg0) leftline(self) -> int` link = __Fl_Help_ViewLink(self, *args) load(self, *args) `load(self, char f) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` select_all(self, *args) `select_all(self)` size(self, *args) `size(self) -> int size(self, int W, int H)` textcolor(self, *args) `textcolor(self, Fl_Color c) textcolor(self) -> Fl_Color` textfont(self, *args) `textfont(self, uchar f) textfont(self) -> uchar` textsize(self, *args) `textsize(self, uchar s) textsize(self) -> uchar` title(self, *args) `title(self) -> char` topline(self, *args) `topline(self, char n) topline(self, int arg0) topline(self) -> int` value(self, *args) `value(self, char v) value(self) -> char` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Help_View> `delete_Fl_Help_View(Fl_Help_View self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` handle(self, *args) `handle(self, int arg0) -> int` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Hold_Browser(Fl_Browser)
`` | `The Fl_Hold_Browser class is a subclass of Fl_Browser which lets the user select a single item, or no items by clicking on the empty space. As long as the mouse button is held down the item pointed to by it is highlighted, and this highlighting remains on when the mouse button is released. Normally the callback is done when the user releases the mouse, but you can change this with when(). See Fl_Browser for methods to add and remove lines from the browser.`
| Method resolution order: Fl_Hold_Browser Fl_Browser Fl_Browser_ Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Hold_Browser` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` full_height(self, *args) `full_height(self) -> int` full_width(self, *args) `full_width(self) -> int` incr_height(self, *args) `incr_height(self) -> int` item_draw(self, *args) `item_draw(self, void arg0, int arg1, int arg2, int arg3, int arg4)` item_first(self, *args) `item_first(self) -> void` item_height(self, *args) `item_height(self, void arg0) -> int` item_next(self, *args) `item_next(self, void arg0) -> void` item_prev(self, *args) `item_prev(self, void arg0) -> void` item_quick_height(self, *args) `item_quick_height(self, void arg0) -> int` item_select(self, *args) `item_select(self, void arg0, int arg1)` item_selected(self, *args) `item_selected(self, void arg0) -> int` item_width(self, *args) `item_width(self, void arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Hold_Browser> `delete_Fl_Hold_Browser(Fl_Hold_Browser self)` Methods inherited from Fl_Browser: add(self, *args) `add(self, char text, PyObject data = None)` bottomline(self, *args) `bottomline(self, int l)` clear(self, *args) `clear(self)` column_char(self, *args) `column_char(self) -> char column_char(self, char c)` column_widths(self, *args) `column_widths(self) -> int column_widths(self, PyObject widths)` data(self, *args) `data(self, int index, PyObject data = None) -> PyObject` display(self, *args) `display(self, int arg0, int arg1 = 1)` displayed(self, *args) `displayed(self, int n) -> int` format_char(self, *args) `format_char(self) -> char format_char(self, char c)` get_data(self, *args) `get_data(self, int index) -> PyObject` hide(self, *args) `hide(self, int n) hide(self)` insert(self, *args) `insert(self, int index, char text, PyObject data = None)` lineposition(self, *args) `lineposition(self, int arg0, Fl_Line_Position arg1)` load(self, *args) `load(self, char filename) -> int` make_visible(self, *args) `make_visible(self, int n)` middleline(self, *args) `middleline(self, int l)` move(self, *args) `move(self, int to, int _from)` remove(self, *args) `remove(self, int arg0)` replace(self, *args) `replace(self, int a, char b)` select(self, *args) `select(self, int arg0, int arg1 = 1) -> int` selected(self, *args) `selected(self, int arg0) -> int` show(self, *args) `show(self, int n) show(self)` size(self, *args) `size(self) -> int size(self, int W, int H)` swap(self, *args) `swap(self, int a, int b)` text(self, *args) `text(self, int arg0) -> char text(self, int arg0, char arg1)` topline(self, *args) `topline(self) -> int topline(self, int l)` value(self, *args) `value(self) -> int value(self, int v)` visible(self, *args) `visible(self, int n) -> int` Data and other attributes inherited from Fl_Browser: BOTTOM = 1 MIDDLE = 2 TOP = 0 Methods inherited from Fl_Browser_: deselect(self, *args) `deselect(self, int docallbacks = 0) -> int` getHScrollbar(self, *args) `getHScrollbar(self) -> Fl_Scrollbar` getScrollbar(self, *args) `getScrollbar(self) -> Fl_Scrollbar` handle(self, *args) `handle(self, int arg0) -> int` has_scrollbar(self, *args) `has_scrollbar(self) -> uchar has_scrollbar(self, uchar i)` hposition(self, *args) `hposition(self) -> int hposition(self, int arg0)` position(self, *args) `position(self) -> int position(self, int arg0)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` scrollbar_left(self, *args) `scrollbar_left(self)` scrollbar_right(self, *args) `scrollbar_right(self)` select_only(self, *args) `select_only(self, void arg0, int docallbacks = 0) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Static methods inherited from Fl_Browser_: scrollbar_width(*args) `scrollbar_width(int b) scrollbar_width() -> int` Data and other attributes inherited from Fl_Browser_: ALWAYS_ON = 4 BOTH = 3 BOTH_ALWAYS = 7 HORIZONTAL = 1 HORIZONTAL_ALWAYS = 5 VERTICAL = 2 VERTICAL_ALWAYS = 6 Methods inherited from Fl_Group: add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Hor_Fill_Slider(Fl_Slider)
`` | `The Fl_Hor_Fill_Slider widget contains a sliding knob inside a box. It is often used as a scrollbar. Moving the box all the way to the top/left sets it to the minimum(), and to the bottom/right to the maximum(). The minimum() may be greater than the maximum() to reverse the slider direction.`
| Method resolution order: Fl_Hor_Fill_Slider Fl_Slider Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Hor_Fill_Slider` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Hor_Fill_Slider> `delete_Fl_Hor_Fill_Slider(Fl_Hor_Fill_Slider self)` Methods inherited from Fl_Slider: bounds(self, *args) `bounds(self, double a, double b)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` scrollvalue(self, *args) `scrollvalue(self, int windowtop, int windowsize, int first, int totalsize) -> int` slider(self, *args) `slider(self) -> Fl_Boxtype slider(self, Fl_Boxtype c)` slider_size(self, *args) `slider_size(self) -> float slider_size(self, double v)` Methods inherited from Fl_Valuator: clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Hor_Nice_Slider(Fl_Slider)
`` | `The Fl_Hor_Nice_Slider widget contains a sliding knob inside a box. It is often used as a scrollbar. Moving the box all the way to the top/left sets it to the minimum(), and to the bottom/right to the maximum(). The minimum() may be greater than the maximum() to reverse the slider direction.`
| Method resolution order: Fl_Hor_Nice_Slider Fl_Slider Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Hor_Nice_Slider` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Hor_Nice_Slider> `delete_Fl_Hor_Nice_Slider(Fl_Hor_Nice_Slider self)` Methods inherited from Fl_Slider: bounds(self, *args) `bounds(self, double a, double b)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` scrollvalue(self, *args) `scrollvalue(self, int windowtop, int windowsize, int first, int totalsize) -> int` slider(self, *args) `slider(self) -> Fl_Boxtype slider(self, Fl_Boxtype c)` slider_size(self, *args) `slider_size(self) -> float slider_size(self, double v)` Methods inherited from Fl_Valuator: clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Hor_Slider(Fl_Slider)
`` | `The Fl_Hor_Slider widget contains a sliding knob inside a box. It is often used as a scrollbar. Moving the box all the way to the top/left sets it to the minimum(), and to the bottom/right to the maximum(). The minimum() may be greater than the maximum() to reverse the slider direction.`
| Method resolution order: Fl_Hor_Slider Fl_Slider Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Hor_Slider` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Hor_Slider> `delete_Fl_Hor_Slider(Fl_Hor_Slider self)` Methods inherited from Fl_Slider: bounds(self, *args) `bounds(self, double a, double b)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` scrollvalue(self, *args) `scrollvalue(self, int windowtop, int windowsize, int first, int totalsize) -> int` slider(self, *args) `slider(self) -> Fl_Boxtype slider(self, Fl_Boxtype c)` slider_size(self, *args) `slider_size(self) -> float slider_size(self, double v)` Methods inherited from Fl_Valuator: clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Hor_Value_Slider(Fl_Value_Slider)
`` | `The Fl_Hor_Value_Slider widget contains a sliding knob inside a box. It is often used as a scrollbar. Moving the box all the way to the top/left sets it to the minimum(), and to the bottom/right to the maximum(). The minimum() may be greater than the maximum() to reverse the slider direction.`
| Method resolution order: Fl_Hor_Value_Slider Fl_Value_Slider Fl_Slider Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Hor_Value_Slider` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Hor_Value_Slider> `delete_Fl_Hor_Value_Slider(Fl_Hor_Value_Slider self)` Methods inherited from Fl_Value_Slider: draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int s)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Methods inherited from Fl_Slider: bounds(self, *args) `bounds(self, double a, double b)` scrollvalue(self, *args) `scrollvalue(self, int windowtop, int windowsize, int first, int totalsize) -> int` slider(self, *args) `slider(self) -> Fl_Boxtype slider(self, Fl_Boxtype c)` slider_size(self, *args) `slider_size(self) -> float slider_size(self, double v)` Methods inherited from Fl_Valuator: clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Image(__builtin__.object)
`` | `Fl_Image is the base class used for caching and drawing all kinds of images in FLTK. This class keeps track of common image data such as the pixels, colormap, width, height, and depth. Virtual methods are used to provide type-specific image handling. Since the Fl_Image class does not support image drawing by itself, calling the draw() method results in a box with an X in it being drawn instead.`
| Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int W, int H, int D) -> Fl_Image` __repr__ = _swig_repr(self) color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` ld(self, *args) `ld(self) -> int` uncache(self, *args) `uncache(self)` w(self, *args) `w(self) -> int` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Image> `delete_Fl_Image(Fl_Image self)`
class Fl_Input(Fl_Input_)
`` | `This is the FLTK text input widget. It displays a single line of text and lets the user edit it. Normally it is drawn with an inset box and a white background. The text may contain any characters (even 0), and will correctly display anything, using ^X notation for unprintable control characters and nn notation for unprintable characters with the high bit set. It assumes the font can draw any characters in the ISO-8859-1 character set. Mouse button 1 Moves the cursor to this point. Drag selects characters. Double click selects words. Triple click selects all text. Shift+click extends the selection. When you select text it is automatically copied to the clipboard. Mouse button 2 Insert the clipboard at the point clicked. You can also select a region and replace it with the clipboard by selecting the region with mouse button 2. Mouse button 3 Currently acts like button 1. Backspace Deletes one character to the left, or deletes the selected region. Enter May cause the callback, see when(). ^A or Home Go to start of line. ^B or Left Move left ^C Copy the selection to the clipboard ^D or Delete Deletes one character to the right or deletes the selected region. ^E or End Go to the end of line. ^F or Right Move right ^K Delete to the end of line (next character) or deletes a single character. These deletions are all concatenated into the clipboard. ^N or Down Move down (for Fl_Multiline_Input only, otherwise it moves to the next input field). ^P or Up Move up (for Fl_Multiline_Input only, otherwise it moves to the previous input field). ^U Delete everything. ^V or ^Y Paste the clipboard ^X or ^W Copy the region to the clipboard and delete it. ^Z or ^_ Undo. This is a single-level undo mechanism, but all adjacent deletions and insertions are concatenated into a single 'undo'. Often this will undo a lot more than you expected. Shift+move Move the cursor but also extend the selection. RightCtrl or Compose Start a compose-character sequence. The next one or two keys typed define the character to insert (see table that follows.) The character 'nbsp' (non-breaking space) is typed by using [compose][space]. The single-character sequences may be followed by a space if necessary to remove ambiguity. The same key may be used to 'quote' control characters into the text. If you need a ^Q character you can get one by typing [compose][Control+Q]. X may have a key on the keyboard defined as XK_Multi_key. If so this key may be used as well as the right-hand control key. You can set this up with the program xmodmap. If your keyboard is set to support a foreign language you should also be able to type 'dead key' prefix characters. On X you will actually be able to see what dead key you typed, and if you then move the cursor without completing the sequence the accent will remain inserted.`
| Method resolution order: Fl_Input Fl_Input_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Input` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Input> `delete_Fl_Input(Fl_Input self)` Methods inherited from Fl_Input_: copy(self, *args) `copy(self, int clipboard) -> int` copy_cuts(self, *args) `copy_cuts(self) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` cut(self, *args) `cut(self) -> int cut(self, int n) -> int cut(self, int a, int b) -> int` index(self, *args) `index(self, int i) -> char` input_type(self, *args) `input_type(self) -> int input_type(self, int t)` insert(self, *args) `insert(self, char t, int l = 0) -> int` mark(self, *args) `mark(self) -> int mark(self, int m) -> int` maximum_size(self, *args) `maximum_size(self) -> int maximum_size(self, int m)` position(self, *args) `position(self) -> int position(self, int p, int m) -> int position(self, int p) -> int` readonly(self, *args) `readonly(self) -> int readonly(self, int b)` replace(self, *args) `replace(self, int arg0, int arg1, char arg2, int arg3 = 0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` size(self, *args) `size(self) -> int size(self, int W, int H)` static_value(self, *args) `static_value(self, char arg0) -> int static_value(self, char arg0, int arg1) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` undo(self, *args) `undo(self) -> int` value(self, *args) `value(self, char arg0) -> int value(self, char arg0, int arg1) -> int value(self) -> char` wrap(self, *args) `wrap(self) -> int wrap(self, int b)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Input_(Fl_Widget)
`` | `This is a virtual base class below Fl_Input. It has all the same interfaces, but lacks the handle() and draw() method. You may want to subclass it if you are one of those people who likes to change how the editing keys work. This can act like any of the subclasses of Fl_Input, by setting type() to one of the following values: FL_NORMAL_INPUT 0 FL_FLOAT_INPUT 1 FL_INT_INPUT 2 FL_MULTILINE_INPUT 4 FL_SECRET_INPUT 5 FL_INPUT_TYPE 7 FL_INPUT_READONLY 8 FL_NORMAL_OUTPUT (FL_NORMAL_INPUT | FL_INPUT_READONLY) FL_MULTILINE_OUTPUT (FL_MULTILINE_INPUT | FL_INPUT_READONLY) FL_INPUT_WRAP 16 FL_MULTILINE_INPUT_WRAP (FL_MULTILINE_INPUT | FL_INPUT_WRAP) FL_MULTILINE_OUTPUT_WRAP (FL_MULTILINE_INPUT | FL_INPUT_READONLY | FL_INPUT_WRAP)`
| Method resolution order: Fl_Input_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Input_` __repr__ = _swig_repr(self) copy(self, *args) `copy(self, int clipboard) -> int` copy_cuts(self, *args) `copy_cuts(self) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` cut(self, *args) `cut(self) -> int cut(self, int n) -> int cut(self, int a, int b) -> int` index(self, *args) `index(self, int i) -> char` input_type(self, *args) `input_type(self) -> int input_type(self, int t)` insert(self, *args) `insert(self, char t, int l = 0) -> int` mark(self, *args) `mark(self) -> int mark(self, int m) -> int` maximum_size(self, *args) `maximum_size(self) -> int maximum_size(self, int m)` position(self, *args) `position(self) -> int position(self, int p, int m) -> int position(self, int p) -> int` readonly(self, *args) `readonly(self) -> int readonly(self, int b)` replace(self, *args) `replace(self, int arg0, int arg1, char arg2, int arg3 = 0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` size(self, *args) `size(self) -> int size(self, int W, int H)` static_value(self, *args) `static_value(self, char arg0) -> int static_value(self, char arg0, int arg1) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` undo(self, *args) `undo(self) -> int` value(self, *args) `value(self, char arg0) -> int value(self, char arg0, int arg1) -> int value(self) -> char` wrap(self, *args) `wrap(self) -> int wrap(self, int b)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Input_> `delete_Fl_Input_(Fl_Input_ self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw(self, *args) `draw(self)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Input_Choice(Fl_Group)
`` | `A combination of the input widget and a menu button. The user can either type into the input area, or use the menu button chooser on the right, which loads the input area with predefined text. Normally it is drawn with an inset box and a white background. The application can directly access both the input and menu widgets directly, using the menubutton() and input() accessor methods.`
| Method resolution order: Fl_Input_Choice Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Input_Choice` __repr__ = _swig_repr(self) add(self, *args) `add(self, char s)` changed(self, *args) `changed(self) -> int` clear(self, *args) `clear(self)` clear_changed(self, *args) `clear_changed(self)` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` draw(self, *args) `draw(self)` input(self, *args) `input(self) -> Fl_Input` menu(self, *args) `menu(self) -> Fl_Menu_Item menu(self, Fl_Menu_Item m)` menubutton(self, *args) `menubutton(self) -> Fl_Menu_Button` resize(self, *args) `resize(self, int X, int Y, int W, int H)` set_changed(self, *args) `set_changed(self)` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, Fl_Color c)` textfont(self, *args) `textfont(self) -> uchar textfont(self, uchar f)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` value(self, *args) `value(self) -> char value(self, char val) value(self, int val)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Input_Choice> `delete_Fl_Input_Choice(Fl_Input_Choice self)` Methods inherited from Fl_Group: add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` handle(self, *args) `handle(self, int arg0) -> int` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Int_Input(Fl_Input)
`` | `The Fl_Int_Input class is a subclass of Fl_Input that only allows the user to type decimal digits (or hex numbers of the form 0xaef).`
| Method resolution order: Fl_Int_Input Fl_Input Fl_Input_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Int_Input` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Int_Input> `delete_Fl_Int_Input(Fl_Int_Input self)` Methods inherited from Fl_Input: draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Input_: copy(self, *args) `copy(self, int clipboard) -> int` copy_cuts(self, *args) `copy_cuts(self) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` cut(self, *args) `cut(self) -> int cut(self, int n) -> int cut(self, int a, int b) -> int` index(self, *args) `index(self, int i) -> char` input_type(self, *args) `input_type(self) -> int input_type(self, int t)` insert(self, *args) `insert(self, char t, int l = 0) -> int` mark(self, *args) `mark(self) -> int mark(self, int m) -> int` maximum_size(self, *args) `maximum_size(self) -> int maximum_size(self, int m)` position(self, *args) `position(self) -> int position(self, int p, int m) -> int position(self, int p) -> int` readonly(self, *args) `readonly(self) -> int readonly(self, int b)` replace(self, *args) `replace(self, int arg0, int arg1, char arg2, int arg3 = 0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` size(self, *args) `size(self) -> int size(self, int W, int H)` static_value(self, *args) `static_value(self, char arg0) -> int static_value(self, char arg0, int arg1) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` undo(self, *args) `undo(self) -> int` value(self, *args) `value(self, char arg0) -> int value(self, char arg0, int arg1) -> int value(self) -> char` wrap(self, *args) `wrap(self) -> int wrap(self, int b)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_JPEG_Image(Fl_RGB_Image)
`` | `The Fl_JPEG_Image class supports loading, caching, and drawing of Joint Photographic Experts Group (JPEG) File Interchange Format (JFIF) images. The class supports grayscale and color (RGB) JPEG image files.`
| Method resolution order: Fl_JPEG_Image Fl_RGB_Image Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, char filename) -> Fl_JPEG_Image` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_JPEG_Image> `delete_Fl_JPEG_Image(Fl_JPEG_Image self)` Methods inherited from Fl_RGB_Image: color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` uncache(self, *args) `uncache(self)` Methods inherited from Fl_Image: count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Label(__builtin__.object)
`` | `Proxy of C++ Fl_Label class`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Fl_Label` __repr__ = _swig_repr(self) draw(self, *args) `draw(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` measure(self, *args) `measure(self, int arg0, int arg1)` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Label> `delete_Fl_Label(Fl_Label self)`
class Fl_Light_Button(Fl_Button)
`` | `Buttons generate callbacks when they are clicked by the user. You control exactly when and how by changing the values for type() and when(). The Fl_Light_Button subclass display the 'on' state by turning on a light, rather than drawing pushed in. The shape of the 'light' is initially set to FL_DOWN_BOX. The color of the light when on is controlled with selection_color(), which defaults to FL_YELLOW.`
| Method resolution order: Fl_Light_Button Fl_Button Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Light_Button` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Light_Button> `delete_Fl_Light_Button(Fl_Light_Button self)` Methods inherited from Fl_Button: clear(self, *args) `clear(self) -> int` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` set(self, *args) `set(self) -> int` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s) shortcut(self, char s)` value(self, *args) `value(self, int arg0) -> int value(self) -> char` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Line_Dial(Fl_Dial)
`` | `The Fl_Line_Dial widget provides a circular dial to control a single floating point value.`
| Method resolution order: Fl_Line_Dial Fl_Dial Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Line_Dial` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Line_Dial> `delete_Fl_Line_Dial(Fl_Line_Dial self)` Methods inherited from Fl_Dial: angle1(self, *args) `angle1(self) -> short angle1(self, short a)` angle2(self, *args) `angle2(self) -> short angle2(self, short a)` angles(self, *args) `angles(self, short a, short b)` handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Valuator: bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Menu_(Fl_Widget)
`` | `All widgets that have a menu in FLTK are subclassed off of this class. Currently FLTK provides you with Fl_Menu_Button, Fl_Menu_Bar, and Fl_Choice . The class contains a pointer to an array of structures of type Fl_Menu_Item. The array may either be supplied directly by the user program, or it may be 'private': a dynamically allocated array managed by the Fl_Menu_.`
| Method resolution order: Fl_Menu_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Menu_` __repr__ = _swig_repr(self) add(self, *args) `add(self, char arg0, int shortcut, Fl_Callback arg2, void arg3 = None, int arg4 = 0) -> int add(self, char arg0) -> int add(self, PyObject lObj, PyObject sObj, PyObject cObj, PyObject uObj = None, PyObject fObj = None) -> int` clear(self, *args) `clear(self)` copy(self, *args) `copy(self, Fl_Menu_Item m, void user_data = None) copy(self, PyObject args, PyObject user_data = None)` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` find_item(self, *args) `find_item(self, char name) -> Fl_Menu_Item` item_pathname(self, *args) `item_pathname(self, char name, int namelen, Fl_Menu_Item finditem = None) -> int` menu(self, *args) `menu(self) -> Fl_Menu_Item menu(self, PyObject args) menu(self) -> PyObject` mode(self, *args) `mode(self, int i, int fl) mode(self, int i) -> int` mvalue(self, *args) `mvalue(self) -> Fl_Menu_Item` picked(self, *args) `picked(self, Fl_Menu_Item arg0) -> Fl_Menu_Item` remove(self, *args) `remove(self, int arg0)` replace(self, *args) `replace(self, int arg0, char arg1)` shortcut(self, *args) `shortcut(self, int i, int s)` size(self, *args) `size(self) -> int size(self, int W, int H)` test_shortcut(self, *args) `test_shortcut(self) -> Fl_Menu_Item` text(self, *args) `text(self) -> char text(self, int i) -> char` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int c)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar c)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar c)` value(self, *args) `value(self) -> int value(self, int i) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Menu_> `delete_Fl_Menu_(Fl_Menu_ self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw(self, *args) `draw(self)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Menu_Bar(Fl_Menu_)
`` | `This widget provides a standard menubar interface. Usually you will put this widget along the top edge of your window. The height of the widget should be 30 for the menu titles to draw correctly with the default font. The items on the bar and the menus they bring up are defined by a single Fl_Menu_Item array. Because a Fl_Menu_Item array defines a hierarchy, the top level menu defines the items in the menubar, while the submenus define the pull-down menus. Sub-sub menus and lower pop up to the right of the submenus. If there is an item in the top menu that is not a title of a submenu, then it acts like a 'button' in the menubar. Clicking on it will pick it. When the user picks an item off the menu, the item's callback is done with the menubar as the Fl_Widget* argument. If the item does not have a callback the menubar's callback is done instead. Submenus will also pop up in response to shortcuts indicated by putting a '&' character in the name field of the menu item. If you put a '&' character in a top-level 'button' then the shortcut picks it. The '&' character in submenus is ignored until the menu is popped up. Typing the shortcut() of any of the menu items will cause callbacks exactly the same as when you pick the item with the mouse.`
| Method resolution order: Fl_Menu_Bar Fl_Menu_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Menu_Bar` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Menu_Bar> `delete_Fl_Menu_Bar(Fl_Menu_Bar self)` Methods inherited from Fl_Menu_: add(self, *args) `add(self, char arg0, int shortcut, Fl_Callback arg2, void arg3 = None, int arg4 = 0) -> int add(self, char arg0) -> int add(self, PyObject lObj, PyObject sObj, PyObject cObj, PyObject uObj = None, PyObject fObj = None) -> int` clear(self, *args) `clear(self)` copy(self, *args) `copy(self, Fl_Menu_Item m, void user_data = None) copy(self, PyObject args, PyObject user_data = None)` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` find_item(self, *args) `find_item(self, char name) -> Fl_Menu_Item` item_pathname(self, *args) `item_pathname(self, char name, int namelen, Fl_Menu_Item finditem = None) -> int` menu(self, *args) `menu(self) -> Fl_Menu_Item menu(self, PyObject args) menu(self) -> PyObject` mode(self, *args) `mode(self, int i, int fl) mode(self, int i) -> int` mvalue(self, *args) `mvalue(self) -> Fl_Menu_Item` picked(self, *args) `picked(self, Fl_Menu_Item arg0) -> Fl_Menu_Item` remove(self, *args) `remove(self, int arg0)` replace(self, *args) `replace(self, int arg0, char arg1)` shortcut(self, *args) `shortcut(self, int i, int s)` size(self, *args) `size(self) -> int size(self, int W, int H)` test_shortcut(self, *args) `test_shortcut(self) -> Fl_Menu_Item` text(self, *args) `text(self) -> char text(self, int i) -> char` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int c)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar c)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar c)` value(self, *args) `value(self) -> int value(self, int i) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Menu_Button(Fl_Menu_)
`` | `This is a button that when pushed pops up a menu (or hierarchy of menus) defined by an array of Fl_Menu_Item objects. Fl_Menu_Button widget. Normally any mouse button will pop up a menu and it is lined up below the button as shown in the picture. However an Fl_Menu_Button may also control a pop-up menu. This is done by setting the type() , see below. The menu will also pop up in response to shortcuts indicated by putting a '&' character in the label(). Typing the shortcut() of any of the menu items will cause callbacks exactly the same as when you pick the item with the mouse. The '&' character in menu item names are only looked at when the menu is popped up, however. When the user picks an item off the menu, the item's callback is done with the menu_button as the Fl_Widget* argument. If the item does not have a callback the menu_button's callback is done instead.`
| Method resolution order: Fl_Menu_Button Fl_Menu_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Menu_Button` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` popup(self, *args) `popup(self) -> Fl_Menu_Item` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: POPUP1 = 1 POPUP12 = 3 POPUP123 = 7 POPUP13 = 5 POPUP2 = 2 POPUP23 = 6 POPUP3 = 4 __swig_destroy__ = <built-in function delete_Fl_Menu_Button> `delete_Fl_Menu_Button(Fl_Menu_Button self)` Methods inherited from Fl_Menu_: add(self, *args) `add(self, char arg0, int shortcut, Fl_Callback arg2, void arg3 = None, int arg4 = 0) -> int add(self, char arg0) -> int add(self, PyObject lObj, PyObject sObj, PyObject cObj, PyObject uObj = None, PyObject fObj = None) -> int` clear(self, *args) `clear(self)` copy(self, *args) `copy(self, Fl_Menu_Item m, void user_data = None) copy(self, PyObject args, PyObject user_data = None)` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` find_item(self, *args) `find_item(self, char name) -> Fl_Menu_Item` item_pathname(self, *args) `item_pathname(self, char name, int namelen, Fl_Menu_Item finditem = None) -> int` menu(self, *args) `menu(self) -> Fl_Menu_Item menu(self, PyObject args) menu(self) -> PyObject` mode(self, *args) `mode(self, int i, int fl) mode(self, int i) -> int` mvalue(self, *args) `mvalue(self) -> Fl_Menu_Item` picked(self, *args) `picked(self, Fl_Menu_Item arg0) -> Fl_Menu_Item` remove(self, *args) `remove(self, int arg0)` replace(self, *args) `replace(self, int arg0, char arg1)` shortcut(self, *args) `shortcut(self, int i, int s)` size(self, *args) `size(self) -> int size(self, int W, int H)` test_shortcut(self, *args) `test_shortcut(self) -> Fl_Menu_Item` text(self, *args) `text(self) -> char text(self, int i) -> char` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int c)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar c)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar c)` value(self, *args) `value(self) -> int value(self, int i) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Menu_Item(__builtin__.object)
`` | `The Fl_Menu_Item structure defines a single menu item that is used by the Fl_Menu_ class. This structure is defined as Fl_Menu_Item : text -> character array # label() shortcut_ -> unsigned long callback_ -> Fl_Callback user_data_ flags -> int labeltype_ -> unsigned character labelfont_ -> unsigned character labelsize_ -> unsigned character labelcolor_ -> unsigned character enum: # values for flags: FL_MENU_INACTIVE = 1, FL_MENU_TOGGLE = 2, FL_MENU_VALUE = 4, FL_MENU_RADIO = 8, FL_MENU_INVISIBLE = 0x10, FL_SUBMENU_POINTER = 0x20, FL_SUBMENU = 0x40, FL_MENU_DIVIDER = 0x80, FL_MENU_HORIZONTAL = 0x100 Typically menu items are statically defined; for example: MenuTable = ( ('&alpha', FL_ALT+ord('a'), the_cb, 1), ('&beta', FL_ALT+ord('b'), the_cb, 2), ('gamma', FL_ALT+ord('c'), the_cb, 3, FL_MENU_DIVIDER), ('&strange', 0, strange_cb), ('&charm', 0, charm_cb), ('&truth', 0, truth_cb), ('b&eauty', 0, beauty_cb), ('sub&menu', 0, 0, 0, FL_SUBMENU), ('one'), ('two'), ('three'), (None,), ('inactive', FL_ALT+'i', 0, 0, FL_MENU_INACTIVE|FL_MENU_DIVIDER), ('invisible',FL_ALT+'i', 0, 0, FL_MENU_INVISIBLE), ('check', FL_ALT+'i', 0, 0, FL_MENU_TOGGLE|FL_MENU_VALUE), ('box', FL_ALT+'i', 0, 0, FL_MENU_TOGGLE), (None,); A submenu title is identified by the bit FL_SUBMENU in the flags field, and ends with a label() that is NULL. You can nest menus to any depth. A pointer to the first item in the submenu can be treated as an Fl_Menu array itself. It is also possible to make seperate submenu arrays with FL_SUBMENU_POINTER flags. You should use the method functions to access structure members and not access them directly to avoid compatibility problems with future releases of FLTK.`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Fl_Menu_Item` __repr__ = _swig_repr(self) activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` activevisible(self, *args) `activevisible(self) -> int` add(self, *args) `add(self, char arg0, int shortcut, Fl_Callback arg2, void arg3 = None, int arg4 = 0) -> int add(self, char a, char b, Fl_Callback c, void d = None, int e = 0) -> int` argument(self, *args) `argument(self) -> long argument(self, long v)` callback(self, *args) `callback(self, Fl_Callback c, void p) callback(self, Fl_Callback c) callback(self, Fl_Callback0 c) callback(self, Fl_Callback1 c, long p = 0) callback(self) -> PyObject` check(self, *args) `check(self)` checkbox(self, *args) `checkbox(self) -> int` checked(self, *args) `checked(self) -> int` clear(self, *args) `clear(self)` deactivate(self, *args) `deactivate(self)` do_callback(self, *args) `do_callback(self, Fl_Widget o) do_callback(self, Fl_Widget o, void arg) do_callback(self, Fl_Widget o, long arg)` draw(self, *args) `draw(self, int x, int y, int w, int h, Fl_Menu_ arg4, int t = 0)` find_shortcut(self, *args) `find_shortcut(self, int ip = None) -> Fl_Menu_Item` first(self, *args) `first(self) -> Fl_Menu_Item first(self) -> Fl_Menu_Item` hide(self, *args) `hide(self)` image(self, *args) `image(self, Fl_Image a)` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure(self, *args) `measure(self, int h, Fl_Menu_ arg1) -> int` next(self, *args) `next(self, int arg0 = 1) -> Fl_Menu_Item next(self, int i = 1) -> Fl_Menu_Item` popup(self, *args) `popup(self, int X, int Y, char title = None, Fl_Menu_Item picked = None, Fl_Menu_ arg4 = None) -> Fl_Menu_Item` pulldown(self, *args) `pulldown(self, int X, int Y, int W, int H, Fl_Menu_Item picked = None, Fl_Menu_ arg5 = None, Fl_Menu_Item title = None, int menubar = 0) -> Fl_Menu_Item` radio(self, *args) `radio(self) -> int` set(self, *args) `set(self)` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s)` show(self, *args) `show(self)` size(self, *args) `size(self) -> int` submenu(self, *args) `submenu(self) -> int` test_shortcut(self, *args) `test_shortcut(self) -> Fl_Menu_Item` uncheck(self, *args) `uncheck(self)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self) -> PyObject` value(self, *args) `value(self) -> int` visible(self, *args) `visible(self) -> int` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Menu_Item> `delete_Fl_Menu_Item(Fl_Menu_Item self)`
class Fl_Menu_Window(Fl_Single_Window)
`` | `The Fl_Menu_Window widget is a window type used for menus. By default the window is drawn in the hardware overlay planes if they are available so that the menu don't force the rest of the window to redraw.`
| Method resolution order: Fl_Menu_Window Fl_Single_Window Fl_Window Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int W, int H, char l = None) -> Fl_Menu_Window __init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Menu_Window` __repr__ = _swig_repr(self) clear_overlay(self, *args) `clear_overlay(self)` draw(self, *args) `draw(self)` erase(self, *args) `erase(self)` flush(self, *args) `flush(self)` hide(self, *args) `hide(self)` overlay(self, *args) `overlay(self) -> int` set_overlay(self, *args) `set_overlay(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Menu_Window> `delete_Fl_Menu_Window(Fl_Menu_Window self)` Methods inherited from Fl_Single_Window: show(self, *args) `show(self, PyObject count = None, PyObject data = None)` Methods inherited from Fl_Window: border(self, *args) `border(self, int b) border(self) -> int` clear_border(self, *args) `clear_border(self)` copy_label(self, *args) `copy_label(self, char a)` cursor(self, *args) `cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` default_cursor(self, *args) `default_cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` free_position(self, *args) `free_position(self)` fullscreen(self, *args) `fullscreen(self)` fullscreen_off(self, *args) `fullscreen_off(self, int arg0, int arg1, int arg2, int arg3)` handle(self, *args) `handle(self, int arg0) -> int` hotspot(self, *args) `hotspot(self, int x, int y, int offscreen = 0) hotspot(self, Fl_Widget arg0, int offscreen = 0)` icon(self, *args) `icon(self) -> void icon(self, void ic)` iconize(self, *args) `iconize(self)` iconlabel(self, *args) `iconlabel(self) -> char iconlabel(self, char arg0)` label(self, *args) `label(self) -> char label(self, char arg0) label(self, char label, char iconlabel)` make_current(self, *args) `make_current(self)` modal(self, *args) `modal(self) -> int` non_modal(self, *args) `non_modal(self) -> int` override(self, *args) `override(self) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` set_modal(self, *args) `set_modal(self)` set_non_modal(self, *args) `set_non_modal(self)` set_override(self, *args) `set_override(self)` shown(self, *args) `shown(self) -> int` size_range(self, *args) `size_range(self, int a, int b, int c = 0, int d = 0, int e = 0, int f = 0, int g = 0)` x_root(self, *args) `x_root(self) -> int` xclass(self, *args) `xclass(self) -> char xclass(self, char c)` y_root(self, *args) `y_root(self) -> int` Static methods inherited from Fl_Window: current(*args) `current() -> Fl_Window` default_callback(*args) `default_callback(Fl_Window arg0, void v)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Multi_Browser(Fl_Browser)
`` | `The Fl_Multi_Browser class is a subclass of Fl_Browser which lets the user select any set of the lines. The user interface is Macintosh style: clicking an item turns off all the others and selects that one, dragging selects all the items the mouse moves over, and shift + click toggles the items. This is different then how forms did it. Normally the callback is done when the user releases the mouse, but you can change this with when(). See Fl_Browser for methods to add and remove lines from the browser.`
| Method resolution order: Fl_Multi_Browser Fl_Browser Fl_Browser_ Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char L = None) -> Fl_Multi_Browser` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` full_height(self, *args) `full_height(self) -> int` full_width(self, *args) `full_width(self) -> int` incr_height(self, *args) `incr_height(self) -> int` item_draw(self, *args) `item_draw(self, void arg0, int arg1, int arg2, int arg3, int arg4)` item_first(self, *args) `item_first(self) -> void` item_height(self, *args) `item_height(self, void arg0) -> int` item_next(self, *args) `item_next(self, void arg0) -> void` item_prev(self, *args) `item_prev(self, void arg0) -> void` item_quick_height(self, *args) `item_quick_height(self, void arg0) -> int` item_select(self, *args) `item_select(self, void arg0, int arg1)` item_selected(self, *args) `item_selected(self, void arg0) -> int` item_width(self, *args) `item_width(self, void arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Multi_Browser> `delete_Fl_Multi_Browser(Fl_Multi_Browser self)` Methods inherited from Fl_Browser: add(self, *args) `add(self, char text, PyObject data = None)` bottomline(self, *args) `bottomline(self, int l)` clear(self, *args) `clear(self)` column_char(self, *args) `column_char(self) -> char column_char(self, char c)` column_widths(self, *args) `column_widths(self) -> int column_widths(self, PyObject widths)` data(self, *args) `data(self, int index, PyObject data = None) -> PyObject` display(self, *args) `display(self, int arg0, int arg1 = 1)` displayed(self, *args) `displayed(self, int n) -> int` format_char(self, *args) `format_char(self) -> char format_char(self, char c)` get_data(self, *args) `get_data(self, int index) -> PyObject` hide(self, *args) `hide(self, int n) hide(self)` insert(self, *args) `insert(self, int index, char text, PyObject data = None)` lineposition(self, *args) `lineposition(self, int arg0, Fl_Line_Position arg1)` load(self, *args) `load(self, char filename) -> int` make_visible(self, *args) `make_visible(self, int n)` middleline(self, *args) `middleline(self, int l)` move(self, *args) `move(self, int to, int _from)` remove(self, *args) `remove(self, int arg0)` replace(self, *args) `replace(self, int a, char b)` select(self, *args) `select(self, int arg0, int arg1 = 1) -> int` selected(self, *args) `selected(self, int arg0) -> int` show(self, *args) `show(self, int n) show(self)` size(self, *args) `size(self) -> int size(self, int W, int H)` swap(self, *args) `swap(self, int a, int b)` text(self, *args) `text(self, int arg0) -> char text(self, int arg0, char arg1)` topline(self, *args) `topline(self) -> int topline(self, int l)` value(self, *args) `value(self) -> int value(self, int v)` visible(self, *args) `visible(self, int n) -> int` Data and other attributes inherited from Fl_Browser: BOTTOM = 1 MIDDLE = 2 TOP = 0 Methods inherited from Fl_Browser_: deselect(self, *args) `deselect(self, int docallbacks = 0) -> int` getHScrollbar(self, *args) `getHScrollbar(self) -> Fl_Scrollbar` getScrollbar(self, *args) `getScrollbar(self) -> Fl_Scrollbar` handle(self, *args) `handle(self, int arg0) -> int` has_scrollbar(self, *args) `has_scrollbar(self) -> uchar has_scrollbar(self, uchar i)` hposition(self, *args) `hposition(self) -> int hposition(self, int arg0)` position(self, *args) `position(self) -> int position(self, int arg0)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` scrollbar_left(self, *args) `scrollbar_left(self)` scrollbar_right(self, *args) `scrollbar_right(self)` select_only(self, *args) `select_only(self, void arg0, int docallbacks = 0) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Static methods inherited from Fl_Browser_: scrollbar_width(*args) `scrollbar_width(int b) scrollbar_width() -> int` Data and other attributes inherited from Fl_Browser_: ALWAYS_ON = 4 BOTH = 3 BOTH_ALWAYS = 7 HORIZONTAL = 1 HORIZONTAL_ALWAYS = 5 VERTICAL = 2 VERTICAL_ALWAYS = 6 Methods inherited from Fl_Group: add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Multi_Label(__builtin__.object)
`` | `Proxy of C++ Fl_Multi_Label class`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Fl_Multi_Label` __repr__ = _swig_repr(self) label(self, *args) `label(self, Fl_Widget arg0) label(self, Fl_Menu_Item arg0)` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Multi_Label> `delete_Fl_Multi_Label(Fl_Multi_Label self)`
class Fl_Multiline_Input(Fl_Input)
`` | `This input field displays ' ' characters as new lines rather than ^J, and accepts the Return, Tab, and up and down arrow keys. This is for editing multiline text. This is far from the nirvana of text editors, and is probably only good for small bits of text, 10 lines at most. I think FLTK can be used to write a powerful text editor, but it is not going to be a built-in feature. Powerful text editors in a toolkit are a big source of bloat.`
| Method resolution order: Fl_Multiline_Input Fl_Input Fl_Input_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Multiline_Input` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Multiline_Input> `delete_Fl_Multiline_Input(Fl_Multiline_Input self)` Methods inherited from Fl_Input: draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Input_: copy(self, *args) `copy(self, int clipboard) -> int` copy_cuts(self, *args) `copy_cuts(self) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` cut(self, *args) `cut(self) -> int cut(self, int n) -> int cut(self, int a, int b) -> int` index(self, *args) `index(self, int i) -> char` input_type(self, *args) `input_type(self) -> int input_type(self, int t)` insert(self, *args) `insert(self, char t, int l = 0) -> int` mark(self, *args) `mark(self) -> int mark(self, int m) -> int` maximum_size(self, *args) `maximum_size(self) -> int maximum_size(self, int m)` position(self, *args) `position(self) -> int position(self, int p, int m) -> int position(self, int p) -> int` readonly(self, *args) `readonly(self) -> int readonly(self, int b)` replace(self, *args) `replace(self, int arg0, int arg1, char arg2, int arg3 = 0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` size(self, *args) `size(self) -> int size(self, int W, int H)` static_value(self, *args) `static_value(self, char arg0) -> int static_value(self, char arg0, int arg1) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` undo(self, *args) `undo(self) -> int` value(self, *args) `value(self, char arg0) -> int value(self, char arg0, int arg1) -> int value(self) -> char` wrap(self, *args) `wrap(self) -> int wrap(self, int b)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Multiline_Output(Fl_Output)
`` | `This widget is a subclass of Fl_Output that displays multiple lines of text. It also displays tab characters as whitespace to the next column.`
| Method resolution order: Fl_Multiline_Output Fl_Output Fl_Input Fl_Input_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Multiline_Output` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Multiline_Output> `delete_Fl_Multiline_Output(Fl_Multiline_Output self)` Methods inherited from Fl_Input: draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Input_: copy(self, *args) `copy(self, int clipboard) -> int` copy_cuts(self, *args) `copy_cuts(self) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` cut(self, *args) `cut(self) -> int cut(self, int n) -> int cut(self, int a, int b) -> int` index(self, *args) `index(self, int i) -> char` input_type(self, *args) `input_type(self) -> int input_type(self, int t)` insert(self, *args) `insert(self, char t, int l = 0) -> int` mark(self, *args) `mark(self) -> int mark(self, int m) -> int` maximum_size(self, *args) `maximum_size(self) -> int maximum_size(self, int m)` position(self, *args) `position(self) -> int position(self, int p, int m) -> int position(self, int p) -> int` readonly(self, *args) `readonly(self) -> int readonly(self, int b)` replace(self, *args) `replace(self, int arg0, int arg1, char arg2, int arg3 = 0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` size(self, *args) `size(self) -> int size(self, int W, int H)` static_value(self, *args) `static_value(self, char arg0) -> int static_value(self, char arg0, int arg1) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` undo(self, *args) `undo(self) -> int` value(self, *args) `value(self, char arg0) -> int value(self, char arg0, int arg1) -> int value(self) -> char` wrap(self, *args) `wrap(self) -> int wrap(self, int b)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Nice_Slider(Fl_Slider)
`` | `The Fl_Nice_Slider widget contains a sliding knob inside a box. It is often used as a scrollbar. Moving the box all the way to the top/left sets it to the minimum(), and to the bottom/right to the maximum(). The minimum() may be greater than the maximum() to reverse the slider direction.`
| Method resolution order: Fl_Nice_Slider Fl_Slider Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Nice_Slider` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Nice_Slider> `delete_Fl_Nice_Slider(Fl_Nice_Slider self)` Methods inherited from Fl_Slider: bounds(self, *args) `bounds(self, double a, double b)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` scrollvalue(self, *args) `scrollvalue(self, int windowtop, int windowsize, int first, int totalsize) -> int` slider(self, *args) `slider(self) -> Fl_Boxtype slider(self, Fl_Boxtype c)` slider_size(self, *args) `slider_size(self) -> float slider_size(self, double v)` Methods inherited from Fl_Valuator: clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Output(Fl_Input)
`` | `This widget displays a piece of text. When you set the value() , Fl_Output does a strcpy() to it's own storage, which is useful for program-generated values. The user may select portions of the text using the mouse and paste the contents into other fields or programs. There is a single subclass, Fl_Multiline_Output, which allows you to display multiple lines of text. The text may contain any characters except`
| Method resolution order: Fl_Output Fl_Input Fl_Input_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Output` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Output> `delete_Fl_Output(Fl_Output self)` Methods inherited from Fl_Input: draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Input_: copy(self, *args) `copy(self, int clipboard) -> int` copy_cuts(self, *args) `copy_cuts(self) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` cut(self, *args) `cut(self) -> int cut(self, int n) -> int cut(self, int a, int b) -> int` index(self, *args) `index(self, int i) -> char` input_type(self, *args) `input_type(self) -> int input_type(self, int t)` insert(self, *args) `insert(self, char t, int l = 0) -> int` mark(self, *args) `mark(self) -> int mark(self, int m) -> int` maximum_size(self, *args) `maximum_size(self) -> int maximum_size(self, int m)` position(self, *args) `position(self) -> int position(self, int p, int m) -> int position(self, int p) -> int` readonly(self, *args) `readonly(self) -> int readonly(self, int b)` replace(self, *args) `replace(self, int arg0, int arg1, char arg2, int arg3 = 0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` size(self, *args) `size(self) -> int size(self, int W, int H)` static_value(self, *args) `static_value(self, char arg0) -> int static_value(self, char arg0, int arg1) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` undo(self, *args) `undo(self) -> int` value(self, *args) `value(self, char arg0) -> int value(self, char arg0, int arg1) -> int value(self) -> char` wrap(self, *args) `wrap(self) -> int wrap(self, int b)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Overlay_Window(Fl_Double_Window)
`` | `This window provides double buffering and also the ability to draw the 'overlay' which is another picture placed on top of the main image. The overlay is designed to be a rapidly-changing but simple graphic such as a mouse selection box. Fl_Overlay_Window uses the overlay planes provided by your graphics hardware if they are available. If no hardware support is found the overlay is simulated by drawing directly into the on-screen copy of the double-buffered window, and 'erased' by copying the backbuffer over it again. This means the overlay will blink if you change the image in the window.`
| Method resolution order: Fl_Overlay_Window Fl_Double_Window Fl_Window Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args, **kwargs) __repr__ = _swig_repr(self) can_do_overlay(self, *args) `can_do_overlay(self) -> int` draw(self, *args) `draw(self)` flush(self, *args) `flush(self)` hide(self, *args) `hide(self)` redraw_overlay(self, *args) `redraw_overlay(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` show(self, *args) `show(self, PyObject count = None, PyObject data = None)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Overlay_Window> `delete_Fl_Overlay_Window(Fl_Overlay_Window self)` Methods inherited from Fl_Window: border(self, *args) `border(self, int b) border(self) -> int` clear_border(self, *args) `clear_border(self)` copy_label(self, *args) `copy_label(self, char a)` cursor(self, *args) `cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` default_cursor(self, *args) `default_cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` free_position(self, *args) `free_position(self)` fullscreen(self, *args) `fullscreen(self)` fullscreen_off(self, *args) `fullscreen_off(self, int arg0, int arg1, int arg2, int arg3)` handle(self, *args) `handle(self, int arg0) -> int` hotspot(self, *args) `hotspot(self, int x, int y, int offscreen = 0) hotspot(self, Fl_Widget arg0, int offscreen = 0)` icon(self, *args) `icon(self) -> void icon(self, void ic)` iconize(self, *args) `iconize(self)` iconlabel(self, *args) `iconlabel(self) -> char iconlabel(self, char arg0)` label(self, *args) `label(self) -> char label(self, char arg0) label(self, char label, char iconlabel)` make_current(self, *args) `make_current(self)` modal(self, *args) `modal(self) -> int` non_modal(self, *args) `non_modal(self) -> int` override(self, *args) `override(self) -> int` set_modal(self, *args) `set_modal(self)` set_non_modal(self, *args) `set_non_modal(self)` set_override(self, *args) `set_override(self)` shown(self, *args) `shown(self) -> int` size_range(self, *args) `size_range(self, int a, int b, int c = 0, int d = 0, int e = 0, int f = 0, int g = 0)` x_root(self, *args) `x_root(self) -> int` xclass(self, *args) `xclass(self) -> char xclass(self, char c)` y_root(self, *args) `y_root(self) -> int` Static methods inherited from Fl_Window: current(*args) `current() -> Fl_Window` default_callback(*args) `default_callback(Fl_Window arg0, void v)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_PNG_Image(Fl_RGB_Image)
`` | `The Fl_PNG_Image class supports loading, caching, and drawing of Portable Network Graphics (PNG) image files. The class loads colormapped and full-color images and handles color- and alpha-based transparency.`
| Method resolution order: Fl_PNG_Image Fl_RGB_Image Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, char filename) -> Fl_PNG_Image` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_PNG_Image> `delete_Fl_PNG_Image(Fl_PNG_Image self)` Methods inherited from Fl_RGB_Image: color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` uncache(self, *args) `uncache(self)` Methods inherited from Fl_Image: count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_PNM_Image(Fl_RGB_Image)
`` | `The Fl_PNM_Image class supports loading, caching, and drawing of Portable Anymap (PNM, PBM, PGM, PPM) image files. The class loads bitmap, grayscale, and full-color images in both ASCII and binary formats.`
| Method resolution order: Fl_PNM_Image Fl_RGB_Image Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, char filename) -> Fl_PNM_Image` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_PNM_Image> `delete_Fl_PNM_Image(Fl_PNM_Image self)` Methods inherited from Fl_RGB_Image: color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` uncache(self, *args) `uncache(self)` Methods inherited from Fl_Image: count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Pack(Fl_Group)
`` | `This widget was designed to add the functionality of compressing and aligning widgets. If type() is FL_HORIZONTAL all the children are resized to the height of the Fl_Pack, and are moved next to each other horizontally. If type() is not FL_HORIZONTAL then the children are resized to the width and are stacked below each other. Then the Fl_Pack resizes itself to surround the child widgets. This widget is needed for the Fl_Tabs. In addition you may want to put the Fl_Pack inside an Fl_Scroll.`
| Method resolution order: Fl_Pack Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Pack` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` horizontal(self, *args) `horizontal(self) -> uchar` spacing(self, *args) `spacing(self) -> int spacing(self, int i)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: HORIZONTAL = 1 VERTICAL = 0 __swig_destroy__ = <built-in function delete_Fl_Pack> `delete_Fl_Pack(Fl_Pack self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` handle(self, *args) `handle(self, int arg0) -> int` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Pixmap(Fl_Image)
`` | `The Fl_Pixmap class supports caching and drawing of colormap (pixmap) images, including transparency.`
| Method resolution order: Fl_Pixmap Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, char D) -> Fl_Pixmap` __repr__ = _swig_repr(self) color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` uncache(self, *args) `uncache(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Pixmap> `delete_Fl_Pixmap(Fl_Pixmap self)` Methods inherited from Fl_Image: count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Positioner(Fl_Widget)
`` | `This class is provided for Forms compatibility. It provides 2D input. It would be useful if this could be put atop another widget so that the crosshairs are on top, but this is not implemented. The color of the crosshairs is selection_color().`
| Method resolution order: Fl_Positioner Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Positioner` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` value(self, *args) `value(self, double arg0, double arg1) -> int` xbounds(self, *args) `xbounds(self, double arg0, double arg1)` xmaximum(self, *args) `xmaximum(self) -> double xmaximum(self, double a)` xminimum(self, *args) `xminimum(self) -> double xminimum(self, double a)` xstep(self, *args) `xstep(self, double a)` xvalue(self, *args) `xvalue(self) -> double xvalue(self, double arg0) -> int` ybounds(self, *args) `ybounds(self, double arg0, double arg1)` ymaximum(self, *args) `ymaximum(self) -> double ymaximum(self, double a)` yminimum(self, *args) `yminimum(self) -> double yminimum(self, double a)` ystep(self, *args) `ystep(self, double a)` yvalue(self, *args) `yvalue(self) -> double yvalue(self, double arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Positioner> `delete_Fl_Positioner(Fl_Positioner self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Preferences(__builtin__.object)
`` | `Fl_Preferences provides methods to store user setting between application starts. It is similar to the Registry on WIN32 and Preferences on MacOS, and provides a simple configuration mechanism for UNIX. Fl_Preferences uses a hierarchy to store data. It bundles similar data into groups and manages entries into those groups as name/value pairs. Preferences are stored in text files that can be edited manually. The file format is easy to read and relatively forgiving. Preferences files are the same on all platforms. User comments in preference files are preserved. Filenames are unique for each application by using a vendor/application naming scheme. The user must provide default values for all entries to ensure proper operation should preferences be corrupted or not yet exist. Entries can be of any length. However, the size of each preferences file should be kept under 100k for performance reasons. One application can have multiple preferences files. Extensive binary data however should be stored in seperate files; see the getUserdataPath() method.`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self, Root root, char vendor, char application) -> Fl_Preferences __init__(self, char path, char vendor, char application) -> Fl_Preferences __init__(self, Fl_Preferences arg0, char group) -> Fl_Preferences` __repr__ = _swig_repr(self) deleteEntry(self, *args) `deleteEntry(self, char entry) -> char` deleteGroup(self, *args) `deleteGroup(self, char group) -> char` entries(self, *args) `entries(self) -> int` entry(self, *args) `entry(self, int arg0) -> char` entryExists(self, *args) `entryExists(self, char entry) -> char` flush(self, *args) `flush(self)` get(self, *args) `get(self, char entry, int defaultValue) -> char get(self, char entry, float defaultValue) -> char get(self, char entry, double defaultValue) -> char get(self, char entry, char defaultValue, int maxSize) -> char get(self, char entry, void value, void defaultValue, int defaultSize, int maxSize) -> char` getUserdataPath(self, *args) `getUserdataPath(self, char path) -> char` group(self, *args) `group(self, int arg0) -> char` groupExists(self, *args) `groupExists(self, char group) -> char` groups(self, *args) `groups(self) -> int` set(self, *args) `set(self, char entry, int value) -> char set(self, char entry, float value, int precision) -> char set(self, char entry, double value) -> char set(self, char entry, double value, int precision) -> char set(self, char entry, char cvalue) -> char set(self, char entry, void cvalue, int size) -> char` size(self, *args) `size(self, char entry) -> int` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: SYSTEM = 0 USER = 1 __swig_destroy__ = <built-in function delete_Fl_Preferences> `delete_Fl_Preferences(Fl_Preferences self)`
class Fl_Progress(Fl_Widget)
`` | `The Fl_Progress widget displays a progress bar for the user.`
| Method resolution order: Fl_Progress Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Progress` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` maximum(self, *args) `maximum(self, float v) maximum(self) -> float` minimum(self, *args) `minimum(self, float v) minimum(self) -> float` value(self, *args) `value(self, float v) value(self) -> float` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Progress> `delete_Fl_Progress(Fl_Progress self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_RGB_Image(Fl_Image)
`` | `Proxy of C++ Fl_RGB_Image class`
| Method resolution order: Fl_RGB_Image Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, uchar bits, int W, int H, int D = 3, int LD = 0) -> Fl_RGB_Image` __repr__ = _swig_repr(self) color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` uncache(self, *args) `uncache(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_RGB_Image> `delete_Fl_RGB_Image(Fl_RGB_Image self)` Methods inherited from Fl_Image: count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Radio_Button(Fl_Button)
`` | `Proxy of C++ Fl_Radio_Button class`
| Method resolution order: Fl_Radio_Button Fl_Button Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Radio_Button` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Radio_Button> `delete_Fl_Radio_Button(Fl_Radio_Button self)` Methods inherited from Fl_Button: clear(self, *args) `clear(self) -> int` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` handle(self, *args) `handle(self, int arg0) -> int` set(self, *args) `set(self) -> int` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s) shortcut(self, char s)` value(self, *args) `value(self, int arg0) -> int value(self) -> char` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Radio_Light_Button(Fl_Light_Button)
`` | `Proxy of C++ Fl_Radio_Light_Button class`
| Method resolution order: Fl_Radio_Light_Button Fl_Light_Button Fl_Button Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Radio_Light_Button` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Radio_Light_Button> `delete_Fl_Radio_Light_Button(Fl_Radio_Light_Button self)` Methods inherited from Fl_Light_Button: handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Button: clear(self, *args) `clear(self) -> int` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` set(self, *args) `set(self) -> int` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s) shortcut(self, char s)` value(self, *args) `value(self, int arg0) -> int value(self) -> char` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Radio_Round_Button(Fl_Round_Button)
`` | `Proxy of C++ Fl_Radio_Round_Button class`
| Method resolution order: Fl_Radio_Round_Button Fl_Round_Button Fl_Light_Button Fl_Button Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Radio_Round_Button` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Radio_Round_Button> `delete_Fl_Radio_Round_Button(Fl_Radio_Round_Button self)` Methods inherited from Fl_Light_Button: handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Button: clear(self, *args) `clear(self) -> int` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` set(self, *args) `set(self) -> int` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s) shortcut(self, char s)` value(self, *args) `value(self, int arg0) -> int value(self) -> char` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Repeat_Button(Fl_Button)
`` | `The Fl_Repeat_Button is a subclass of Fl_Button that generates a callback when it is pressed and then repeatedly generates callbacks as long as it is held down. The speed of the repeat is fixed and depends on the implementation.`
| Method resolution order: Fl_Repeat_Button Fl_Button Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Repeat_Button` __repr__ = _swig_repr(self) deactivate(self, *args) `deactivate(self)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Repeat_Button> `delete_Fl_Repeat_Button(Fl_Repeat_Button self)` Methods inherited from Fl_Button: clear(self, *args) `clear(self) -> int` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` set(self, *args) `set(self) -> int` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s) shortcut(self, char s)` value(self, *args) `value(self, int arg0) -> int value(self) -> char` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Return_Button(Fl_Button)
`` | `The Fl_Return_Button is a subclass of Fl_Button that generates a callback when it is pressed or when the user presses the Enter key. A carriage-return symbol is drawn next to the button label.`
| Method resolution order: Fl_Return_Button Fl_Button Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Return_Button` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Return_Button> `delete_Fl_Return_Button(Fl_Return_Button self)` Methods inherited from Fl_Button: clear(self, *args) `clear(self) -> int` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` set(self, *args) `set(self) -> int` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s) shortcut(self, char s)` value(self, *args) `value(self, int arg0) -> int value(self) -> char` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Roller(Fl_Valuator)
`` | `The Fl_Roller widget is a 'dolly' control commonly used to move 3D objects.`
| Method resolution order: Fl_Roller Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char L = None) -> Fl_Roller` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Roller> `delete_Fl_Roller(Fl_Roller self)` Methods inherited from Fl_Valuator: bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Round_Button(Fl_Light_Button)
`` | `Buttons generate callbacks when they are clicked by the user. You control exactly when and how by changing the values for type() and when(). The Fl_Round_Button subclass display the 'on' state by turning on a light, rather than drawing pushed in. The shape of the 'light' is initially set to FL_ROUND_DOWN_BOX. The color of the light when on is controlled with selection_color(), which defaults to FL_RED.`
| Method resolution order: Fl_Round_Button Fl_Light_Button Fl_Button Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Round_Button` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Round_Button> `delete_Fl_Round_Button(Fl_Round_Button self)` Methods inherited from Fl_Light_Button: handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Button: clear(self, *args) `clear(self) -> int` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` set(self, *args) `set(self) -> int` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s) shortcut(self, char s)` value(self, *args) `value(self, int arg0) -> int value(self) -> char` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Round_Clock(Fl_Clock)
`` | `This widget provides a round analog clock display and is provided for Forms compatibility. It installs a 1-second timeout callback using Fl::add_timeout().`
| Method resolution order: Fl_Round_Clock Fl_Clock Fl_Clock_Output Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Round_Clock` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Round_Clock> `delete_Fl_Round_Clock(Fl_Round_Clock self)` Methods inherited from Fl_Clock: handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Clock_Output: hour(self, *args) `hour(self) -> int` minute(self, *args) `minute(self) -> int` second(self, *args) `second(self) -> int` value(self, *args) `value(self, ulong v) value(self, int arg0, int arg1, int arg2) value(self) -> ulong` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Scroll(Fl_Group)
`` | `This container widget lets you maneuver around a set of widgets much larger than your window. If the child widgets are larger than the size of this object then scrollbars will appear so that you can scroll over to them: If all of the child widgets are packed together into a solid rectangle then you want to set box() to FL_NO_BOX or one of the _FRAME types. This will result in the best output. However, if the child widgets are a sparse arrangment you must set box() to a real _BOX type. This can result in some blinking during redrawing, but that can be solved by using a Fl_Double_Window. This widget can also be used to pan around a single child widget 'canvas'. This child widget should be of your own class, with a draw() method that draws the contents. The scrolling is done by changing the x() and y() of the widget, so this child must use the x() and y() to position it's drawing. To speed up drawing it should test fl_push_clip() . Another very useful child is a single Fl_Pack, which is itself a group that packs it's children together and changes size to surround them. Filling the Fl_Pack with Fl_Tabs groups (and then putting normal widgets inside those) gives you a very powerful scrolling list of individually-openable panels. Fluid lets you create these, but you can only lay out objects that fit inside the Fl_Scroll without scrolling. Be sure to leave space for the scrollbars, as Fluid won't show these either. You cannot use Fl_Window as a child of this since the clipping is not conveyed to it when drawn, and it will draw over the scrollbars and neighboring objects.`
| Method resolution order: Fl_Scroll Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Scroll` __repr__ = _swig_repr(self) clear(self, *args) `clear(self)` draw(self, *args) `draw(self)` getHScrollbar(self, *args) `getHScrollbar(self) -> Fl_Scrollbar` getScrollbar(self, *args) `getScrollbar(self) -> Fl_Scrollbar` handle(self, *args) `handle(self, int arg0) -> int` position(self, *args) `position(self, int arg0, int arg1)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` xposition(self, *args) `xposition(self) -> int` yposition(self, *args) `yposition(self) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: ALWAYS_ON = 4 BOTH = 3 BOTH_ALWAYS = 7 HORIZONTAL = 1 HORIZONTAL_ALWAYS = 5 VERTICAL = 2 VERTICAL_ALWAYS = 6 __swig_destroy__ = <built-in function delete_Fl_Scroll> `delete_Fl_Scroll(Fl_Scroll self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Scrollbar(Fl_Slider)
`` | `The Fl_Scrollbar widget displays a slider with arrow buttons at the ends of the scrollbar. Clicking on the arrows move up/left and down/right by linesize(). Scrollbars also accept FL_SHORTCUT events: the arrows move by linesize(), and vertical scrollbars take Page Up/Down (they move by the page size minus linesize()) and Home/End (they jump to the top or bottom). Scrollbars have step(1) preset (they always return integers). If desired you can set the step() to non-integer values. You will then have to use casts to get at the floating-point versions of value() from Fl_Slider.`
| Method resolution order: Fl_Scrollbar Fl_Slider Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Scrollbar` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` linesize(self, *args) `linesize(self) -> int linesize(self, int i)` value(self, *args) `value(self) -> int value(self, int p, int s, int top, int total) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Scrollbar> `delete_Fl_Scrollbar(Fl_Scrollbar self)` Methods inherited from Fl_Slider: bounds(self, *args) `bounds(self, double a, double b)` scrollvalue(self, *args) `scrollvalue(self, int windowtop, int windowsize, int first, int totalsize) -> int` slider(self, *args) `slider(self) -> Fl_Boxtype slider(self, Fl_Boxtype c)` slider_size(self, *args) `slider_size(self) -> float slider_size(self, double v)` Methods inherited from Fl_Valuator: clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Secret_Input(Fl_Input)
`` | `The Fl_Secret_Input class is a subclass of Fl_Input that displays its input as a string of asterisks. This subclass is usually used to receive passwords and other 'secret' information.`
| Method resolution order: Fl_Secret_Input Fl_Input Fl_Input_ Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Secret_Input` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Secret_Input> `delete_Fl_Secret_Input(Fl_Secret_Input self)` Methods inherited from Fl_Input: draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Methods inherited from Fl_Input_: copy(self, *args) `copy(self, int clipboard) -> int` copy_cuts(self, *args) `copy_cuts(self) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` cut(self, *args) `cut(self) -> int cut(self, int n) -> int cut(self, int a, int b) -> int` index(self, *args) `index(self, int i) -> char` input_type(self, *args) `input_type(self) -> int input_type(self, int t)` insert(self, *args) `insert(self, char t, int l = 0) -> int` mark(self, *args) `mark(self) -> int mark(self, int m) -> int` maximum_size(self, *args) `maximum_size(self) -> int maximum_size(self, int m)` position(self, *args) `position(self) -> int position(self, int p, int m) -> int position(self, int p) -> int` readonly(self, *args) `readonly(self) -> int readonly(self, int b)` replace(self, *args) `replace(self, int arg0, int arg1, char arg2, int arg3 = 0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` size(self, *args) `size(self) -> int size(self, int W, int H)` static_value(self, *args) `static_value(self, char arg0) -> int static_value(self, char arg0, int arg1) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` undo(self, *args) `undo(self) -> int` value(self, *args) `value(self, char arg0) -> int value(self, char arg0, int arg1) -> int value(self) -> char` wrap(self, *args) `wrap(self) -> int wrap(self, int b)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Select_Browser(Fl_Browser)
`` | `The Fl_Select_Browser class is a subclass of Fl_Browser which lets the user select a single item, or no items by clicking on the empty space. As long as the mouse button is held down the item pointed to by it is highlighted. Normally the callback is done when the user presses the mouse, but you can change this with when(). See Fl_Browser for methods to add and remove lines from the browser.`
| Method resolution order: Fl_Select_Browser Fl_Browser Fl_Browser_ Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Select_Browser` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` full_height(self, *args) `full_height(self) -> int` full_width(self, *args) `full_width(self) -> int` incr_height(self, *args) `incr_height(self) -> int` item_draw(self, *args) `item_draw(self, void arg0, int arg1, int arg2, int arg3, int arg4)` item_first(self, *args) `item_first(self) -> void` item_height(self, *args) `item_height(self, void arg0) -> int` item_next(self, *args) `item_next(self, void arg0) -> void` item_prev(self, *args) `item_prev(self, void arg0) -> void` item_quick_height(self, *args) `item_quick_height(self, void arg0) -> int` item_select(self, *args) `item_select(self, void arg0, int arg1)` item_selected(self, *args) `item_selected(self, void arg0) -> int` item_width(self, *args) `item_width(self, void arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Select_Browser> `delete_Fl_Select_Browser(Fl_Select_Browser self)` Methods inherited from Fl_Browser: add(self, *args) `add(self, char text, PyObject data = None)` bottomline(self, *args) `bottomline(self, int l)` clear(self, *args) `clear(self)` column_char(self, *args) `column_char(self) -> char column_char(self, char c)` column_widths(self, *args) `column_widths(self) -> int column_widths(self, PyObject widths)` data(self, *args) `data(self, int index, PyObject data = None) -> PyObject` display(self, *args) `display(self, int arg0, int arg1 = 1)` displayed(self, *args) `displayed(self, int n) -> int` format_char(self, *args) `format_char(self) -> char format_char(self, char c)` get_data(self, *args) `get_data(self, int index) -> PyObject` hide(self, *args) `hide(self, int n) hide(self)` insert(self, *args) `insert(self, int index, char text, PyObject data = None)` lineposition(self, *args) `lineposition(self, int arg0, Fl_Line_Position arg1)` load(self, *args) `load(self, char filename) -> int` make_visible(self, *args) `make_visible(self, int n)` middleline(self, *args) `middleline(self, int l)` move(self, *args) `move(self, int to, int _from)` remove(self, *args) `remove(self, int arg0)` replace(self, *args) `replace(self, int a, char b)` select(self, *args) `select(self, int arg0, int arg1 = 1) -> int` selected(self, *args) `selected(self, int arg0) -> int` show(self, *args) `show(self, int n) show(self)` size(self, *args) `size(self) -> int size(self, int W, int H)` swap(self, *args) `swap(self, int a, int b)` text(self, *args) `text(self, int arg0) -> char text(self, int arg0, char arg1)` topline(self, *args) `topline(self) -> int topline(self, int l)` value(self, *args) `value(self) -> int value(self, int v)` visible(self, *args) `visible(self, int n) -> int` Data and other attributes inherited from Fl_Browser: BOTTOM = 1 MIDDLE = 2 TOP = 0 Methods inherited from Fl_Browser_: deselect(self, *args) `deselect(self, int docallbacks = 0) -> int` getHScrollbar(self, *args) `getHScrollbar(self) -> Fl_Scrollbar` getScrollbar(self, *args) `getScrollbar(self) -> Fl_Scrollbar` handle(self, *args) `handle(self, int arg0) -> int` has_scrollbar(self, *args) `has_scrollbar(self) -> uchar has_scrollbar(self, uchar i)` hposition(self, *args) `hposition(self) -> int hposition(self, int arg0)` position(self, *args) `position(self) -> int position(self, int arg0)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` scrollbar_left(self, *args) `scrollbar_left(self)` scrollbar_right(self, *args) `scrollbar_right(self)` select_only(self, *args) `select_only(self, void arg0, int docallbacks = 0) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Static methods inherited from Fl_Browser_: scrollbar_width(*args) `scrollbar_width(int b) scrollbar_width() -> int` Data and other attributes inherited from Fl_Browser_: ALWAYS_ON = 4 BOTH = 3 BOTH_ALWAYS = 7 HORIZONTAL = 1 HORIZONTAL_ALWAYS = 5 VERTICAL = 2 VERTICAL_ALWAYS = 6 Methods inherited from Fl_Group: add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Shared_Image(Fl_Image)
`` | `The Fl_Shared_Image class supports caching, loading, and drawing of image files. Most applications will also want to link against the fltk_images library and call the fl_register_images() function to support standard image formats such as BMP, GIF, JPEG, and PNG.`
| Method resolution order: Fl_Shared_Image Fl_Image __builtin__.object Methods defined here: __disown__(self) __init__(self, *args) `__init__(self) -> Fl_Shared_Image __init__(self, char n, Fl_Image img = None) -> Fl_Shared_Image` __repr__ = _swig_repr(self) color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx, int cy) draw(self, int X, int Y)` name(self, *args) `name(self) -> char` refcount(self, *args) `refcount(self) -> int` release(self, *args) `release(self)` reload(self, *args) `reload(self)` uncache(self, *args) `uncache(self)` Static methods defined here: add_handler(*args) `add_handler(Fl_Shared_Handler f)` find(*args) `find(char n, int W = 0, int H = 0) -> Fl_Shared_Image` get(*args) `get(char n, int W = 0, int H = 0) -> Fl_Shared_Image` images(*args) `images() -> Fl_Shared_Image` num_images(*args) `num_images() -> int` remove_handler(*args) `remove_handler(Fl_Shared_Handler f)` Data descriptors defined here: thisown `The membership flag` Methods inherited from Fl_Image: __del__ lambda self count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Data and other attributes inherited from Fl_Image: __swig_destroy__ = <built-in function delete_Fl_Image> `delete_Fl_Image(Fl_Image self)`
class Fl_Simple_Counter(Fl_Counter)
`` | `Proxy of C++ Fl_Simple_Counter class`
| Method resolution order: Fl_Simple_Counter Fl_Counter Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Simple_Counter` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Simple_Counter> `delete_Fl_Simple_Counter(Fl_Simple_Counter self)` Methods inherited from Fl_Counter: handle(self, *args) `handle(self, int arg0) -> int` lstep(self, *args) `lstep(self, double a)` step(self, *args) `step(self, double a, double b) step(self, double a)` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int s)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Methods inherited from Fl_Valuator: bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Single_Window(Fl_Window)
`` | `This is the same as Fl_Window. However, it is possible that some implementations will provide double-buffered windows by default. This subclass can be used to force single-buffering. This may be useful for modifying existing programs that use incremental update, or for some types of image data, such as a movie flipbook.`
| Method resolution order: Fl_Single_Window Fl_Window Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int W, int H, char l = None) -> Fl_Single_Window __init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Single_Window` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` flush(self, *args) `flush(self)` show(self, *args) `show(self, PyObject count = None, PyObject data = None)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Single_Window> `delete_Fl_Single_Window(Fl_Single_Window self)` Methods inherited from Fl_Window: border(self, *args) `border(self, int b) border(self) -> int` clear_border(self, *args) `clear_border(self)` copy_label(self, *args) `copy_label(self, char a)` cursor(self, *args) `cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` default_cursor(self, *args) `default_cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` free_position(self, *args) `free_position(self)` fullscreen(self, *args) `fullscreen(self)` fullscreen_off(self, *args) `fullscreen_off(self, int arg0, int arg1, int arg2, int arg3)` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` hotspot(self, *args) `hotspot(self, int x, int y, int offscreen = 0) hotspot(self, Fl_Widget arg0, int offscreen = 0)` icon(self, *args) `icon(self) -> void icon(self, void ic)` iconize(self, *args) `iconize(self)` iconlabel(self, *args) `iconlabel(self) -> char iconlabel(self, char arg0)` label(self, *args) `label(self) -> char label(self, char arg0) label(self, char label, char iconlabel)` make_current(self, *args) `make_current(self)` modal(self, *args) `modal(self) -> int` non_modal(self, *args) `non_modal(self) -> int` override(self, *args) `override(self) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` set_modal(self, *args) `set_modal(self)` set_non_modal(self, *args) `set_non_modal(self)` set_override(self, *args) `set_override(self)` shown(self, *args) `shown(self) -> int` size_range(self, *args) `size_range(self, int a, int b, int c = 0, int d = 0, int e = 0, int f = 0, int g = 0)` x_root(self, *args) `x_root(self) -> int` xclass(self, *args) `xclass(self) -> char xclass(self, char c)` y_root(self, *args) `y_root(self) -> int` Static methods inherited from Fl_Window: current(*args) `current() -> Fl_Window` default_callback(*args) `default_callback(Fl_Window arg0, void v)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Slider(Fl_Valuator)
`` | `The Fl_Slider widget contains a sliding knob inside a box. It if often used as a scrollbar. Moving the box all the way to the top/left sets it to the minimum(), and to the bottom/right to the maximum(). The minimum() may be greater than the maximum() to reverse the slider direction.`
| Method resolution order: Fl_Slider Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Slider __init__(self, uchar t, int x, int y, int w, int h, char l) -> Fl_Slider` __repr__ = _swig_repr(self) bounds(self, *args) `bounds(self, double a, double b)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` scrollvalue(self, *args) `scrollvalue(self, int windowtop, int windowsize, int first, int totalsize) -> int` slider(self, *args) `slider(self) -> Fl_Boxtype slider(self, Fl_Boxtype c)` slider_size(self, *args) `slider_size(self) -> float slider_size(self, double v)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Slider> `delete_Fl_Slider(Fl_Slider self)` Methods inherited from Fl_Valuator: clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Spinner(Fl_Group)
`` | `The Fl_Spinner widget is a combination of the input widget and repeat buttons. The user can either type into the input area or use the buttons to change the value.`
| Method resolution order: Fl_Spinner Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char L = None) -> Fl_Spinner` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` format(self, *args) `format(self) -> char format(self, char f)` handle(self, *args) `handle(self, int event) -> int` maximum(self, *args) `maximum(self, double m) maximum(self) -> double` maxinum(self, *args) `maxinum(self) -> double` minimum(self, *args) `minimum(self, double m) minimum(self) -> double` mininum(self, *args) `mininum(self) -> double` range(self, *args) `range(self, double a, double b)` resize(self, *args) `resize(self, int X, int Y, int W, int H)` step(self, *args) `step(self) -> double step(self, double s)` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, Fl_Color c)` textfont(self, *args) `textfont(self) -> uchar textfont(self, uchar f)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` type(self, *args) `type(self) -> uchar type(self, uchar v)` value(self, *args) `value(self) -> double value(self, double v)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Spinner> `delete_Fl_Spinner(Fl_Spinner self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Table(Fl_Group)
`` | `This is the base class for table widgets. (eg. Fl_Table_Row). To be useful it must be subclassed and several virtual functions defined. Normally applications use widgets derived from this widget, and do not use this widget directly; this widget is usually too low level to be used directly by applications. This widget does not handle the data in the table. The draw_cell() method must be overridden by a subclass to manage drawing the contents of the cells. This widget can be used in several ways: * As a custom widget; see testtablerow.cxx. Very optimal for even extremely large tables. * As a table made up of a single FLTK widget instanced all over the table; see singleinput.cxx. Very optimal for even extremely large tables; * As a regular container of FLTK widgets, one widget per cell. See widgettable.cxx. Not recommended for large tables. When acting as part of a custom widget, events on the cells and/or headings generate callbacks when they are clicked by the user. You control when events are generated based on the setting for Fl_Table::when(). When acting as a container for FLTK widgets, the FLTK widgets maintain themselves. Although the draw_cell() method must be overridden, its contents can be very simple. See the draw_cell() code in widgettable.cxx.`
| Method resolution order: Fl_Table Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Table` __repr__ = _swig_repr(self) add(self, *args) `add(self, Fl_Widget w)` begin(self, *args) `begin(self)` callback_col(self, *args) `callback_col(self) -> int` callback_context(self, *args) `callback_context(self) -> TableContext` callback_row(self, *args) `callback_row(self) -> int` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` col_header(self, *args) `col_header(self) -> int col_header(self, int flag)` col_header_color(self, *args) `col_header_color(self, Fl_Color val) col_header_color(self) -> Fl_Color` col_header_height(self, *args) `col_header_height(self, int height) col_header_height(self) -> int` col_position(self, *args) `col_position(self, int col) col_position(self) -> int` col_resize(self, *args) `col_resize(self) -> int col_resize(self, int flag)` col_resize_min(self, *args) `col_resize_min(self) -> int col_resize_min(self, int val)` col_width(self, *args) `col_width(self, int col, int width) col_width(self, int col) -> int` col_width_all(self, *args) `col_width_all(self, int width)` cols(self, *args) `cols(self, int val) cols(self) -> int` do_callback(self, *args) `do_callback(self, TableContext context, int row, int col)` draw(self, *args) `draw(self)` draw_cell(self, *args) `draw_cell(self, TableContext context, int R = 0, int C = 0, int X = 0, int Y = 0, int W = 0, int H = 0)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget w) -> int` get_selection(self, *args) `get_selection(self)` handle(self, *args) `handle(self, int e) -> int` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget w, int n)` insert_before(self, *args) `insert_before(self, Fl_Widget w, Fl_Widget w2)` is_interactive_resize(self, *args) `is_interactive_resize(self) -> int` is_selected(self, *args) `is_selected(self, int r, int c) -> int` move_cursor(self, *args) `move_cursor(self, int R, int C) -> int` resize(self, *args) `resize(self, int X, int Y, int W, int H)` row_header(self, *args) `row_header(self) -> int row_header(self, int flag)` row_header_color(self, *args) `row_header_color(self, Fl_Color val) row_header_color(self) -> Fl_Color` row_header_width(self, *args) `row_header_width(self, int width) row_header_width(self) -> int` row_height(self, *args) `row_height(self, int row, int height) row_height(self, int row) -> int` row_height_all(self, *args) `row_height_all(self, int height)` row_position(self, *args) `row_position(self, int row) row_position(self) -> int` row_resize(self, *args) `row_resize(self) -> int row_resize(self, int flag)` row_resize_min(self, *args) `row_resize_min(self) -> int row_resize_min(self, int val)` rows(self, *args) `rows(self, int val) rows(self) -> int` set_selection(self, *args) `set_selection(self, int s_top, int s_left, int s_bottom, int s_right)` table_box(self, *args) `table_box(self, Fl_Boxtype val) table_box(self) -> Fl_Boxtype` top_row(self, *args) `top_row(self, int row) top_row(self) -> int` visible_cells(self, *args) `visible_cells(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: CONTEXT_CELL = 16 CONTEXT_COL_HEADER = 8 CONTEXT_ENDPAGE = 2 CONTEXT_NONE = 0 CONTEXT_RC_RESIZE = 64 CONTEXT_ROW_HEADER = 4 CONTEXT_STARTPAGE = 1 CONTEXT_TABLE = 32 __swig_destroy__ = <built-in function delete_Fl_Table> `delete_Fl_Table(Fl_Table self)` Methods inherited from Fl_Group: add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Table_Row(Fl_Table)
`` | `This class implements a simple table of rows and columns that specializes in the selection of rows. This widget is similar in behavior to a 'mail subject browser', similar to that found in mozilla, netscape and outlook mail browsers. Most methods of importance will be found in the Fl_Table widget, such as rows() and cols(). To be useful it must be subclassed and at minimum the draw_cell() method must be overridden to provide the content of the cells. This widget does not manage the cell's data content; it is up to the parent class's draw_cell() method override to provide this. Events on the cells and/or headings generate callbacks when they are clicked by the user. You control when events are generated based on the values you supply for when().`
| Method resolution order: Fl_Table_Row Fl_Table Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Table_Row` __repr__ = _swig_repr(self) clear(self, *args) `clear(self)` draw_cell(self, *args) `draw_cell(self, TableContext context, int R = 0, int C = 0, int X = 0, int Y = 0, int W = 0, int H = 0)` find_cell(self, *args) `find_cell(self, TableContext context, int R, int C, int X, int Y, int W, int H) -> int` handle(self, *args) `handle(self, int event) -> int` row_selected(self, *args) `row_selected(self, int row) -> int` rows(self, *args) `rows(self, int val) rows(self) -> int` select_all_rows(self, *args) `select_all_rows(self, int flag = 1)` select_row(self, *args) `select_row(self, int row, int flag = 1) -> int` type(self, *args) `type(self, TableRowSelectMode val) type(self) -> TableRowSelectMode` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: SELECT_MULTI = 2 SELECT_NONE = 0 SELECT_SINGLE = 1 __swig_destroy__ = <built-in function delete_Fl_Table_Row> `delete_Fl_Table_Row(Fl_Table_Row self)` Methods inherited from Fl_Table: add(self, *args) `add(self, Fl_Widget w)` begin(self, *args) `begin(self)` callback_col(self, *args) `callback_col(self) -> int` callback_context(self, *args) `callback_context(self) -> TableContext` callback_row(self, *args) `callback_row(self) -> int` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` col_header(self, *args) `col_header(self) -> int col_header(self, int flag)` col_header_color(self, *args) `col_header_color(self, Fl_Color val) col_header_color(self) -> Fl_Color` col_header_height(self, *args) `col_header_height(self, int height) col_header_height(self) -> int` col_position(self, *args) `col_position(self, int col) col_position(self) -> int` col_resize(self, *args) `col_resize(self) -> int col_resize(self, int flag)` col_resize_min(self, *args) `col_resize_min(self) -> int col_resize_min(self, int val)` col_width(self, *args) `col_width(self, int col, int width) col_width(self, int col) -> int` col_width_all(self, *args) `col_width_all(self, int width)` cols(self, *args) `cols(self, int val) cols(self) -> int` do_callback(self, *args) `do_callback(self, TableContext context, int row, int col)` draw(self, *args) `draw(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget w) -> int` get_selection(self, *args) `get_selection(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget w, int n)` insert_before(self, *args) `insert_before(self, Fl_Widget w, Fl_Widget w2)` is_interactive_resize(self, *args) `is_interactive_resize(self) -> int` is_selected(self, *args) `is_selected(self, int r, int c) -> int` move_cursor(self, *args) `move_cursor(self, int R, int C) -> int` resize(self, *args) `resize(self, int X, int Y, int W, int H)` row_header(self, *args) `row_header(self) -> int row_header(self, int flag)` row_header_color(self, *args) `row_header_color(self, Fl_Color val) row_header_color(self) -> Fl_Color` row_header_width(self, *args) `row_header_width(self, int width) row_header_width(self) -> int` row_height(self, *args) `row_height(self, int row, int height) row_height(self, int row) -> int` row_height_all(self, *args) `row_height_all(self, int height)` row_position(self, *args) `row_position(self, int row) row_position(self) -> int` row_resize(self, *args) `row_resize(self) -> int row_resize(self, int flag)` row_resize_min(self, *args) `row_resize_min(self) -> int row_resize_min(self, int val)` set_selection(self, *args) `set_selection(self, int s_top, int s_left, int s_bottom, int s_right)` table_box(self, *args) `table_box(self, Fl_Boxtype val) table_box(self) -> Fl_Boxtype` top_row(self, *args) `top_row(self, int row) top_row(self) -> int` visible_cells(self, *args) `visible_cells(self)` Data and other attributes inherited from Fl_Table: CONTEXT_CELL = 16 CONTEXT_COL_HEADER = 8 CONTEXT_ENDPAGE = 2 CONTEXT_NONE = 0 CONTEXT_RC_RESIZE = 64 CONTEXT_ROW_HEADER = 4 CONTEXT_STARTPAGE = 1 CONTEXT_TABLE = 32 Methods inherited from Fl_Group: add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Tabs(Fl_Group)
`` | `The Fl_Tabs widget is the 'file card tabs' interface that allows you to put lots and lots of buttons and switches in a panel, as popularized by many toolkits. Clicking the tab makes a child visible() by calling show() on it, and all other children are made invisible by calling hide() on them. Usually the children are Fl_Group widgets containing several widgets themselves. Each child makes a card, and it's label() is printed on the card tab, including the label font and style. The selection color of that child is used to color the tab, while the color of the child determines the background color of the pane. The size of the tabs is controlled by the bounding box of the children (there should be some space between the children and the edge of the Fl_Tabs), and the tabs may be placed 'inverted' on the bottom, this is determined by which gap is larger. It is easiest to lay this out in fluid, using the fluid browser to select each child group and resize them until the tabs look the way you want them to.`
| Method resolution order: Fl_Tabs Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Tabs` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` push(self, *args) `push(self) -> Fl_Widget push(self, Fl_Widget arg0) -> int` value(self, *args) `value(self) -> Fl_Widget value(self, Fl_Widget arg0) -> int` which(self, *args) `which(self, int event_x, int event_y) -> Fl_Widget` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Tabs> `delete_Fl_Tabs(Fl_Tabs self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Text_Buffer(__builtin__.object)
`` | `The Fl_Text_Buffer class is used by the Fl_Text_Display and Fl_Text_Editor to manage complex text data and is based upon the excellent NEdit text editor engine - see http://www.nedit.org/.`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self, int requestedSize = 0) -> Fl_Text_Buffer` __repr__ = _swig_repr(self) add_modify_callback = __Fl_Text_BufferAddModifyCallback(self, *args) add_predelete_callback(self, *args) `add_predelete_callback(self, Fl_Text_Predelete_Cb bufPredelCB, void cbArg)` append(self, *args) `append(self, char t)` appendfile(self, *args) `appendfile(self, char file, int buflen = 128*1024) -> int` call_modify_callbacks(self, *args) `call_modify_callbacks(self)` call_predelete_callbacks(self, *args) `call_predelete_callbacks(self)` canUndo(self, *args) `canUndo(self, char flag = 1)` character(self, *args) `character(self, int pos) -> char` clear_rectangular(self, *args) `clear_rectangular(self, int start, int end, int rectStart, int rectEnd)` copy(self, *args) `copy(self, Fl_Text_Buffer fromBuf, int fromStart, int fromEnd, int toPos)` count_displayed_characters(self, *args) `count_displayed_characters(self, int lineStartPos, int targetPos) -> int` count_lines(self, *args) `count_lines(self, int startPos, int endPos) -> int` findchar_backward(self, *args) `findchar_backward(self, int startPos, char searchChar) -> int` findchar_forward(self, *args) `findchar_forward(self, int startPos, char searchChar) -> int` findchars_backward(self, *args) `findchars_backward(self, int startPos, char searchChars) -> int` findchars_forward(self, *args) `findchars_forward(self, int startPos, char searchChars) -> int` highlight(self, *args) `highlight(self, int start, int end) highlight(self) -> int` highlight_position(self, *args) `highlight_position(self, int start, int end) -> int highlight_position(self, int start, int end, int isRect, int rectStart, int rectEnd) -> int` highlight_rectangular(self, *args) `highlight_rectangular(self, int start, int end, int rectStart, int rectEnd)` highlight_selection(self, *args) `highlight_selection(self) -> Fl_Text_Selection` highlight_text(self, *args) `highlight_text(self) -> char` insert(self, *args) `insert(self, int pos, char text)` insert_column(self, *args) `insert_column(self, int column, int startPos, char text, int charsInserted, int charsDeleted)` insertfile(self, *args) `insertfile(self, char file, int pos, int buflen = 128*1024) -> int` length(self, *args) `length(self) -> int` line_end(self, *args) `line_end(self, int pos) -> int` line_start(self, *args) `line_start(self, int pos) -> int` line_text(self, *args) `line_text(self, int pos) -> char` loadfile(self, *args) `loadfile(self, char file, int buflen = 128*1024) -> int` null_substitution_character(self, *args) `null_substitution_character(self) -> char` outputfile(self, *args) `outputfile(self, char file, int start, int end, int buflen = 128*1024) -> int` overlay_rectangular(self, *args) `overlay_rectangular(self, int startPos, int rectStart, int rectEnd, char text, int charsInserted, int charsDeleted)` primary_selection(self, *args) `primary_selection(self) -> Fl_Text_Selection` remove(self, *args) `remove(self, int start, int end)` remove_modify_callback = __Fl_Text_BufferRemoveModifyCallback(self, *args) remove_predelete_callback(self, *args) `remove_predelete_callback(self, Fl_Text_Predelete_Cb predelCB, void cbArg)` remove_rectangular(self, *args) `remove_rectangular(self, int start, int end, int rectStart, int rectEnd)` remove_secondary_selection(self, *args) `remove_secondary_selection(self)` remove_selection(self, *args) `remove_selection(self)` replace(self, *args) `replace(self, int start, int end, char text)` replace_rectangular(self, *args) `replace_rectangular(self, int start, int end, int rectStart, int rectEnd, char text)` replace_secondary_selection(self, *args) `replace_secondary_selection(self, char text)` replace_selection(self, *args) `replace_selection(self, char text)` rewind_lines(self, *args) `rewind_lines(self, int startPos, int nLines) -> int` savefile(self, *args) `savefile(self, char file, int buflen = 128*1024) -> int` search_backward(self, *args) `search_backward(self, int startPos, char searchString, int matchCase = 0) -> int` search_forward(self, *args) `search_forward(self, int startPos, char searchString, int matchCase = 0) -> int` secondary_select(self, *args) `secondary_select(self, int start, int end)` secondary_select_rectangular(self, *args) `secondary_select_rectangular(self, int start, int end, int rectStart, int rectEnd)` secondary_selected(self, *args) `secondary_selected(self) -> int` secondary_selection(self, *args) `secondary_selection(self) -> Fl_Text_Selection` secondary_selection_position(self, *args) `secondary_selection_position(self, int start, int end) -> int secondary_selection_position(self, int start, int end, int isRect, int rectStart, int rectEnd) -> int` secondary_selection_text(self, *args) `secondary_selection_text(self) -> char` secondary_unselect(self, *args) `secondary_unselect(self)` select(self, *args) `select(self, int start, int end)` select_rectangular(self, *args) `select_rectangular(self, int start, int end, int rectStart, int rectEnd)` selected(self, *args) `selected(self) -> int` selection_position(self, *args) `selection_position(self, int start, int end) -> int selection_position(self, int start, int end, int isRect, int rectStart, int rectEnd) -> int` selection_text(self, *args) `selection_text(self) -> char` skip_displayed_characters(self, *args) `skip_displayed_characters(self, int lineStartPos, int nChars) -> int` skip_lines(self, *args) `skip_lines(self, int startPos, int nLines) -> int` substitute_null_characters(self, *args) `substitute_null_characters(self, char string, int length) -> int` tab_distance(self, *args) `tab_distance(self) -> int tab_distance(self, int tabDist)` text(self, *args) `text(self) -> char text(self, char text)` text_in_rectangle(self, *args) `text_in_rectangle(self, int start, int end, int rectStart, int rectEnd) -> char` text_range(self, *args) `text_range(self, int start, int end) -> char` undo(self, *args) `undo(self, int cp = None) -> int` unhighlight(self, *args) `unhighlight(self)` unselect(self, *args) `unselect(self)` unsubstitute_null_characters(self, *args) `unsubstitute_null_characters(self, char string)` word_end(self, *args) `word_end(self, int pos) -> int` word_start(self, *args) `word_start(self, int pos) -> int` Static methods defined here: character_width(*args) `character_width(char c, int indent, int tabDist, char nullSubsChar) -> int` expand_character(*args) `expand_character(int pos, int indent, char outStr) -> int expand_character(char c, int indent, char outStr, int tabDist, char nullSubsChar) -> int` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Text_Buffer> `delete_Fl_Text_Buffer(Fl_Text_Buffer self)`
class Fl_Text_Display(Fl_Group)
`` | `This is the FLTK text display widget. It allows the user to view multiple lines of text and supports highlighting and scrolling. The buffer that is displayed in the widget is managed by the Fl_Text_Buffer class.`
| Method resolution order: Fl_Text_Display Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Text_Display` __repr__ = _swig_repr(self) buffer(self, *args) `buffer(self, Fl_Text_Buffer buf) buffer(self) -> Fl_Text_Buffer` count_lines(self, *args) `count_lines(self, int start, int end, bool start_pos_is_line_start) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, Fl_Color n)` cursor_style(self, *args) `cursor_style(self, int style)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int e) -> int` hide_cursor(self, *args) `hide_cursor(self)` highlight_data(self, *args) `highlight_data(self, Fl_Text_Buffer styleBuffer, Fl_Text_Display::Style_Table_Entry styleTable, int nStyles, char unfinishedStyle, PyObject func, PyObject cbArg)` in_selection(self, *args) `in_selection(self, int x, int y) -> int` insert(self, *args) `insert(self, char text)` insert_position(self, *args) `insert_position(self, int newPos) insert_position(self) -> int` line_end(self, *args) `line_end(self, int pos, bool start_pos_is_line_start) -> int` line_start(self, *args) `line_start(self, int pos) -> int` move_down(self, *args) `move_down(self) -> int` move_left(self, *args) `move_left(self) -> int` move_right(self, *args) `move_right(self) -> int` move_up(self, *args) `move_up(self) -> int` next_word(self, *args) `next_word(self)` overstrike(self, *args) `overstrike(self, char text)` position_style(self, *args) `position_style(self, int lineStartPos, int lineLen, int lineIndex, int dispIndex) -> int` previous_word(self, *args) `previous_word(self)` redisplay_range(self, *args) `redisplay_range(self, int start, int end)` resize(self, *args) `resize(self, int X, int Y, int W, int H)` rewind_lines(self, *args) `rewind_lines(self, int startPos, int nLines) -> int` scroll(self, *args) `scroll(self, int topLineNum, int horizOffset)` scrollbar_align(self, *args) `scrollbar_align(self) -> Fl_Align scrollbar_align(self, Fl_Align a)` scrollbar_width(self, *args) `scrollbar_width(self) -> int scrollbar_width(self, int W)` show_cursor(self, *args) `show_cursor(self, int b = 1)` show_insert_position(self, *args) `show_insert_position(self)` skip_lines(self, *args) `skip_lines(self, int startPos, int nLines, bool startPosIsLineStart) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` word_end(self, *args) `word_end(self, int pos) -> int` word_start(self, *args) `word_start(self, int pos) -> int` wrap_mode(self, *args) `wrap_mode(self, int wrap, int wrap_margin)` wrapped_column(self, *args) `wrapped_column(self, int row, int column) -> int` wrapped_row(self, *args) `wrapped_row(self, int row) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: ATTR_HIDDEN = 2 ATTR_NONE = 0 ATTR_UNDERLINE = 1 BLOCK_CURSOR = 3 CARET_CURSOR = 1 CHARACTER_POS = 1 CURSOR_POS = 0 DIM_CURSOR = 2 DRAG_CHAR = 0 DRAG_LINE = 2 DRAG_WORD = 1 HEAVY_CURSOR = 4 NORMAL_CURSOR = 0 __swig_destroy__ = <built-in function delete_Fl_Text_Display> `delete_Fl_Text_Display(Fl_Text_Display self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Text_Editor(Fl_Text_Display)
`` | `This is the FLTK text editor widget. It allows the user to edit multiple lines of text and supports highlighting and scrolling. The buffer that is displayed in the widget is managed by the Fl_Text_Buffer class.`
| Method resolution order: Fl_Text_Editor Fl_Text_Display Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Text_Editor` __repr__ = _swig_repr(self) add_key_binding(self, *args) `add_key_binding(self, int key, int state, Key_Func f)` bound_key_function(self, *args) `bound_key_function(self, int key, int state) -> Key_Func` default_key_function(self, *args) `default_key_function(self, Key_Func f)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int e) -> int` insert_mode(self, *args) `insert_mode(self, int b) insert_mode(self) -> int` remove_all_key_bindings(self, *args) `remove_all_key_bindings(self)` remove_key_binding(self, *args) `remove_key_binding(self, int key, int state)` Static methods defined here: kf_backspace(*args) `kf_backspace(int c, Fl_Text_Editor e) -> int` kf_c_s_move(*args) `kf_c_s_move(int c, Fl_Text_Editor e) -> int` kf_copy(*args) `kf_copy(int c, Fl_Text_Editor e) -> int` kf_ctrl_move(*args) `kf_ctrl_move(int c, Fl_Text_Editor e) -> int` kf_cut(*args) `kf_cut(int c, Fl_Text_Editor e) -> int` kf_default(*args) `kf_default(int c, Fl_Text_Editor e) -> int` kf_delete(*args) `kf_delete(int c, Fl_Text_Editor e) -> int` kf_down(*args) `kf_down(int c, Fl_Text_Editor e) -> int` kf_end(*args) `kf_end(int c, Fl_Text_Editor e) -> int` kf_enter(*args) `kf_enter(int c, Fl_Text_Editor e) -> int` kf_home(*args) `kf_home(int arg0, Fl_Text_Editor e) -> int` kf_ignore(*args) `kf_ignore(int c, Fl_Text_Editor e) -> int` kf_insert(*args) `kf_insert(int c, Fl_Text_Editor e) -> int` kf_left(*args) `kf_left(int c, Fl_Text_Editor e) -> int` kf_move(*args) `kf_move(int c, Fl_Text_Editor e) -> int` kf_page_down(*args) `kf_page_down(int c, Fl_Text_Editor e) -> int` kf_page_up(*args) `kf_page_up(int c, Fl_Text_Editor e) -> int` kf_paste(*args) `kf_paste(int c, Fl_Text_Editor e) -> int` kf_right(*args) `kf_right(int c, Fl_Text_Editor e) -> int` kf_select_all(*args) `kf_select_all(int c, Fl_Text_Editor e) -> int` kf_shift_move(*args) `kf_shift_move(int c, Fl_Text_Editor e) -> int` kf_undo(*args) `kf_undo(int c, Fl_Text_Editor e) -> int` kf_up(*args) `kf_up(int c, Fl_Text_Editor e) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Text_Editor> `delete_Fl_Text_Editor(Fl_Text_Editor self)` Methods inherited from Fl_Text_Display: buffer(self, *args) `buffer(self, Fl_Text_Buffer buf) buffer(self) -> Fl_Text_Buffer` count_lines(self, *args) `count_lines(self, int start, int end, bool start_pos_is_line_start) -> int` cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, Fl_Color n)` cursor_style(self, *args) `cursor_style(self, int style)` hide_cursor(self, *args) `hide_cursor(self)` highlight_data(self, *args) `highlight_data(self, Fl_Text_Buffer styleBuffer, Fl_Text_Display::Style_Table_Entry styleTable, int nStyles, char unfinishedStyle, PyObject func, PyObject cbArg)` in_selection(self, *args) `in_selection(self, int x, int y) -> int` insert(self, *args) `insert(self, char text)` insert_position(self, *args) `insert_position(self, int newPos) insert_position(self) -> int` line_end(self, *args) `line_end(self, int pos, bool start_pos_is_line_start) -> int` line_start(self, *args) `line_start(self, int pos) -> int` move_down(self, *args) `move_down(self) -> int` move_left(self, *args) `move_left(self) -> int` move_right(self, *args) `move_right(self) -> int` move_up(self, *args) `move_up(self) -> int` next_word(self, *args) `next_word(self)` overstrike(self, *args) `overstrike(self, char text)` position_style(self, *args) `position_style(self, int lineStartPos, int lineLen, int lineIndex, int dispIndex) -> int` previous_word(self, *args) `previous_word(self)` redisplay_range(self, *args) `redisplay_range(self, int start, int end)` resize(self, *args) `resize(self, int X, int Y, int W, int H)` rewind_lines(self, *args) `rewind_lines(self, int startPos, int nLines) -> int` scroll(self, *args) `scroll(self, int topLineNum, int horizOffset)` scrollbar_align(self, *args) `scrollbar_align(self) -> Fl_Align scrollbar_align(self, Fl_Align a)` scrollbar_width(self, *args) `scrollbar_width(self) -> int scrollbar_width(self, int W)` show_cursor(self, *args) `show_cursor(self, int b = 1)` show_insert_position(self, *args) `show_insert_position(self)` skip_lines(self, *args) `skip_lines(self, int startPos, int nLines, bool startPosIsLineStart) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` word_end(self, *args) `word_end(self, int pos) -> int` word_start(self, *args) `word_start(self, int pos) -> int` wrap_mode(self, *args) `wrap_mode(self, int wrap, int wrap_margin)` wrapped_column(self, *args) `wrapped_column(self, int row, int column) -> int` wrapped_row(self, *args) `wrapped_row(self, int row) -> int` Data and other attributes inherited from Fl_Text_Display: ATTR_HIDDEN = 2 ATTR_NONE = 0 ATTR_UNDERLINE = 1 BLOCK_CURSOR = 3 CARET_CURSOR = 1 CHARACTER_POS = 1 CURSOR_POS = 0 DIM_CURSOR = 2 DRAG_CHAR = 0 DRAG_LINE = 2 DRAG_WORD = 1 HEAVY_CURSOR = 4 NORMAL_CURSOR = 0 Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Text_Selection(__builtin__.object)
`` | `Proxy of C++ Fl_Text_Selection class`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Fl_Text_Selection` __repr__ = _swig_repr(self) end(self, *args) `end(self) -> int` includes(self, *args) `includes(self, int pos, int lineStartPos, int dispIndex) -> int` position(self, *args) `position(self, int start, int end) -> int position(self, int start, int end, int isRect, int rectStart, int rectEnd) -> int` rect_end(self, *args) `rect_end(self) -> int` rect_start(self, *args) `rect_start(self) -> int` rectangular(self, *args) `rectangular(self) -> char` selected(self, *args) `selected(self) -> char selected(self, char b)` set(self, *args) `set(self, int start, int end)` set_rectangular(self, *args) `set_rectangular(self, int start, int end, int rectStart, int rectEnd)` start(self, *args) `start(self) -> int` update(self, *args) `update(self, int pos, int nDeleted, int nInserted)` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Text_Selection> `delete_Fl_Text_Selection(Fl_Text_Selection self)`
class Fl_Tile(Fl_Group)
`` | `The Fl_Tile class lets you resize the children by dragging the border between them: Fl_Tile allows objects to be resized to zero dimensions. To prevent this you can use the resizable() to limit where corners can be dragged to. Even though objects can be resized to zero sizes, they must initially have non-zero sizes so the Fl_Tile can figure out their layout. If desired, call position() after creating the children but before displaying the window to set the borders where you want. The 'borders' are part of the children - Fl_Tile does not draw any graphics of its own. In the example above, all of the children have FL_DOWN_BOX types, and the 'ridges' you see are actually two adjacent FL_DOWN_BOX's drawn next to each other. All neighboring widgets share the same edge - the widget's thick borders make it appear as though the widgets aren't actually touching, but they are. If the edges of adjacent widgets do not touch, then it will be impossible to drag the corresponding edges.`
| Method resolution order: Fl_Tile Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Tile` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` position(self, *args) `position(self, int arg0, int arg1, int arg2, int arg3)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Tile> `delete_Fl_Tile(Fl_Tile self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Tiled_Image(Fl_Image)
`` | `The Fl_Tiled_Image class supports tiling of images over a specified area. The source (tile) image is not copied unless you call the color_average(), desaturate(), or inactive() methods.`
| Method resolution order: Fl_Tiled_Image Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, Fl_Image i, int W = 0, int H = 0) -> Fl_Tiled_Image` __repr__ = _swig_repr(self) color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx, int cy) draw(self, int X, int Y)` image(self, *args) `image(self) -> Fl_Image` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Tiled_Image> `delete_Fl_Tiled_Image(Fl_Tiled_Image self)` Methods inherited from Fl_Image: count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` ld(self, *args) `ld(self) -> int` uncache(self, *args) `uncache(self)` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Timer(Fl_Widget)
`` | `This is provided only to emulate the Forms Timer widget. It works by making a timeout callback every 1/5 second. This is wasteful and inaccurate if you just want something to happen a fixed time in the future. You should directly call Fl::add_timeout() instead.`
| Method resolution order: Fl_Timer Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, uchar t, int x, int y, int w, int h, char l) -> Fl_Timer` __repr__ = _swig_repr(self) direction(self, *args) `direction(self) -> char direction(self, char d)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` suspended(self, *args) `suspended(self) -> char suspended(self, char d)` value(self, *args) `value(self, double arg0) value(self) -> double` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Timer> `delete_Fl_Timer(Fl_Timer self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Toggle_Button(Fl_Button)
`` | `Proxy of C++ Fl_Toggle_Button class`
| Method resolution order: Fl_Toggle_Button Fl_Button Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H, char l = None) -> Fl_Toggle_Button` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Toggle_Button> `delete_Fl_Toggle_Button(Fl_Toggle_Button self)` Methods inherited from Fl_Button: clear(self, *args) `clear(self) -> int` down_box(self, *args) `down_box(self) -> Fl_Boxtype down_box(self, Fl_Boxtype b)` down_color(self, *args) `down_color(self) -> Fl_Color down_color(self, unsigned int c)` handle(self, *args) `handle(self, int arg0) -> int` set(self, *args) `set(self) -> int` setonly(self, *args) `setonly(self)` shortcut(self, *args) `shortcut(self) -> int shortcut(self, int s) shortcut(self, char s)` value(self, *args) `value(self, int arg0) -> int value(self) -> char` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Tooltip(__builtin__.object)
`` | `The Fl_Tooltip class provides tooltip support for all FLTK widgets.`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Fl_Tooltip` __repr__ = _swig_repr(self) Static methods defined here: color(*args) `color(unsigned int c) color() -> Fl_Color` current(*args) `current() -> Fl_Widget current(Fl_Widget arg0)` delay(*args) `delay() -> float delay(float f)` disable(*args) `disable()` enable(*args) `enable(int b = 1)` enabled(*args) `enabled() -> int` enter_(*args) `enter_(Fl_Widget w)` enter_area(*args) `enter_area(Fl_Widget w, int X, int Y, int W, int H, char tip)` exit_(*args) `exit_(Fl_Widget w)` font(*args) `font() -> int font(int i)` hoverdelay(*args) `hoverdelay() -> float hoverdelay(float f)` size(*args) `size() -> int size(int s)` textcolor(*args) `textcolor(unsigned int c) textcolor() -> Fl_Color` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Tooltip> `delete_Fl_Tooltip(Fl_Tooltip self)`
class Fl_Valuator(Fl_Widget)
`` | `The Fl_Valuator class controls a single floating-point value and provides a consistent interface to set the value, range, and step, and insures that callbacks are done the same for every object.`
| Method resolution order: Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __init__(self, *args, **kwargs) __repr__ = _swig_repr(self) bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Valuator> `delete_Fl_Valuator(Fl_Valuator self)` Methods inherited from Fl_Widget: __disown__(self) activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw(self, *args) `draw(self)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Value_Input(Fl_Valuator)
`` | `The Fl_Value_Input widget displays a numeric value. The user can click in the text field and edit it - there is in fact a hidden Fl_Input widget with type(FL_FLOAT_INPUT) or type(FL_INT_INPUT) in there - and when they hit return or tab the value updates to what they typed and the callback is done. If step() is non-zero, the user can also drag the mouse across the object and thus slide the value. The left button moves one step() per pixel, the middle by 10 * step(), and the right button by 100 * step(). It is therefore impossible to select text by dragging across it, although clicking can still move the insertion cursor. If step() is non-zero and integral, then the range of numbers are limited to integers instead of floating point values.`
| Method resolution order: Fl_Value_Input Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Value_Input` __repr__ = _swig_repr(self) cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` soft(self, *args) `soft(self, char s) soft(self) -> char` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Value_Input> `delete_Fl_Value_Input(Fl_Value_Input self)` Methods inherited from Fl_Valuator: bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Value_Output(Fl_Valuator)
`` | `The Fl_Value_Output widget displays a floating point value. If step() is not zero, the user can adjust the value by dragging the mouse left and right. The left button moves one step() per pixel, the middle by 10 * step(), and the right button by 100 * step(). This is much lighter-weight than Fl_Value_Input because it contains no text editing code or character buffer.`
| Method resolution order: Fl_Value_Output Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Value_Output` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` soft(self, *args) `soft(self, uchar s) soft(self) -> uchar` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int s)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Value_Output> `delete_Fl_Value_Output(Fl_Value_Output self)` Methods inherited from Fl_Valuator: bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Value_Slider(Fl_Slider)
`` | `The Fl_Value_Slider widget is a Fl_Slider widget with a box displaying the current value.`
| Method resolution order: Fl_Value_Slider Fl_Slider Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char l = None) -> Fl_Value_Slider` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int s)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Value_Slider> `delete_Fl_Value_Slider(Fl_Value_Slider self)` Methods inherited from Fl_Slider: bounds(self, *args) `bounds(self, double a, double b)` scrollvalue(self, *args) `scrollvalue(self, int windowtop, int windowsize, int first, int totalsize) -> int` slider(self, *args) `slider(self) -> Fl_Boxtype slider(self, Fl_Boxtype c)` slider_size(self, *args) `slider_size(self) -> float slider_size(self, double v)` Methods inherited from Fl_Valuator: clamp(self, *args) `clamp(self, double arg0) -> double` format(self, *args) `format(self, char format_string) -> int` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Widget(__builtin__.object)
`` | `Fl_Widget is the base class for all widgets in FLTK. You can't create one of these because the constructor is not public. However you can subclass it. All 'property' accessing methods, such as color(), parent(), or argument() are implemented as trivial inline functions and thus are as fast and small as accessing fields in a structure. Unless otherwise noted, the property setting methods such as color(n) or label(s) are also trivial inline functions, even if they change the widget's appearance. It is up to the user code to call redraw() after these.`
| Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Widget` __repr__ = _swig_repr(self) activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw(self, *args) `draw(self)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods defined here: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Widget> `delete_Fl_Widget(Fl_Widget self)`
class Fl_Window(Fl_Group)
`` | `This widget produces an actual window. This can either be a main window, with a border and title and all the window management controls, or a 'subwindow' inside a window. This is controlled by whether or not the window has a parent(). Once you create a window, you usually add children Fl_Widget 's to it by using window->add(child) for each new widget. See Fl_Group for more information on how to add and remove children. There are several subclasses of Fl_Window that provide double-buffering, overlay, menu, and OpenGL support. The window's callback is done if the user tries to close a window using the window manager and Fl.modal() is zero or equal to the window. Fl_Window has a default callback that calls Fl_Window.hide().`
| Method resolution order: Fl_Window Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Window __init__(self, int arg0, int arg1, char arg2 = None) -> Fl_Window` __repr__ = _swig_repr(self) border(self, *args) `border(self, int b) border(self) -> int` clear_border(self, *args) `clear_border(self)` copy_label(self, *args) `copy_label(self, char a)` cursor(self, *args) `cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` default_cursor(self, *args) `default_cursor(self, Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` draw(self, *args) `draw(self)` flush(self, *args) `flush(self)` free_position(self, *args) `free_position(self)` fullscreen(self, *args) `fullscreen(self)` fullscreen_off(self, *args) `fullscreen_off(self, int arg0, int arg1, int arg2, int arg3)` handle(self, *args) `handle(self, int arg0) -> int` hide(self, *args) `hide(self)` hotspot(self, *args) `hotspot(self, int x, int y, int offscreen = 0) hotspot(self, Fl_Widget arg0, int offscreen = 0)` icon(self, *args) `icon(self) -> void icon(self, void ic)` iconize(self, *args) `iconize(self)` iconlabel(self, *args) `iconlabel(self) -> char iconlabel(self, char arg0)` label(self, *args) `label(self) -> char label(self, char arg0) label(self, char label, char iconlabel)` make_current(self, *args) `make_current(self)` modal(self, *args) `modal(self) -> int` non_modal(self, *args) `non_modal(self) -> int` override(self, *args) `override(self) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` set_modal(self, *args) `set_modal(self)` set_non_modal(self, *args) `set_non_modal(self)` set_override(self, *args) `set_override(self)` show(self, *args) `show(self, PyObject count = None, PyObject data = None)` shown(self, *args) `shown(self) -> int` size_range(self, *args) `size_range(self, int a, int b, int c = 0, int d = 0, int e = 0, int f = 0, int g = 0)` x_root(self, *args) `x_root(self) -> int` xclass(self, *args) `xclass(self) -> char xclass(self, char c)` y_root(self, *args) `y_root(self) -> int` Static methods defined here: current(*args) `current() -> Fl_Window` default_callback(*args) `default_callback(Fl_Window arg0, void v)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Window> `delete_Fl_Window(Fl_Window self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_Wizard(Fl_Group)
`` | `The Fl_Wizard widget is based off the Fl_Tabs widget, but instead of displaying tabs it only changes 'tabs' under program control. Its primary purpose is to support 'wizards' that step a user through configuration or troubleshooting tasks. As with Fl_Tabs, wizard panes are composed of child (usually Fl_Group) widgets. Navigation buttons must be added separately.`
| Method resolution order: Fl_Wizard Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int arg0, int arg1, int arg2, int arg3, char arg4 = None) -> Fl_Wizard` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` next(self, *args) `next(self)` prev(self, *args) `prev(self)` value(self, *args) `value(self) -> Fl_Widget value(self, Fl_Widget arg0)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_Wizard> `delete_Fl_Wizard(Fl_Wizard self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` handle(self, *args) `handle(self, int arg0) -> int` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_XBM_Image(Fl_Bitmap)
`` | `The Fl_XBM_Image class supports loading, caching, and drawing of X Bitmap (XBM) bitmap files.`
| Method resolution order: Fl_XBM_Image Fl_Bitmap Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, char filename) -> Fl_XBM_Image` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_XBM_Image> `delete_Fl_XBM_Image(Fl_XBM_Image self)` Methods inherited from Fl_Bitmap: copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` uncache(self, *args) `uncache(self)` Methods inherited from Fl_Image: color_average(self, *args) `color_average(self, Fl_Color c, float i)` count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` desaturate(self, *args) `desaturate(self)` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Fl_XPM_Image(Fl_Pixmap)
`` | `The Fl_XPM_Image class supports loading, caching, and drawing of X Pixmap (XPM) images, including transparency.`
| Method resolution order: Fl_XPM_Image Fl_Pixmap Fl_Image __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, char filename) -> Fl_XPM_Image` __repr__ = _swig_repr(self) Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Fl_XPM_Image> `delete_Fl_XPM_Image(Fl_XPM_Image self)` Methods inherited from Fl_Pixmap: color_average(self, *args) `color_average(self, Fl_Color c, float i)` copy(self, *args) `copy(self, int W, int H) -> Fl_Image copy(self) -> Fl_Image` desaturate(self, *args) `desaturate(self)` draw(self, *args) `draw(self, int X, int Y, int W, int H, int cx = 0, int cy = 0) draw(self, int X, int Y)` label(self, *args) `label(self, Fl_Widget w) label(self, Fl_Menu_Item m)` uncache(self, *args) `uncache(self)` Methods inherited from Fl_Image: count(self, *args) `count(self) -> int` d(self, *args) `d(self) -> int` data(self, *args) `data(self) -> char` h(self, *args) `h(self) -> int` inactive(self, *args) `inactive(self)` ld(self, *args) `ld(self) -> int` w(self, *args) `w(self) -> int` Data descriptors inherited from Fl_Image: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Flcc_HueBox(Fl_Widget)
`` | `Proxy of C++ Flcc_HueBox class`
| Method resolution order: Flcc_HueBox Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H) -> Flcc_HueBox` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Flcc_HueBox> `delete_Flcc_HueBox(Flcc_HueBox self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Flcc_ValueBox(Fl_Widget)
`` | `Proxy of C++ Flcc_ValueBox class`
| Method resolution order: Flcc_ValueBox Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H) -> Flcc_ValueBox` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Flcc_ValueBox> `delete_Flcc_ValueBox(Flcc_ValueBox self)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Flcc_Value_Input(Fl_Value_Input)
`` | `Proxy of C++ Flcc_Value_Input class`
| Method resolution order: Flcc_Value_Input Fl_Value_Input Fl_Valuator Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int X, int Y, int W, int H) -> Flcc_Value_Input` __repr__ = _swig_repr(self) format(self, *args) `format(self, char arg0) -> int` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Flcc_Value_Input> `delete_Flcc_Value_Input(Flcc_Value_Input self)` Methods inherited from Fl_Value_Input: cursor_color(self, *args) `cursor_color(self) -> Fl_Color cursor_color(self, unsigned int n)` draw(self, *args) `draw(self)` handle(self, *args) `handle(self, int arg0) -> int` resize(self, *args) `resize(self, int arg0, int arg1, int arg2, int arg3)` soft(self, *args) `soft(self, char s) soft(self) -> char` textcolor(self, *args) `textcolor(self) -> Fl_Color textcolor(self, unsigned int n)` textfont(self, *args) `textfont(self) -> Fl_Font textfont(self, uchar s)` textsize(self, *args) `textsize(self) -> uchar textsize(self, uchar s)` Methods inherited from Fl_Valuator: bounds(self, *args) `bounds(self, double a, double b)` clamp(self, *args) `clamp(self, double arg0) -> double` increment(self, *args) `increment(self, double arg0, int arg1) -> double` maximum(self, *args) `maximum(self) -> double maximum(self, double a)` minimum(self, *args) `minimum(self) -> double minimum(self, double a)` precision(self, *args) `precision(self, int arg0)` range(self, *args) `range(self, double a, double b)` round(self, *args) `round(self, double arg0) -> double` step(self, *args) `step(self, int a) step(self, double a, int b) step(self, double s) step(self) -> double` value(self, *args) `value(self) -> double value(self, double arg0) -> int` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class ListSelect(Fl_Group)
`` | `Proxy of C++ ListSelect class`
| Method resolution order: ListSelect Fl_Group Fl_Widget __builtin__.object Methods defined here: __del__ lambda self __disown__(self) __init__(self, *args) `__init__(self, int x, int y, int w, int h, char topLabel = None, char bottomLabel = None) -> ListSelect` __repr__ = _swig_repr(self) draw(self, *args) `draw(self)` getBottomBrowser(self, *args) `getBottomBrowser(self) -> Fl_Multi_Browser` getTopBrowser(self, *args) `getTopBrowser(self) -> Fl_Multi_Browser` resize(self, *args) `resize(self, int x, int y, int w, int h)` Data descriptors defined here: thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_ListSelect> `delete_ListSelect(ListSelect self)` Methods inherited from Fl_Group: add(self, *args) `add(self, Fl_Widget o)` add_resizable(self, *args) `add_resizable(self, Fl_Widget o)` begin(self, *args) `begin(self)` child(self, *args) `child(self, int n) -> Fl_Widget` children(self, *args) `children(self) -> int` clear(self, *args) `clear(self)` end(self, *args) `end(self)` find(self, *args) `find(self, Fl_Widget o) -> int` focus(self, *args) `focus(self, Fl_Widget o)` forms_end(self, *args) `forms_end(self)` handle(self, *args) `handle(self, int arg0) -> int` init_sizes(self, *args) `init_sizes(self)` insert(self, *args) `insert(self, Fl_Widget arg0, int i)` insert_before(self, *args) `insert_before(self, Fl_Widget o, Fl_Widget before)` remove(self, *args) `remove(self, Fl_Widget o)` resizable(self, *args) `resizable(self, Fl_Widget o) resizable(self) -> Fl_Widget` Static methods inherited from Fl_Group: current(*args) `current() -> Fl_Group current(Fl_Group g)` Methods inherited from Fl_Widget: activate(self, *args) `activate(self)` active(self, *args) `active(self) -> int` active_r(self, *args) `active_r(self) -> int` align(self, *args) `align(self) -> Fl_Align align(self, uchar a)` argument(self, *args) `argument(self) -> long argument(self, long v)` box(self, *args) `box(self) -> Fl_Boxtype box(self, Fl_Boxtype a)` callback = __Fl_WidgetCallback(self, *args) changed(self, *args) `changed(self) -> int` clear_changed(self, *args) `clear_changed(self)` clear_damage(self, *args) `clear_damage(self, uchar c = 0)` clear_output(self, *args) `clear_output(self)` clear_visible(self, *args) `clear_visible(self)` clear_visible_focus(self, *args) `clear_visible_focus(self)` color(self, *args) `color(self) -> Fl_Color color(self, unsigned int a) color(self, unsigned int a, unsigned int b)` color2(self, *args) `color2(self) -> Fl_Color color2(self, unsigned int a)` contains(self, *args) `contains(self, Fl_Widget arg0) -> int` copy_label(self, *args) `copy_label(self, char a)` damage(self, *args) `damage(self) -> uchar damage(self, uchar c) damage(self, uchar c, int arg1, int arg2, int arg3, int arg4)` damage_resize(self, *args) `damage_resize(self, int arg0, int arg1, int arg2, int arg3) -> int` deactivate(self, *args) `deactivate(self)` deimage(self, *args) `deimage(self) -> Fl_Image deimage(self, Fl_Image a)` do_callback(self, *args) `do_callback(self) do_callback(self, Fl_Widget o, void arg = None) do_callback(self, Fl_Widget o, long arg)` draw_label(self, *args) `draw_label(self, int arg0, int arg1, int arg2, int arg3, Fl_Align arg4)` h(self, *args) `h(self) -> int` hide(self, *args) `hide(self)` image(self, *args) `image(self) -> Fl_Image image(self, Fl_Image a)` inside(self, *args) `inside(self, Fl_Widget o) -> int` label(self, *args) `label(self) -> char label(self, char a) label(self, Fl_Labeltype a, char b)` labelcolor(self, *args) `labelcolor(self) -> Fl_Color labelcolor(self, unsigned int a)` labelfont(self, *args) `labelfont(self) -> Fl_Font labelfont(self, uchar a)` labelsize(self, *args) `labelsize(self) -> uchar labelsize(self, uchar a)` labeltype(self, *args) `labeltype(self) -> Fl_Labeltype labeltype(self, Fl_Labeltype a)` measure_label(self, *args) `measure_label(self, int xx, int yy)` output(self, *args) `output(self) -> int` parent(self, *args) `parent(self) -> Fl_Group parent(self, Fl_Group p)` position(self, *args) `position(self, int X, int Y)` redraw(self, *args) `redraw(self)` redraw_label(self, *args) `redraw_label(self)` selection_color(self, *args) `selection_color(self) -> Fl_Color selection_color(self, unsigned int a)` set_changed(self, *args) `set_changed(self)` set_output(self, *args) `set_output(self)` set_visible(self, *args) `set_visible(self)` set_visible_focus(self, *args) `set_visible_focus(self)` show(self, *args) `show(self)` size(self, *args) `size(self, int W, int H)` take_focus(self, *args) `take_focus(self) -> int` takesevents(self, *args) `takesevents(self) -> int` tooltip(self, *args) `tooltip(self) -> char tooltip(self, char t)` type(self, *args) `type(self) -> uchar type(self, uchar t)` user_data(self, *args) `user_data(self) user_data(self, void v) user_data(self, PyObject PyData) user_data(self) -> PyObject` visible(self, *args) `visible(self) -> int` visible_focus(self, *args) `visible_focus(self, int v) visible_focus(self) -> int` visible_r(self, *args) `visible_r(self) -> int` w(self, *args) `w(self) -> int` when(self, *args) `when(self) -> Fl_When when(self, uchar i)` window(self, *args) `window(self) -> Fl_Window` x(self, *args) `x(self) -> int` y(self, *args) `y(self) -> int` Static methods inherited from Fl_Widget: default_callback(*args) `default_callback(Fl_Widget arg0, void arg1)` label_shortcut(*args) `label_shortcut(char t) -> char` test_shortcut(*args) `test_shortcut() -> int test_shortcut(char arg0) -> int` Data descriptors inherited from Fl_Widget: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Style_Table_Entry(__builtin__.object)
`` | `Proxy of C++ Style_Table_Entry class`
| Methods defined here: __del__ lambda self __init__(self, *args) `__init__(self) -> Style_Table_Entry` __repr__ = _swig_repr(self) Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` thisown `The membership flag` Data and other attributes defined here: __swig_destroy__ = <built-in function delete_Style_Table_Entry> `delete_Style_Table_Entry(Style_Table_Entry self)`

Functions
`` |  | FL_CHART_ENTRY_swigregister(...) Fl_Adjuster_swigregister(...) Fl_BMP_Image_swigregister(...) Fl_Bitmap_swigregister(...) Fl_Box_swigregister(...) Fl_Browser__scrollbar_width(*args) `scrollbar_width(int b) Fl_Browser__scrollbar_width() -> int` Fl_Browser__swigregister(...) Fl_Browser_swigregister(...) Fl_Button_swigregister(...) Fl_Chart_swigregister(...) Fl_Check_Browser_swigregister(...) Fl_Check_Button_swigregister(...) Fl_Choice_swigregister(...) Fl_Clock_Output_swigregister(...) Fl_Clock_swigregister(...) Fl_Color_Chooser_hsv2rgb(*args) `Fl_Color_Chooser_hsv2rgb(double arg0, double arg1, double arg2, double arg3, double arg4, double arg5)` Fl_Color_Chooser_rgb2hsv(*args) `Fl_Color_Chooser_rgb2hsv(double arg0, double arg1, double arg2, double arg3, double arg4, double arg5)` Fl_Color_Chooser_swigregister(...) Fl_Counter_swigregister(...) Fl_Dial_swigregister(...) Fl_Double_Window_swigregister(...) Fl_End_swigregister(...) Fl_File_Browser_swigregister(...) Fl_File_Chooser_swigregister(...) Fl_File_Icon_find(*args) `Fl_File_Icon_find(char filename, int filetype = ANY) -> Fl_File_Icon` Fl_File_Icon_first(*args) `Fl_File_Icon_first() -> Fl_File_Icon` Fl_File_Icon_labeltype(*args) `Fl_File_Icon_labeltype(Fl_Label o, int x, int y, int w, int h, Fl_Align a)` Fl_File_Icon_load_system_icons(*args) `Fl_File_Icon_load_system_icons()` Fl_File_Icon_swigregister(...) Fl_File_Input_swigregister(...) Fl_Fill_Dial_swigregister(...) Fl_Fill_Slider_swigregister(...) Fl_Float_Input_swigregister(...) Fl_FormsBitmap_swigregister(...) Fl_FormsPixmap_swigregister(...) Fl_Free_swigregister(...) Fl_GIF_Image_swigregister(...) Fl_Gl_Window_swigregister(...) Fl_Group_current(*args) `current() -> Fl_Group Fl_Group_current(Fl_Group g)` Fl_Group_swigregister(...) Fl_Help_Block_swigregister(...) Fl_Help_Dialog_swigregister(...) Fl_Help_Link_swigregister(...) Fl_Help_Target_swigregister(...) Fl_Help_View_swigregister(...) Fl_Hold_Browser_swigregister(...) Fl_Hor_Fill_Slider_swigregister(...) Fl_Hor_Nice_Slider_swigregister(...) Fl_Hor_Slider_swigregister(...) Fl_Hor_Value_Slider_swigregister(...) Fl_Image_swigregister(...) Fl_Input_Choice_swigregister(...) Fl_Input__swigregister(...) Fl_Input_swigregister(...) Fl_Int_Input_swigregister(...) Fl_JPEG_Image_swigregister(...) Fl_Label_swigregister(...) Fl_Light_Button_swigregister(...) Fl_Line_Dial_swigregister(...) Fl_Menu_Bar_swigregister(...) Fl_Menu_Button_swigregister(...) Fl_Menu_Item_swigregister(...) Fl_Menu_Window_swigregister(...) Fl_Menu__swigregister(...) Fl_Multi_Browser_swigregister(...) Fl_Multi_Label_swigregister(...) Fl_Multiline_Input_swigregister(...) Fl_Multiline_Output_swigregister(...) Fl_Nice_Slider_swigregister(...) Fl_Output_swigregister(...) Fl_Overlay_Window_swigregister(...) Fl_PNG_Image_swigregister(...) Fl_PNM_Image_swigregister(...) Fl_Pack_swigregister(...) Fl_Pixmap_swigregister(...) Fl_Positioner_swigregister(...) Fl_Preferences_swigregister(...) Fl_Progress_swigregister(...) Fl_RGB_Image_swigregister(...) Fl_Radio_Button_swigregister(...) Fl_Radio_Light_Button_swigregister(...) Fl_Radio_Round_Button_swigregister(...) Fl_Repeat_Button_swigregister(...) Fl_Return_Button_swigregister(...) Fl_Roller_swigregister(...) Fl_Round_Button_swigregister(...) Fl_Round_Clock_swigregister(...) Fl_Scroll_swigregister(...) Fl_Scrollbar_swigregister(...) Fl_Secret_Input_swigregister(...) Fl_Select_Browser_swigregister(...) Fl_Shared_Image_add_handler(*args) `Fl_Shared_Image_add_handler(Fl_Shared_Handler f)` Fl_Shared_Image_find(*args) `Fl_Shared_Image_find(char n, int W = 0, int H = 0) -> Fl_Shared_Image` Fl_Shared_Image_get(*args) `Fl_Shared_Image_get(char n, int W = 0, int H = 0) -> Fl_Shared_Image` Fl_Shared_Image_images(*args) `Fl_Shared_Image_images() -> Fl_Shared_Image` Fl_Shared_Image_num_images(*args) `Fl_Shared_Image_num_images() -> int` Fl_Shared_Image_remove_handler(*args) `Fl_Shared_Image_remove_handler(Fl_Shared_Handler f)` Fl_Shared_Image_swigregister(...) Fl_Simple_Counter_swigregister(...) Fl_Single_Window_swigregister(...) Fl_Slider_swigregister(...) Fl_Spinner_swigregister(...) Fl_Table_Row_swigregister(...) Fl_Table_swigregister(...) Fl_Tabs_swigregister(...) Fl_Text_Buffer_character_width(*args) `Fl_Text_Buffer_character_width(char c, int indent, int tabDist, char nullSubsChar) -> int` Fl_Text_Buffer_expand_character(*args) `expand_character(int pos, int indent, char outStr) -> int Fl_Text_Buffer_expand_character(char c, int indent, char outStr, int tabDist, char nullSubsChar) -> int` Fl_Text_Buffer_swigregister(...) Fl_Text_Display_swigregister(...) Fl_Text_Editor_kf_backspace(*args) `Fl_Text_Editor_kf_backspace(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_c_s_move(*args) `Fl_Text_Editor_kf_c_s_move(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_copy(*args) `Fl_Text_Editor_kf_copy(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_ctrl_move(*args) `Fl_Text_Editor_kf_ctrl_move(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_cut(*args) `Fl_Text_Editor_kf_cut(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_default(*args) `Fl_Text_Editor_kf_default(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_delete(*args) `Fl_Text_Editor_kf_delete(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_down(*args) `Fl_Text_Editor_kf_down(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_end(*args) `Fl_Text_Editor_kf_end(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_enter(*args) `Fl_Text_Editor_kf_enter(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_home(*args) `Fl_Text_Editor_kf_home(int arg0, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_ignore(*args) `Fl_Text_Editor_kf_ignore(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_insert(*args) `Fl_Text_Editor_kf_insert(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_left(*args) `Fl_Text_Editor_kf_left(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_move(*args) `Fl_Text_Editor_kf_move(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_page_down(*args) `Fl_Text_Editor_kf_page_down(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_page_up(*args) `Fl_Text_Editor_kf_page_up(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_paste(*args) `Fl_Text_Editor_kf_paste(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_right(*args) `Fl_Text_Editor_kf_right(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_select_all(*args) `Fl_Text_Editor_kf_select_all(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_shift_move(*args) `Fl_Text_Editor_kf_shift_move(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_undo(*args) `Fl_Text_Editor_kf_undo(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_kf_up(*args) `Fl_Text_Editor_kf_up(int c, Fl_Text_Editor e) -> int` Fl_Text_Editor_swigregister(...) Fl_Text_Selection_swigregister(...) Fl_Tile_swigregister(...) Fl_Tiled_Image_swigregister(...) Fl_Timer_swigregister(...) Fl_Toggle_Button_swigregister(...) Fl_Tooltip_color(*args) `color(unsigned int c) Fl_Tooltip_color() -> Fl_Color` Fl_Tooltip_current(*args) `current() -> Fl_Widget Fl_Tooltip_current(Fl_Widget arg0)` Fl_Tooltip_delay(*args) `delay() -> float Fl_Tooltip_delay(float f)` Fl_Tooltip_disable(*args) `Fl_Tooltip_disable()` Fl_Tooltip_enable(*args) `Fl_Tooltip_enable(int b = 1)` Fl_Tooltip_enabled(*args) `Fl_Tooltip_enabled() -> int` Fl_Tooltip_enter_(*args) `Fl_Tooltip_enter_(Fl_Widget w)` Fl_Tooltip_enter_area(*args) `Fl_Tooltip_enter_area(Fl_Widget w, int X, int Y, int W, int H, char tip)` Fl_Tooltip_exit_(*args) `Fl_Tooltip_exit_(Fl_Widget w)` Fl_Tooltip_font(*args) `font() -> int Fl_Tooltip_font(int i)` Fl_Tooltip_hoverdelay(*args) `hoverdelay() -> float Fl_Tooltip_hoverdelay(float f)` Fl_Tooltip_size(*args) `size() -> int Fl_Tooltip_size(int s)` Fl_Tooltip_swigregister(...) Fl_Tooltip_textcolor(*args) `textcolor(unsigned int c) Fl_Tooltip_textcolor() -> Fl_Color` Fl_Valuator_swigregister(...) Fl_Value_Input_swigregister(...) Fl_Value_Output_swigregister(...) Fl_Value_Slider_swigregister(...) Fl_Widget_default_callback(*args) `Fl_Widget_default_callback(Fl_Widget arg0, void arg1)` Fl_Widget_label_shortcut(*args) `Fl_Widget_label_shortcut(char t) -> char` Fl_Widget_swigregister(...) Fl_Widget_test_shortcut(*args) `test_shortcut() -> int Fl_Widget_test_shortcut(char arg0) -> int` Fl_Window_current(*args) `Fl_Window_current() -> Fl_Window` Fl_Window_default_callback(*args) `Fl_Window_default_callback(Fl_Window arg0, void v)` Fl_Window_swigregister(...) Fl_Wizard_swigregister(...) Fl_XBM_Image_swigregister(...) Fl_XPM_Image_swigregister(...) Fl_add_awake_handler_(*args) `Fl_add_awake_handler_(Fl_Awake_Handler arg0, void arg1) -> int` Fl_add_check(...) Fl_add_fd(...) Fl_add_handler(...) Fl_add_idle(func, data=None) Fl_add_timeout(...) Fl_arg(*args) `Fl_arg(int arg0, char arg1, int arg2) -> int` Fl_args(*args) `args(int arg0, char arg1, int arg2, int arg3 = None) -> int Fl_args(int arg0, char arg1)` Fl_awake(*args) `awake(Fl_Awake_Handler cb, void message = None) -> int Fl_awake(void message = None)` Fl_background(*args) `Fl_background(uchar arg0, uchar arg1, uchar arg2)` Fl_background2(*args) `Fl_background2(uchar arg0, uchar arg1, uchar arg2)` Fl_belowmouse(*args) `belowmouse() -> Fl_Widget Fl_belowmouse(Fl_Widget arg0)` Fl_box_dh(*args) `Fl_box_dh(Fl_Boxtype arg0) -> int` Fl_box_dw(*args) `Fl_box_dw(Fl_Boxtype arg0) -> int` Fl_box_dx(*args) `Fl_box_dx(Fl_Boxtype arg0) -> int` Fl_box_dy(*args) `Fl_box_dy(Fl_Boxtype arg0) -> int` Fl_check(*args) `Fl_check() -> int` Fl_clear_widget_pointer(*args) `Fl_clear_widget_pointer(Fl_Widget w)` Fl_compose(*args) `Fl_compose(int _del) -> int` Fl_compose_reset(*args) `Fl_compose_reset()` Fl_copy(*args) `Fl_copy(char stuff, int len, int clipboard = 0)` Fl_damage(*args) `damage(int d) Fl_damage() -> int` Fl_default_atclose(*args) `Fl_default_atclose(Fl_Window arg0, void arg1)` Fl_delete_widget(*args) `Fl_delete_widget(Fl_Widget w)` Fl_display(*args) `Fl_display(char arg0)` Fl_dnd(*args) `Fl_dnd() -> int` Fl_dnd_text_ops(*args) `dnd_text_ops(int v) Fl_dnd_text_ops() -> int` Fl_do_widget_deletion(*args) `Fl_do_widget_deletion()` Fl_draw_box_active(*args) `Fl_draw_box_active() -> int` Fl_event(*args) `Fl_event() -> int` Fl_event_alt(*args) `Fl_event_alt() -> int` Fl_event_button(*args) `Fl_event_button() -> int` Fl_event_button1(*args) `Fl_event_button1() -> int` Fl_event_button2(*args) `Fl_event_button2() -> int` Fl_event_button3(*args) `Fl_event_button3() -> int` Fl_event_buttons(*args) `Fl_event_buttons() -> int` Fl_event_clicks(*args) `event_clicks() -> int Fl_event_clicks(int i)` Fl_event_ctrl(*args) `Fl_event_ctrl() -> int` Fl_event_dx(*args) `Fl_event_dx() -> int` Fl_event_dy(*args) `Fl_event_dy() -> int` Fl_event_inside(*args) `event_inside(int arg0, int arg1, int arg2, int arg3) -> int Fl_event_inside(Fl_Widget arg0) -> int` Fl_event_is_click(*args) `event_is_click() -> int Fl_event_is_click(int i)` Fl_event_key(*args) `event_key() -> int Fl_event_key(int arg0) -> int` Fl_event_length(*args) `Fl_event_length() -> int` Fl_event_original_key(*args) `Fl_event_original_key() -> int` Fl_event_shift(*args) `Fl_event_shift() -> int` Fl_event_state(*args) `event_state() -> int Fl_event_state(int i) -> int` Fl_event_text(*args) `Fl_event_text() -> char` Fl_event_x(*args) `Fl_event_x() -> int` Fl_event_x_root(*args) `Fl_event_x_root() -> int` Fl_event_y(*args) `Fl_event_y() -> int` Fl_event_y_root(*args) `Fl_event_y_root() -> int` Fl_first_window(*args) `first_window() -> Fl_Window Fl_first_window(Fl_Window arg0)` Fl_flush(*args) `Fl_flush()` Fl_focus(*args) `focus() -> Fl_Widget Fl_focus(Fl_Widget arg0)` Fl_foreground(*args) `Fl_foreground(uchar arg0, uchar arg1, uchar arg2)` Fl_free_color(*args) `Fl_free_color(Fl_Color arg0, int overlay = 0)` Fl_get_awake_handler_(*args) `Fl_get_awake_handler_(Fl_Awake_Handler arg0, void arg1) -> int` Fl_get_boxtype(*args) `Fl_get_boxtype(Fl_Boxtype arg0) -> Fl_Box_Draw_F` Fl_get_color(*args) `Fl_get_color(Fl_Color arg0)` Fl_get_font(*args) `Fl_get_font(Fl_Font arg0) -> char` Fl_get_font_name(*args) `Fl_get_font_name(Fl_Font arg0, int attributes = None) -> char` Fl_get_font_sizes(*args) `Fl_get_font_sizes(Fl_Font arg0, int sizep) -> int` Fl_get_key(*args) `Fl_get_key(int arg0) -> int` Fl_get_mouse(*args) `Fl_get_mouse(int arg0, int arg1)` Fl_get_system_colors(*args) `Fl_get_system_colors()` Fl_grab(*args) `grab() -> Fl_Window Fl_grab(Fl_Window arg0)` Fl_h(*args) `Fl_h() -> int` Fl_handle(*args) `Fl_handle(int arg0, Fl_Window arg1) -> int` Fl_has_idle(*args) `Fl_has_idle(void cb, void arg1 = None) -> int` Fl_has_timeout(*args) `Fl_has_timeout(Fl_Timeout_Handler arg0, void arg1 = None) -> int` Fl_lock(*args) `Fl_lock()` Fl_modal(*args) `Fl_modal() -> Fl_Window` Fl_mt_run(window) Fl_next_window(*args) `Fl_next_window(Fl_Window arg0) -> Fl_Window` Fl_own_colormap(*args) `Fl_own_colormap()` Fl_paste(*args) `paste(Fl_Widget receiver, int clipboard) Fl_paste(Fl_Widget receiver)` Fl_pushed(*args) `pushed() -> Fl_Widget Fl_pushed(Fl_Widget arg0)` Fl_readqueue(*args) `Fl_readqueue() -> Fl_Widget` Fl_ready(*args) `Fl_ready() -> int` Fl_redraw(*args) `Fl_redraw()` Fl_release(*args) `Fl_release()` Fl_release_widget_pointer(*args) `Fl_release_widget_pointer(Fl_Widget w)` Fl_reload_scheme(*args) `Fl_reload_scheme() -> int` Fl_remove_check(...) Fl_remove_fd(...) Fl_remove_handler(...) Fl_remove_idle(func, data=None) Fl_remove_timeout(...) Fl_repeat_timeout(...) Fl_run(*args) `Fl_run() -> int` Fl_scheme(*args) `scheme(char arg0) -> int Fl_scheme() -> char` Fl_screen_count(*args) `Fl_screen_count() -> int` Fl_screen_xywh(*args) `screen_xywh(int X, int Y, int W, int H) screen_xywh(int X, int Y, int W, int H, int mx, int my) Fl_screen_xywh(int X, int Y, int W, int H, int n)` Fl_scrollbar_size(*args) `scrollbar_size() -> int Fl_scrollbar_size(int W)` Fl_selection(*args) `Fl_selection(Fl_Widget owner, char arg1, int len)` Fl_selection_owner(*args) `selection_owner() -> Fl_Widget Fl_selection_owner(Fl_Widget arg0)` Fl_set_abort(*args) `Fl_set_abort(void f)` Fl_set_atclose(*args) `Fl_set_atclose(void f)` Fl_set_boxtype(*args) `set_boxtype(Fl_Boxtype arg0, Fl_Box_Draw_F arg1, uchar arg2, uchar arg3, uchar arg4, uchar arg5) Fl_set_boxtype(Fl_Boxtype arg0, Fl_Boxtype _from)` Fl_set_color(*args) `set_color(Fl_Color arg0, uchar arg1, uchar arg2, uchar arg3) Fl_set_color(Fl_Color arg0, unsigned int arg1)` Fl_set_font(*args) `set_font(Fl_Font arg0, char arg1) Fl_set_font(Fl_Font arg0, Fl_Font arg1)` Fl_set_fonts(*args) `Fl_set_fonts(char arg0 = None) -> Fl_Font` Fl_set_labeltype(*args) `Fl_set_labeltype(Fl_Labeltype arg0, Fl_Label_Draw_F arg1, Fl_Label_Measure_F arg2)` Fl_swigregister(...) Fl_test_shortcut(*args) `Fl_test_shortcut(int arg0) -> int` Fl_thread_message(*args) `Fl_thread_message()` Fl_unlock(*args) `Fl_unlock()` Fl_version(*args) `Fl_version() -> double` Fl_visible_focus(*args) `visible_focus(int v) Fl_visible_focus() -> int` Fl_visual(*args) `Fl_visual(int arg0) -> int` Fl_w(*args) `Fl_w() -> int` Fl_wait(*args) `wait() -> int Fl_wait(double time) -> double` Fl_watch_widget_pointer(*args) `Fl_watch_widget_pointer(Fl_Widget w)` Fl_x(*args) `Fl_x() -> int` Fl_y(*args) `Fl_y() -> int` Flcc_HueBox_swigregister(...) Flcc_ValueBox_swigregister(...) Flcc_Value_Input_swigregister(...) ListSelect_swigregister(...) Style_Table_Entry_swigregister(...) downCB(*args) `downCB(Fl_Widget v, void arg1)` fl_add_symbol(*args) `fl_add_symbol(char name, void drawit, int scalable) -> int` fl_alert(*args) `fl_alert(char arg0, v(...) *args)` fl_arc(*args) `fl_arc(int x, int y, int w, int h, double a1, double a2) fl_arc(double x, double y, double r, double start, double a)` fl_ask(*args) `fl_ask(char arg0, v(...) *args) -> int` fl_beep(*args) `fl_beep(int type = FL_BEEP_DEFAULT)` fl_begin_complex_polygon(*args) `fl_begin_complex_polygon()` fl_begin_line(*args) `fl_begin_line()` fl_begin_loop(*args) `fl_begin_loop()` fl_begin_points(*args) `fl_begin_points()` fl_begin_polygon(*args) `fl_begin_polygon()` fl_box(*args) `fl_box(Fl_Boxtype b) -> Fl_Boxtype` fl_can_do_alpha_blending(*args) `fl_can_do_alpha_blending() -> char` fl_cancel_get(*args) `fl_cancel_get() -> char` fl_cancel_set(*args) `fl_cancel_set(char value)` fl_choice(*args) `fl_choice(char q, char b0, char b1, char b2, v(...) *args) -> int` fl_circle(*args) `fl_circle(double x, double y, double r)` fl_clip_box(*args) `fl_clip_box(int arg0, int arg1, int arg2, int arg3) -> int` fl_close_get(*args) `fl_close_get() -> char` fl_close_set(*args) `fl_close_set(char value)` fl_color(*args) `fl_color(Fl_Color arg0) fl_color(uchar arg0, uchar arg1, uchar arg2) fl_color() -> Fl_Color` fl_color_average(*args) `fl_color_average(Fl_Color c1, Fl_Color c2, float weight) -> Fl_Color` fl_color_chooser(*args) `fl_color_chooser(char name, uchar r, uchar g, uchar b) -> int` fl_color_cube(*args) `fl_color_cube(int r, int g, int b) -> Fl_Color` fl_contrast(*args) `fl_contrast(Fl_Color fg, Fl_Color bg) -> Fl_Color` fl_cursor(*args) `fl_cursor(Fl_Cursor arg0, Fl_Color arg1 = FL_BLACK, Fl_Color arg2 = FL_WHITE)` fl_curve(*args) `fl_curve(double arg0, double arg1, double arg2, double arg3, double arg4, double arg5, double arg6, double arg7)` fl_darker(*args) `fl_darker(Fl_Color c) -> Fl_Color` fl_define_FL_DIAMOND_BOX(*args) `fl_define_FL_DIAMOND_BOX() -> Fl_Boxtype` fl_define_FL_EMBOSSED_LABEL(*args) `fl_define_FL_EMBOSSED_LABEL() -> Fl_Labeltype` fl_define_FL_ENGRAVED_LABEL(*args) `fl_define_FL_ENGRAVED_LABEL() -> Fl_Labeltype` fl_define_FL_GTK_UP_BOX(*args) `fl_define_FL_GTK_UP_BOX() -> Fl_Boxtype` fl_define_FL_OVAL_BOX(*args) `fl_define_FL_OVAL_BOX() -> Fl_Boxtype` fl_define_FL_PLASTIC_UP_BOX(*args) `fl_define_FL_PLASTIC_UP_BOX() -> Fl_Boxtype` fl_define_FL_RFLAT_BOX(*args) `fl_define_FL_RFLAT_BOX() -> Fl_Boxtype` fl_define_FL_ROUNDED_BOX(*args) `fl_define_FL_ROUNDED_BOX() -> Fl_Boxtype` fl_define_FL_ROUND_UP_BOX(*args) `fl_define_FL_ROUND_UP_BOX() -> Fl_Boxtype` fl_define_FL_RSHADOW_BOX(*args) `fl_define_FL_RSHADOW_BOX() -> Fl_Boxtype` fl_define_FL_SHADOW_BOX(*args) `fl_define_FL_SHADOW_BOX() -> Fl_Boxtype` fl_define_FL_SHADOW_LABEL(*args) `fl_define_FL_SHADOW_LABEL() -> Fl_Labeltype` fl_descent(*args) `fl_descent() -> int` fl_dir_chooser(*args) `fl_dir_chooser(char message, char fname, int relative = 0) -> char` fl_down(*args) `fl_down(Fl_Boxtype b) -> Fl_Boxtype` fl_draw(*args) `fl_draw(char arg0, int x, int y) fl_draw(char arg0, int n, int x, int y) fl_draw(char arg0, int arg1, int arg2, int arg3, int arg4, Fl_Align arg5, Fl_Image img = None, int draw_symbols = 1) fl_draw(char arg0, int arg1, int arg2, int arg3, int arg4, Fl_Align arg5, void callthis, Fl_Image img = None, int draw_symbols = 1)` fl_draw_box(*args) `fl_draw_box(Fl_Boxtype arg0, int x, int y, int w, int h, Fl_Color arg5)` fl_draw_image(*args) `fl_draw_image(uchar arg0, int arg1, int arg2, int arg3, int arg4, int delta = 3, int ldelta = 0)` fl_draw_image_mono(*args) `fl_draw_image_mono(uchar arg0, int arg1, int arg2, int arg3, int arg4, int delta = 1, int ld = 0)` fl_draw_pixmap(*args) `fl_draw_pixmap(char data, int x, int y, Fl_Color arg3 = FL_BACKGROUND_COLOR) -> int` fl_draw_symbol(*args) `fl_draw_symbol(char label, int x, int y, int w, int h, Fl_Color arg5) -> int` fl_end_complex_polygon(*args) `fl_end_complex_polygon()` fl_end_line(*args) `fl_end_line()` fl_end_loop(*args) `fl_end_loop()` fl_end_points(*args) `fl_end_points()` fl_end_polygon(*args) `fl_end_polygon()` fl_file_chooser(*args) `fl_file_chooser(char message, char pat, char fname, int relative = 0) -> char` fl_file_chooser_callback(*args) `fl_file_chooser_callback(void cb)` fl_file_chooser_ok_label(*args) `fl_file_chooser_ok_label(char l)` fl_filename_absolute(*args) `fl_filename_absolute(char to, int tolen, char _from) -> int fl_filename_absolute(char to, char _from) -> int` fl_filename_expand(*args) `fl_filename_expand(char to, int tolen, char _from) -> int fl_filename_expand(char to, char _from) -> int` fl_filename_ext(*args) `fl_filename_ext(char arg0) -> char` fl_filename_isdir(*args) `fl_filename_isdir(char name) -> int` fl_filename_match(*args) `fl_filename_match(char name, char pattern) -> int` fl_filename_name(*args) `fl_filename_name(char arg0) -> char` fl_filename_relative(*args) `fl_filename_relative(char to, int tolen, char _from) -> int fl_filename_relative(char to, char _from) -> int` fl_filename_setext(*args) `fl_filename_setext(char to, int tolen, char ext) -> char fl_filename_setext(char to, char ext) -> char` fl_font(*args) `fl_font(int face, int size) fl_font() -> int` fl_frame(*args) `fl_frame(Fl_Boxtype b) -> Fl_Boxtype fl_frame(char s, int x, int y, int w, int h)` fl_frame2(*args) `fl_frame2(char s, int x, int y, int w, int h)` fl_gap(*args) `fl_gap()` fl_gray_ramp(*args) `fl_gray_ramp(int i) -> Fl_Color` fl_height(*args) `fl_height() -> int fl_height(int arg0, int size) -> int` fl_inactive(*args) `fl_inactive(Fl_Color c) -> Fl_Color` fl_input(*args) `fl_input(char label, char deflt = None) -> char` fl_latin1_to_local(*args) `fl_latin1_to_local(char arg0, int n = -1) -> char` fl_lighter(*args) `fl_lighter(Fl_Color c) -> Fl_Color` fl_line(*args) `fl_line(int arg0, int arg1, int arg2, int arg3) fl_line(int arg0, int arg1, int arg2, int arg3, int arg4, int arg5)` fl_line_style(*args) `fl_line_style(int style, int width = 0, char dashes = None)` fl_local_to_latin1(*args) `fl_local_to_latin1(char arg0, int n = -1) -> char` fl_local_to_mac_roman(*args) `fl_local_to_mac_roman(char arg0, int n = -1) -> char` fl_loop(*args) `fl_loop(int arg0, int arg1, int arg2, int arg3, int arg4, int arg5) fl_loop(int arg0, int arg1, int arg2, int arg3, int arg4, int arg5, int arg6, int arg7)` fl_mac_roman_to_local(*args) `fl_mac_roman_to_local(char arg0, int n = -1) -> char` fl_measure(*args) `fl_measure(char arg0, int draw_symbols = 1)` fl_measure_pixmap(*args) `fl_measure_pixmap(char data) -> int` fl_message(*args) `fl_message(char arg0, v(...) *args)` fl_message_font(*args) `fl_message_font(unsigned char f, unsigned char s)` fl_message_icon(*args) `fl_message_icon() -> Fl_Widget` fl_mt_alert(*args) `fl_mt_alert(char text)` fl_mt_ask(*args) `fl_mt_ask(char text) -> int` fl_mt_choice(*args) `fl_mt_choice(char q, char b0, char b1, char b2) -> int` fl_mt_input(*args) `fl_mt_input(char label, char deflt = None) -> char` fl_mt_message(*args) `fl_mt_message(char text)` fl_mt_password(*args) `fl_mt_password(char label, char deflt = None) -> char` fl_mult_matrix(*args) `fl_mult_matrix(double a, double b, double c, double d, double x, double y)` fl_no_get(*args) `fl_no_get() -> char` fl_no_set(*args) `fl_no_set(char value)` fl_not_clipped(*args) `fl_not_clipped(int x, int y, int w, int h) -> int` fl_ok_get(*args) `fl_ok_get() -> char` fl_ok_set(*args) `fl_ok_set(char value)` fl_old_shortcut(*args) `fl_old_shortcut(char arg0) -> int` fl_open_uri(*args) `fl_open_uri(char uri, char msg = (char *) 0, int msglen = 0) -> int` fl_overlay_clear(*args) `fl_overlay_clear()` fl_overlay_rect(*args) `fl_overlay_rect(int arg0, int arg1, int arg2, int arg3)` fl_password(*args) `fl_password(char label, char deflt = None) -> char` fl_pie(*args) `fl_pie(int x, int y, int w, int h, double a1, double a2)` fl_point(*args) `fl_point(int x, int y)` fl_polygon(*args) `fl_polygon(int arg0, int arg1, int arg2, int arg3, int arg4, int arg5) fl_polygon(int arg0, int arg1, int arg2, int arg3, int arg4, int arg5, int arg6, int arg7)` fl_pop_clip(*args) `fl_pop_clip()` fl_pop_matrix(*args) `fl_pop_matrix()` fl_push_clip(*args) `fl_push_clip(int x, int y, int w, int h)` fl_push_matrix(*args) `fl_push_matrix()` fl_push_no_clip(*args) `fl_push_no_clip()` fl_rect(*args) `fl_rect(int x, int y, int w, int h) fl_rect(int x, int y, int w, int h, Fl_Color c)` fl_rectf(*args) `fl_rectf(int x, int y, int w, int h) fl_rectf(int x, int y, int w, int h, Fl_Color c) fl_rectf(int x, int y, int w, int h, uchar r, uchar g, uchar b)` fl_register_images(*args) `fl_register_images()` fl_rgb_color(*args) `fl_rgb_color(uchar r, uchar g, uchar b) -> Fl_Color fl_rgb_color(uchar g) -> Fl_Color` fl_rotate(*args) `fl_rotate(double d)` fl_scale(*args) `fl_scale(double x, double y) fl_scale(double x)` fl_scroll(*args) `fl_scroll(int X, int Y, int W, int H, int dx, int dy, void draw_area, void data)` fl_shortcut_label(*args) `fl_shortcut_label(int arg0) -> char` fl_show_colormap(*args) `fl_show_colormap(Fl_Color oldcol) -> Fl_Color` fl_size(*args) `fl_size() -> int` fl_transform_dx(*args) `fl_transform_dx(double x, double y) -> double` fl_transform_dy(*args) `fl_transform_dy(double x, double y) -> double` fl_transform_x(*args) `fl_transform_x(double x, double y) -> double` fl_transform_y(*args) `fl_transform_y(double x, double y) -> double` fl_transformed_vertex(*args) `fl_transformed_vertex(double x, double y)` fl_translate(*args) `fl_translate(double x, double y)` fl_vertex(*args) `fl_vertex(double x, double y)` fl_width(*args) `fl_width(char arg0) -> double fl_width(char arg0, int n) -> double fl_width(uchar arg0) -> double` fl_xid(*args) `fl_xid(Fl_Window w) -> int` fl_xyline(*args) `fl_xyline(int x, int y, int x1) fl_xyline(int x, int y, int x1, int y2) fl_xyline(int x, int y, int x1, int y2, int x3)` fl_yes_get(*args) `fl_yes_get() -> char` fl_yes_set(*args) `fl_yes_set(char value)` fl_yxline(*args) `fl_yxline(int x, int y, int y1) fl_yxline(int x, int y, int y1, int x2) fl_yxline(int x, int y, int y1, int x2, int y3)` glBegin(*args) `glBegin(int mode)` glClear(*args) `glClear(int mask)` glColor3f(*args) `glColor3f(float red, float green, float blue)` glEnd(*args) `glEnd()` glLoadIdentity(*args) `glLoadIdentity()` glVertex3f(*args) `glVertex3f(float x, float y, float z)` glViewport(*args) `glViewport(int x, int y, int width, int height)` gl_color(*args) `gl_color(Fl_Color arg0) gl_color(int c)` gl_descent(*args) `gl_descent() -> int` gl_draw(*args) `gl_draw(char arg0) gl_draw(char arg0, int n) gl_draw(char arg0, int x, int y) gl_draw(char arg0, float x, float y) gl_draw(char arg0, int n, int x, int y) gl_draw(char arg0, int n, float x, float y) gl_draw(char arg0, int x, int y, int w, int h, Fl_Align arg5)` gl_draw_image(*args) `gl_draw_image(uchar arg0, int x, int y, int w, int h, int d = 3, int ld = 0)` gl_finish(*args) `gl_finish()` gl_font(*args) `gl_font(int fontid, int size)` gl_height(*args) `gl_height() -> int` gl_measure(*args) `gl_measure(char arg0)` gl_rect(*args) `gl_rect(int x, int y, int w, int h)` gl_rectf(*args) `gl_rectf(int x, int y, int w, int h)` gl_start(*args) `gl_start()` gl_width(*args) `gl_width(char arg0) -> double gl_width(char arg0, int n) -> double gl_width(uchar arg0) -> double` pyFLTK_controlIdleCallbacks(*args) `pyFLTK_controlIdleCallbacks(int enable)` pyFLTK_doIdleCallbacks() pyFLTK_registerDoIdle(...) setMenu(...) toggleCB(*args) `toggleCB(Fl_Widget v, void arg1)` upCB(*args) `upCB(Fl_Widget v, void arg1)` weakref_proxy = proxy(...) `proxy(object[, callback]) -- create a proxy object that weakly references 'object'. 'callback', if given, is called with a reference to the proxy when 'object' is about to be finalized.`

Data
`` |  | FL_ACCUM = 4 FL_ACTIVATE = 14 FL_ALIGN_BOTTOM = 2 FL_ALIGN_BOTTOM_LEFT = 6 FL_ALIGN_BOTTOM_RIGHT = 10 FL_ALIGN_CENTER = 0 FL_ALIGN_CLIP = 64 FL_ALIGN_IMAGE_OVER_TEXT = 0 FL_ALIGN_INSIDE = 16 FL_ALIGN_LEFT = 4 FL_ALIGN_LEFT_BOTTOM = 6 FL_ALIGN_LEFT_TOP = 5 FL_ALIGN_NOWRAP = 0 FL_ALIGN_RIGHT = 8 FL_ALIGN_RIGHT_BOTTOM = 10 FL_ALIGN_RIGHT_TOP = 9 FL_ALIGN_TEXT_OVER_IMAGE = 32 FL_ALIGN_TOP = 1 FL_ALIGN_TOP_LEFT = 5 FL_ALIGN_TOP_RIGHT = 9 FL_ALIGN_WRAP = 128 FL_ALL_FREE = 5 FL_ALPHA = 8 FL_ALPHASORT = 0 FL_ALT = 524288 FL_ANALOG_CLOCK = 0 FL_Alt_L = 65513 FL_Alt_R = 65514 FL_BACKGROUND2_COLOR = 7 FL_BACKGROUND_COLOR = 49 FL_BAR_CHART = 0 FL_BEEP_DEFAULT = 0 FL_BEEP_ERROR = 2 FL_BEEP_MESSAGE = 1 FL_BEEP_NOTIFICATION = 5 FL_BEEP_PASSWORD = 4 FL_BEEP_QUESTION = 3 FL_BLACK = 56 FL_BLUE = 216 FL_BOLD = 1 FL_BORDER_BOX = 14 FL_BORDER_FRAME = 16 FL_BUTTON1 = 16777216 FL_BUTTON2 = 33554432 FL_BUTTON3 = 67108864 FL_BUTTONS = 2130706432 FL_BackSpace = 65288 FL_Button = 65256 FL_CAPS_LOCK = 131072 FL_CAP_FLAT = 256 FL_CAP_ROUND = 512 FL_CAP_SQUARE = 768 FL_CASEALPHASORT = 1 FL_CASENUMERICSORT = 2 FL_CHART_LABEL_MAX = 18 FL_CHART_MAX = 128 FL_CLOSE = 10 FL_COLOR_CUBE = 56 FL_COMMAND = 262144 FL_CONTINUOUS_FREE = 4 FL_COURIER = 4 FL_COURIER_BOLD = 5 FL_COURIER_BOLD_ITALIC = 7 FL_COURIER_ITALIC = 6 FL_CTRL = 262144 FL_CURSOR_ARROW = 35 FL_CURSOR_CROSS = 66 FL_CURSOR_DEFAULT = 0 FL_CURSOR_E = 49 FL_CURSOR_HAND = 31 FL_CURSOR_HELP = 47 FL_CURSOR_INSERT = 77 FL_CURSOR_MOVE = 27 FL_CURSOR_N = 70 FL_CURSOR_NE = 69 FL_CURSOR_NESW = 81 FL_CURSOR_NONE = 255 FL_CURSOR_NS = 78 FL_CURSOR_NW = 68 FL_CURSOR_NWSE = 80 FL_CURSOR_S = 9 FL_CURSOR_SE = 8 FL_CURSOR_SW = 7 FL_CURSOR_W = 36 FL_CURSOR_WAIT = 76 FL_CURSOR_WE = 79 FL_CYAN = 223 FL_Caps_Lock = 65509 FL_Control_L = 65507 FL_Control_R = 65508 FL_DAMAGE_ALL = 128 FL_DAMAGE_CHILD = 1 FL_DAMAGE_EXPOSE = 2 FL_DAMAGE_OVERLAY = 8 FL_DAMAGE_SCROLL = 4 FL_DAMAGE_USER1 = 16 FL_DAMAGE_USER2 = 32 FL_DARK1 = 47 FL_DARK2 = 45 FL_DARK3 = 39 FL_DARK_BLUE = 136 FL_DARK_CYAN = 140 FL_DARK_GREEN = 60 FL_DARK_MAGENTA = 152 FL_DARK_RED = 72 FL_DARK_YELLOW = 76 FL_DASH = 1 FL_DASHDOT = 3 FL_DASHDOTDOT = 4 FL_DEACTIVATE = 13 FL_DEPTH = 16 FL_DIAMOND_DOWN_BOX = 25 FL_DIAMOND_UP_BOX = 24 FL_DIGITAL_CLOCK = 0 FL_DND_DRAG = 21 FL_DND_ENTER = 20 FL_DND_LEAVE = 22 FL_DND_RELEASE = 23 FL_DOT = 2 FL_DOUBLE = 2 FL_DOUBLE_WINDOW = 241 FL_DOWN_BOX = 3 FL_DOWN_FRAME = 5 FL_DRAG = 5 FL_DRAW = 100 FL_Delete = 65535 FL_Down = 65364 FL_EMBOSSED_BOX = 11 FL_EMBOSSED_FRAME = 13 FL_EMBOSSED_LABEL = 4 FL_ENGRAVED_BOX = 10 FL_ENGRAVED_FRAME = 12 FL_ENGRAVED_LABEL = 3 FL_ENTER = 3 FL_EXCEPT = 8 FL_End = 65367 FL_Enter = 65293 FL_Escape = 65307 FL_F = 65469 FL_FAKE_SINGLE = 512 FL_FILLED_CHART = 3 FL_FILL_CHART = 3 FL_FILL_DIAL = 2 FL_FLAT_BOX = 1 FL_FLOAT_INPUT = 1 FL_FOCUS = 6 FL_FOREGROUND_COLOR = 0 FL_FREEMEM = 102 FL_FREEZE = 103 FL_FREE_BOXTYPE = 48 FL_FREE_COLOR = 16 FL_FREE_FONT = 16 FL_FREE_LABELTYPE = 8 FL_F_Last = 65504 FL_GRAY = 49 FL_GRAY0 = 32 FL_GRAY_RAMP = 32 FL_GREEN = 63 FL_GTK_DOWN_BOX = 39 FL_GTK_DOWN_FRAME = 41 FL_GTK_ROUND_DOWN_BOX = 47 FL_GTK_ROUND_UP_BOX = 46 FL_GTK_THIN_DOWN_BOX = 43 FL_GTK_THIN_DOWN_FRAME = 45 FL_GTK_THIN_UP_BOX = 42 FL_GTK_THIN_UP_FRAME = 44 FL_GTK_UP_BOX = 38 FL_GTK_UP_FRAME = 40 FL_HELVETICA = 0 FL_HELVETICA_BOLD = 1 FL_HELVETICA_BOLD_ITALIC = 3 FL_HELVETICA_ITALIC = 2 FL_HIDDEN_BUTTON = 3 FL_HIDDEN_INPUT = 3 FL_HIDDEN_TIMER = 2 FL_HIDE = 15 FL_HOLD_BROWSER = 2 FL_HORBAR_CHART = 1 FL_HORIZONTAL = 1 FL_HOR_FILL_SLIDER = 3 FL_HOR_NICE_SLIDER = 5 FL_HOR_SLIDER = 1 FL_Help = 65384 FL_Home = 65360 FL_IMAGE_WITH_ALPHA = 1073741824 FL_INACTIVE_COLOR = 8 FL_INDEX = 1 FL_INPUT_FREE = 3 FL_INPUT_READONLY = 8 FL_INPUT_TYPE = 7 FL_INPUT_WRAP = 16 FL_INT_INPUT = 2 FL_ITALIC = 2 FL_Insert = 65379 FL_JOIN_BEVEL = 12288 FL_JOIN_MITER = 4096 FL_JOIN_ROUND = 8192 FL_KEYBOARD = 8 FL_KEYDOWN = 8 FL_KEYUP = 9 FL_KP = 65408 FL_KP_Enter = 65421 FL_KP_Last = 65469 FL_LEAVE = 4 FL_LEFT_MOUSE = 1 FL_LIGHT1 = 50 FL_LIGHT2 = 52 FL_LIGHT3 = 54 FL_LINE_CHART = 2 FL_LINE_DIAL = 1 FL_Left = 65361 FL_MAGENTA = 248 FL_MAJOR_VERSION = 1 FL_MENU_BOX = 2 FL_MENU_CHECK = 4 FL_MENU_DIVIDER = 128 FL_MENU_HORIZONTAL = 256 FL_MENU_INACTIVE = 1 FL_MENU_INVISIBLE = 16 FL_MENU_RADIO = 8 FL_MENU_TOGGLE = 2 FL_MENU_VALUE = 4 FL_META = 4194304 FL_MIDDLE_MOUSE = 2 FL_MINOR_VERSION = 1 FL_MOUSEWHEEL = 19 FL_MOVE = 11 FL_MULTILINE_INPUT = 4 FL_MULTILINE_INPUT_WRAP = 20 FL_MULTILINE_OUTPUT = 12 FL_MULTILINE_OUTPUT_WRAP = 28 FL_MULTISAMPLE = 128 FL_MULTI_BROWSER = 3 FL_Menu = 65383 FL_Meta_L = 65511 FL_Meta_R = 65512 FL_NORMAL_BROWSER = 0 FL_NORMAL_BUTTON = 0 FL_NORMAL_COUNTER = 0 FL_NORMAL_DIAL = 0 FL_NORMAL_FREE = 1 FL_NORMAL_INPUT = 0 FL_NORMAL_LABEL = 0 FL_NORMAL_OUTPUT = 8 FL_NORMAL_TIMER = 0 FL_NO_BOX = 0 FL_NO_EVENT = 0 FL_NO_LABEL = 1 FL_NUMERICSORT = 3 FL_NUM_BLUE = 5 FL_NUM_FREE_COLOR = 16 FL_NUM_GRAY = 24 FL_NUM_GREEN = 8 FL_NUM_LOCK = 1048576 FL_NUM_RED = 5 FL_Num_Lock = 65407 FL_OFLAT_BOX = 29 FL_OSHADOW_BOX = 27 FL_OVAL_BOX = 26 FL_OVAL_FRAME = 28 FL_PASTE = 17 FL_PATCH_VERSION = 9 FL_PATH_MAX = 256 FL_PIE_CHART = 5 FL_PLASTIC_DOWN_BOX = 31 FL_PLASTIC_DOWN_FRAME = 33 FL_PLASTIC_ROUND_DOWN_BOX = 37 FL_PLASTIC_ROUND_UP_BOX = 36 FL_PLASTIC_THIN_DOWN_BOX = 35 FL_PLASTIC_THIN_UP_BOX = 34 FL_PLASTIC_UP_BOX = 30 FL_PLASTIC_UP_FRAME = 32 FL_PUP_BOX = 2 FL_PUP_CHECK = 4 FL_PUP_GRAY = 1 FL_PUP_GREY = 1 FL_PUP_INVISIBLE = 16 FL_PUP_NONE = 0 FL_PUP_RADIO = 8 FL_PUP_SUBMENU = 32 FL_PUSH = 1 FL_Page_Down = 65366 FL_Page_Up = 65365 FL_Pause = 65299 FL_Print = 65377 FL_RADIO_BUTTON = 102 FL_READ = 1 FL_RED = 88 FL_RELEASE = 2 FL_RESERVED_TYPE = 100 FL_RFLAT_BOX = 21 FL_RGB = 0 FL_RGB8 = 64 FL_RIGHT_MOUSE = 3 FL_ROUNDED_BOX = 18 FL_ROUNDED_FRAME = 20 FL_ROUND_CLOCK = 1 FL_ROUND_DOWN_BOX = 23 FL_ROUND_UP_BOX = 22 FL_RSHADOW_BOX = 19 FL_Right = 65363 FL_SCREEN = 13 FL_SCREEN_BOLD = 14 FL_SCROLL_LOCK = 8388608 FL_SECRET_INPUT = 5 FL_SELECTIONCLEAR = 18 FL_SELECTION_COLOR = 15 FL_SELECT_BROWSER = 1 FL_SHADOW_BOX = 15 FL_SHADOW_FRAME = 17 FL_SHADOW_LABEL = 2 FL_SHIFT = 65536 FL_SHORTCUT = 12 FL_SHOW = 16 FL_SIMPLE_COUNTER = 1 FL_SINGLE = 0 FL_SLEEPING_FREE = 2 FL_SOLID = 0 FL_SPECIALPIE_CHART = 6 FL_SPIKE_CHART = 4 FL_SQUARE_CLOCK = 0 FL_STENCIL = 32 FL_STEP = 101 FL_STEREO = 256 FL_SUBMENU = 64 FL_SUBMENU_POINTER = 32 FL_SYMBOL = 12 FL_SYMBOL_LABEL = 0 FL_Scroll_Lock = 65300 FL_Shift_L = 65505 FL_Shift_R = 65506 FL_TEXT_EDITOR_ANY_STATE = -1 FL_TEXT_MAX_EXP_CHAR_LEN = 20 FL_THAW = 104 FL_THIN_DOWN_BOX = 7 FL_THIN_DOWN_FRAME = 9 FL_THIN_UP_BOX = 6 FL_THIN_UP_FRAME = 8 FL_TIMES = 8 FL_TIMES_BOLD = 9 FL_TIMES_BOLD_ITALIC = 11 FL_TIMES_ITALIC = 10 FL_TOGGLE_BUTTON = 1 FL_Tab = 65289 FL_UNFOCUS = 7 FL_UP_BOX = 2 FL_UP_FRAME = 4 FL_Up = 65362 FL_VALUE_TIMER = 1 FL_VERTICAL = 0 FL_VERT_FILL_SLIDER = 2 FL_VERT_NICE_SLIDER = 4 FL_VERT_SLIDER = 0 FL_WHEN_CHANGED = 1 FL_WHEN_ENTER_KEY = 8 FL_WHEN_ENTER_KEY_ALWAYS = 10 FL_WHEN_ENTER_KEY_CHANGED = 11 FL_WHEN_NEVER = 0 FL_WHEN_NOT_CHANGED = 2 FL_WHEN_RELEASE = 4 FL_WHEN_RELEASE_ALWAYS = 6 FL_WHITE = 255 FL_WINDOW = 240 FL_WRITE = 4 FL_YELLOW = 95 FL_ZAPF_DINGBATS = 15 M_1_PI = 0.31830988618379069 M_2_PI = 0.63661977236758138 M_PI = 3.1415926535897931 M_PI_2 = 1.5707963267948966 M_PI_4 = 0.78539816339744828 M_SQRT1_2 = 0.70710678118654757 M_SQRT2 = 1.4142135623730951